/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : DL_u8_validation.h
   Author             : Rajesh
   Version            : V0.0.0.1
   Origination Date   : 21/01/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the DataBase DataLayer 8-bit field Validation functions

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             21/01/2022           Rajesh

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

#ifndef _DL_U8_VALIDATION_H_
#define	_DL_U8_VALIDATION_H_

/* USER CODE BEGIN EFP */
/*!
 * Function declaration
 */
/* USER CODE BEGIN Function decl */
#if (SDK_SERVICE_WARNING_LIGHT == PS_ENABLE)
int8_t validate_wl_state(uint16_t wl_num ,uint8_t state);
int8_t validate_wl_pwm(uint16_t wl_num ,uint8_t period);
#endif

#if (SDK_SERVICE_KEYPAD == PS_ENABLE)
int8_t validate_keypad_backlight(uint16_t keypad, uint8_t key_state);
int8_t validate_keypad_status(uint16_t keypad, uint8_t key_status);
int8_t validate_keypad_press(uint16_t keypad, uint8_t key_press);
#endif

#if (SDK_SERVICE_RTC == PS_ENABLE)
int8_t validate_RTC_parameter(uint16_t rtc_index, uint8_t value);
int8_t validate_and_SET_RTC_parameter(uint16_t rtc_index, uint8_t value);
#endif

#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
int8_t validate_DIO_CFG_parameter(uint16_t DIO_db_idx, uint8_t DIO_state);
int8_t validate_DIO_state(uint16_t DIO_db_idx, uint8_t DIO_state);
#endif

#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)
int8_t validate_LTS_conversion_time(uint16_t LTS_db_idx, uint8_t LTS_conv_time);
int8_t validate_LTS_conversion_mode(uint16_t LTS_db_idx, uint8_t LTS_conv_mode);
int8_t validate_LTS_trigger(uint16_t LTS_db_idx, uint8_t LTS_tigger);
#endif

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
int8_t validate_WD_feed_id(uint16_t wd_db_idx, uint8_t feed_id);
#endif

#if (SDK_SERVICE_LED == PS_ENABLE)
int8_t validate_led_state(uint16_t led_idx, uint8_t led_state);
#endif

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
int8_t validate_digital_input(uint16_t cfg_idx, uint8_t digital_input);
int8_t validate_num_of_samples(uint16_t cfg_idx, uint8_t value);
int8_t validate_cfg_type(uint16_t cfg_idx, uint8_t cfg_type);
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
int8_t validate_lcd_state(uint16_t lcd_idx, uint8_t lcd_state);
int8_t validate_lcd_brightness(uint16_t lcd_idx, uint8_t brightness_val);
#endif

#if (SDK_SERVICE_PM == PS_ENABLE)
int8_t validate_power_mode(uint16_t pm_idx, uint8_t pm_state);
int8_t validate_keypad_wakeup_state(uint16_t wakeup_idx, uint8_t state);
int8_t validate_rtc_wakeup_state(uint16_t wakeup_idx, uint8_t state);
int8_t validate_rtc_timeout(uint16_t wakeup_idx, uint8_t state);
#endif

#if (SDK_SERVICE_POWER_MONITOR == PS_ENABLE)
int8_t validate_IGN_state(uint16_t ign_idx, uint8_t ign_status);
#endif

#if (SDK_SERVICE_SWTIMER == PS_ENABLE)
int8_t validate_timer_status(uint16_t db_idx, uint8_t status);
int8_t validate_timer_mode(uint16_t db_idx, uint8_t mode);
int8_t validate_timer_callback(uint16_t db_idx, uint8_t state);
#endif

#if (SDK_SERVICE_BLE == PS_ENABLE)
int8_t validate_ble_tx_status(uint16_t db_idx, uint8_t status);
int8_t validate_ble_rx_status(uint16_t db_idx, uint8_t status);
int8_t validate_ble_buffer_status(uint16_t db_idx, uint8_t buf_status);
int8_t validate_ble_communication_status(uint16_t db_idx, uint8_t comm_status);
#endif

#if (SDK_SERVICE_USB == PS_ENABLE)
int8_t validate_usb_communication_status(uint16_t db_idx, uint8_t comm_status);
int8_t validate_usb_tx_status(uint16_t db_idx, uint8_t status);
int8_t validate_usb_rx_status(uint16_t db_idx, uint8_t status);
int8_t validate_usb_rxbuf_status(uint16_t db_idx, uint8_t status);
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
int8_t validate_eeprom_read_status(uint16_t db_idx, uint8_t status);
int8_t validate_eeprom_write_status(uint16_t db_idx, uint8_t status);
#endif

#if (SDK_SERVICE_CAMERA == PS_ENABLE)
int8_t validate_camera_stream_mode(uint16_t db_idx, uint8_t stream_state);
int8_t validate_camera_stream_state(uint16_t db_idx, uint8_t stream_state);
int8_t validate_flip_state(uint16_t db_idx, uint8_t flip_state);
#endif

#if (SDK_SERVICE_FDCAN == PS_ENABLE)
int8_t validate_fdcan_mode(uint16_t index_number ,uint8_t mode);
int8_t validate_filter_index(uint16_t index_number ,uint8_t range);
int8_t validate_can_state(uint16_t idx_num ,uint8_t state);
int8_t validate_can_comm_state(uint16_t idx_num ,uint8_t state);
int8_t validate_can_reset(uint16_t idx_num ,uint8_t state);
int8_t validate_can_byte_count(uint16_t idx_num ,uint8_t count_val);
int8_t validate_can_data_size(uint16_t idx_num ,uint8_t size);
int8_t validate_can_data_available(uint16_t idx_num ,uint8_t state);
int8_t validate_can_baudrate(uint16_t idx_num ,uint8_t baudrate);
#endif

#if (THROUGH_PUT_SERVICE == PS_ENABLE)
int8_t validate_percentage_time(uint16_t db_idx ,uint8_t p_time);
#endif

int8_t validate_dummy_field(uint16_t dummy1, uint8_t dummy2);
int8_t validate_ps_init_state(uint16_t wl_state, uint8_t wl_state_val);

/* USER CODE END EFP */

#endif	//_DB_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
