/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : platform_service.h
   Author             : Rajesh
   Version            : V0.0.0.1
   Origination Date   : 21/01/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the platform service configuration structures and macros

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             21/01/2022           Rajesh

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _PLATFORM_SERVICE_H_
#define	_PLATFORM_SERVICE_H_

/* USER CODE BEGIN enum */

/*!
 * SDK Platform service thread state
 */
typedef enum __PS_ThState
{
	STATE_STOP,
	STATE_START,
}PS_ThState;

/*!
 * Platform Service Timers
 */
typedef enum __PS_Timer
{
#if (SDK_SERVICE_WARNING_LIGHT == PS_ENABLE)
	PS_WL_TIMER,
#endif

#if (SDK_SERVICE_KEYPAD == PS_ENABLE)
	PS_KPD_TIMER,
#endif

#if (SDK_SERVICE_RTC == PS_ENABLE)
	PS_RTC_TIMER,
#endif

#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)
	PS_LS_TIMER,
#endif

#if (SDK_SERVICE_LED == PS_ENABLE)
	PS_LED_TIMER,
#endif

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
	PS_CI_TIMER,
#endif

#if (SDK_SERVICE_POWER_MONITOR == PS_ENABLE)
	PS_POWERMONITOR_TIMER,
#endif

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
	PS_WD_TIMER,
#endif

#if (SDK_SERVICE_USB == PS_ENABLE)
	PS_USB_TIMER,
#endif

	PS_MAX_TIMER,
}PS_Timer;

/* USER CODE END enum */

/* USER CODE BEGIN Private defines */
/*!
 *  Maximum number of Platform Service
 */
#define MAX_NUMBER_PS          15

/*!
 * Platform service SUCCESS Macro
 */
#define PS_SUCCESS   0

/*!
 * Platform service FAILURE Macro
 */
#define PS_FAILURE   -1

/*!
 * Platform service DB Function macros
 */
#define SET_DB Set_DL
#define GET_DB Get_DL

/*!
 * Platform service queue tick to wait
 */
#define Q_TICKSTOWAIT   1000

/*!
 * SDK Command Buffer Size
 */
#define CBUF_BUF_SIZE   5

/* USER CODE END Private defines */

/* USER CODE BEGIN EFP */
/*!
 * Function declaration
 */
void Platform_service_init(void);
void DB_u8_Field_Validation_Reg(void);
void DB_u16_Field_Validation_Reg(void);
void DB_float_Field_Validation_Reg(void);
void DB_u32_Field_Validation_Reg(void);
void DB_EEPROM_Field_Validation_Reg(void);
void DB_Buf_Field_Validation_Reg(void);
void DB_ju8_Field_Validation_Reg(void);
void DB_ju16_Field_Validation_Reg(void);
void DB_ju32_Field_Validation_Reg(void);

#if ((SDK_SERVICE_WARNING_LIGHT == PS_ENABLE) || \
		(SDK_SERVICE_LED == PS_ENABLE) ||        \
		(SDK_SERVICE_CFG_INPUT == PS_ENABLE) ||  \
		(SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE))
int8_t TakeI2CBusLock();
int8_t GiveI2CBusLock();
#endif

#if ((SDK_SERVICE_EEPROM == PS_ENABLE) || \
		(SDK_SERVICE_BLE == PS_ENABLE))
int8_t TakeSPIBusLock();
int8_t GiveSPIBusLock();
#endif

#if (SDK_SERVICE_WARNING_LIGHT == PS_ENABLE)
int8_t Warning_Light_PS_Start(void);
#endif

#if (SDK_SERVICE_KEYPAD == PS_ENABLE)
int8_t Keypad_PS_Start(void);
#endif

#if (SDK_SERVICE_RTC == PS_ENABLE)
int8_t RTC_PS_Start(void);
#endif

#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
int8_t DIO_PS_Start(void);
#endif

#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)
int8_t LS_PS_Start(void);
#endif

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
int8_t Watchdog_PS_Start(void);
#endif

#if (SDK_SERVICE_LED == PS_ENABLE)
int8_t LED_PS_Start(void);
#endif

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
int8_t CI_PS_Start(void);
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
int8_t LCD_PS_Start(void);
#endif

#if (SDK_SERVICE_PM == PS_ENABLE)
int8_t PM_PS_Start(void);
#endif

#if (SDK_SERVICE_POWER_MONITOR == PS_ENABLE)
int8_t PowerMonitor_PS_Start(void);
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
int8_t EE_PS_Start(void);
#endif

#if (SDK_SERVICE_SWTIMER == PS_ENABLE)
int8_t SWT_PS_Start(void);
#endif

#if (SDK_SERVICE_BLE == PS_ENABLE)
int8_t BLE_PS_Start(void);
#endif

#if (SDK_SERVICE_USB == PS_ENABLE)
int8_t USB_PS_Start(void);
#endif

#if (SDK_SERVICE_CAMERA == PS_ENABLE)
int8_t Camera_PS_Start(void);
#endif

#if (SDK_SERVICE_J1939 == PS_ENABLE)
int8_t J1939_PS_Start(void);
#endif

#if (THROUGH_PUT_SERVICE == PS_ENABLE)
int8_t Throughput_service_Start(void);
#endif

#if (SDK_SERVICE_FDCAN == PS_ENABLE)
int8_t FDCAN_PS_Start(void);
#endif

#if (USER_TASK_STATE == PS_ENABLE)
int8_t User_Task_Start(void);
#endif

/* USER CODE END EFP */

#endif	//_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
