/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : RTC_platformservice.h
   Author             : Arjun
   Version            : V0.0.0.1
   Origination Date   : 28/01/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the RTC platform service declaration

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             28/01/2022           Arjun

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _RTC_PLATFORM_SERVICE_H_
#define	_RTC_PLATFORM_SERVICE_H_

/*!
 * RTC TX Q size for
 * receiving data from SDK API.
 */
#define RTC_RX_TX_MAX_Q_SIZE 		10

/*!
 * Alarm Occured / Not Occured Alarm.
 */
#define ALARM_NOT_OCCURED        	0
#define ALARM_OCCURED            	1

/*!
 * RTC Platform service Task timeout value
 */
#define PS_RTC_SECOND_TIMEOUT       1000

/*!
 * SET RTC Parameter
 */
#define SET_RTC_PARAMETER			1

/*!
 * RTC parameter max and min value
 */
#define RTC_MIN_VAL					0
#define RTC_MAX_VAL					60

#define RTC_12H_MAX_VAL				12
#define RTC_24H_MAX_VAL				24

#define RTC_DAY_MIN_VAL				1
#define RTC_DAY_MAX_VAL				31

#define RTC_WEEKDAY_MIN_VAL			1
#define RTC_WEEKDAY_MAX_VAL			7

#define RTC_MONTH_MIN_VAL			1
#define RTC_MONTH_MAX_VAL			12

#define RTC_YEAR_MIN_VAL			0
#define RTC_YEAR_MAX_VAL			99

#define RTC_YEAR_MIN_VAL			0
#define RTC_YEAR_MAX_VAL			99

#define FORMAT_12_HOUR          	1
#define FORMAT_24_HOUR          	0

#define RTCBUF_BUF_SIZE				9

/*!
 * RTC Task stack Depth
 */
#define RTC_STACK_DEPTH				512

/* !
 * RTC SDK Field Index
 */
#define RTC_FUNC_INDEX             	0
#define RTC_RESULT_INDEX           	0
#define RTC_SEC_INDEX           	1
#define RTC_MIN_INDEX           	2
#define RTC_HOUR_INDEX           	3
#define RTC_DATE_INDEX           	4
#define RTC_MONTH_INDEX             5
#define RTC_YEAR_INDEX              6
#define RTC_WEEKDAY_INDEX           7
#define RTC_TIME_FORMAT_INDEX       8

#define ALARM_SEC_INDEX             1
#define ALARM_MIN_INDEX             2
#define ALARM_HOUR_INDEX            3
#define ALARM_WEEKDAY_INDEX         7


/*!
 * Function declaration
 */
void RTC_PS_DB_Init(void);

/*!
 * RTC SDK Message
 */
typedef enum __RTC_MSG
{
	RTC_SET,
	RTC_GET,
	RTC_SET_ALARM_A,
	RTC_SET_ALARM_B,
	RTC_ALARM_A_OCCURED,
	RTC_ALARM_B_OCCURED

}RTC_MSG;

/*!
 * RTC Input Events
 */
typedef enum __RTC_Event
{
	RTC_TMR_EVENT,
	RTC_MSG_EVENT,
}RTC_Event;


/*!
 * RTC Input Function
 */
typedef enum __RTC_Func
{
	TIME,
	ALARM_A,
	ALARM_B,
}RTC_Func;

/*!
 * RTC Platform service structure
 */
typedef struct __rtc_ps
{
	uint8_t Seconds;
	uint8_t Minutes;
	uint8_t Hours;
	uint8_t Date;
	uint8_t Month;
	uint8_t Year;
	uint8_t WeekDay;
	uint8_t time_format;
}rtc_ps;

#endif	//_RTC_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
