/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : USB_Platformservice.h
   Author             :
   Version            : V0.0.0.1
   Origination Date   : 14/02/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the USB platform service declarations

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             14/02/2022

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _USB_PLATFORM_SERVICE_H_
#define	_USB_PLATFORM_SERVICE_H_

/*!
 * USB TxQ and RxQ size for
 * send and receiving data from SDK API.
 */
#define USB_RX_TX_MAX_Q_SIZE     		10

/*!
 * USB Platform service Task timeout value
 */
#define PS_USB_TIMER_COUNT				1000

/*!
 * USB Platform Service Task Size
 */
#define USB_TASK_SIZE         			512

/* Thread State */
#define USB_THREAD_STATE_RUN   			0
#define USB_THREAD_STATE_STOP  			1

/*!
 * USB Packet timer state
 */
#define TIMER_NOT_STARTED              -1
#define TIMER_TIMEDOUT                  0

/* !
 * USB SDK Field Index
 */
#define USB_FUNC_INDEX             		0
#define USB_RESULT_INDEX           		0
#define USB_DATA_INDEX              	1
#define USB_LEN_INDEX	              	2

/*!
 *  USB Buffer status
 */
#define USB_TX_BUFF_FULL                1
#define USB_TX_BUFF_NOTFULL             2


/*!
 * Status of the RX buffer
 */
#define RX_MSG_PENDING                   1
#define RX_MSF_EMPTY                     2

/*!
 * USB Common Identifier macros
 */
#define BATTARY_POSITIVE_VOLT            1000

/*!
 * USB Enable /
 * USB disable
 */
#define   USB_ENABLE          			 1
#define   USB_DISABLE         			 0


/*!
 * USB return Values
 */
#define POINTER_ERROR           		 -1
#define INVALID_FRAME           		 -2
#define NOT_COMPLETE_FRAME      		 -3
#define VALID_FRAME              		 1

/*!
 * Maximum packet size
 */
#define MAX_USB_RX_LEN           		 255
#define MAX_USB_TX_LEN                   72
#define ADDITIONAL_FRAME_SIZE    		 4

/*!
 * USB CALLBACK IDs
 */
typedef enum
{
  PS_HAL_PCD_SOF_CB_ID          = 0x01,  /*!< USB PCD SOF callback ID          */
  PS_HAL_PCD_SETUPSTAGE_CB_ID   = 0x02,  /*!< USB PCD Setup Stage callback ID  */
  PS_HAL_PCD_RESET_CB_ID        = 0x03,  /*!< USB PCD Reset callback ID        */
  PS_HAL_PCD_SUSPEND_CB_ID      = 0x04,  /*!< USB PCD Suspend callback ID      */
  PS_HAL_PCD_RESUME_CB_ID       = 0x05,  /*!< USB PCD Resume callback ID       */
  PS_HAL_PCD_CONNECT_CB_ID      = 0x06,  /*!< USB PCD Connect callback ID      */
  PS_HAL_PCD_DISCONNECT_CB_ID   = 0x07,  /*!< USB PCD Disconnect callback ID   */

  PS_HAL_PCD_MSPINIT_CB_ID      = 0x08,  /*!< USB PCD MspInit callback ID      */
  PS_HAL_PCD_MSPDEINIT_CB_ID    = 0x09   /*!< USB PCD MspDeInit callback ID    */

} PS_HAL_PCD_CallbackIDTypeDef;


/*!
 * USB Events
 */
typedef enum __USB_Event
{
	USB_RX_EVENT,
	USB_CONN_EVENT,
	USB_DISC_EVENT,
	USB_TMR_EVENT,
	USB_MSG_EVENT,
	USB_CAM_STOP_EVENT,
	USB_CAM_START_EVENT
}USB_Event;


/*!
 * USB SDK Message
 */
typedef enum __USB_MSG
{
	USB_ACT,
	USB_SET,
}USB_MSG;

/*!
 * USB Communication status
 */
typedef enum __USB_COMM_STATUS
{
	USB_COMM_OK,
	USB_COMM_ERROR,
}USB_COMM_STATUS;

/*!
 * Function declaration
 */
int8_t USB_DB_Init(void);

#endif	//_USB_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
