/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : Bluetooth_Platformservice.c
   Author             : Arjun
   Version            : V0.0.0.1
   Origination Date   : 25/02/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the BLE platform service initialization

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             25/02/2022			Arjun

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../Inc/common.h"
/* USER CODE END Includes */

/* USER CODE BEGIN Macros */


/* USER CODE END Macros */


/* USER CODE BEGIN Global Variables */


#if (SDK_SERVICE_BLE == PS_ENABLE)
extern pvt_variable pv;
static uint8_t bluetooth_module_state = 0;

/* Private functions declaration */
static void BLEWakeupExternal_interrupt_init(void);
static void BLE_CS_init(void);

void HAL_GPIO_EXTI_BLE_Callback()
{
	/* Send Notify to the Keypad task to update the Key Status */
	xTaskNotifyFromISR( pv.ble_task, (1<<BLE_WKUP_EVENT) , eSetBits, NULL );
}

#if (SDK_CAM_BLE_STOP == PS_ENABLE)
/** @brief Stop/Start BLE Platform service task
 *
 *  This function starts/stops the BLE Platform Service
 *  task.
 *
 *  @param  state : Switch the state of running thread
 *
 *  @return SUCCESS
 *          FAILURE
 *
 */
uint8_t Stop_BLE_Service(uint8_t state)
{
	uint8_t *buff;
	uint8_t res;
	/* Get the buffer from the Memory */
   	buff = (uint8_t *) ai430_memory_alloc();


   	/* Check the state */
	if (STATE_STOP == state)
	{
		state = BLE_CAM_STOP_EVENT;
	}
	else
		state = BLE_CAM_START_EVENT;

    buff[0]  = BLE_CAM_STOP_EVENT;

	/* Send the data into the LED Q */
	if (xQueueSend( pv.bletxq, ( void * )&buff, ( TickType_t ) Q_TICKSTOWAIT ) != pdPASS)
	{
		/* Release the buffer */
		ai430_memory_free(buff);
		return FAILURE;
	}

	/* Notify the BLE task to update the BLE data */
	if (xTaskNotify( pv.ble_task, (1<<state), eSetBits ) != pdPASS)
	{
		return FAILURE;
	}

	/* Wait for receiving the return data */
    /* Send the data to the BLE platform service layer */
	if (xQueueReceive(pv.blerxq, &buff, ( TickType_t ) Q_TICKSTOWAIT ) != pdPASS )
	{
		/* Release the buffer */
		ai430_memory_free(buff);
		return FAILURE;
	}

	res = buff[BLE_RESULT_INDEX];

	/* Release the buffer */
	ai430_memory_free(buff);

	return res;
}
#endif

#if (SDK_SERVICE_PM == PS_ENABLE)
/** @brief BLE module deinit
 *
 *  This function will make the BLE reset pin to low.
 *
 *  @param  None
 *
 *  @return  None
 *
 */
void BLE_deinit(void)
{
    HAL_GPIO_WritePin(GPIOI, GPIO_PIN_8, GPIO_PIN_RESET);

    /* Deinit the BLE WakeUp Pin */
    HAL_GPIO_DeInit(GPIOF, GPIO_PIN_6);
}

/** @brief BLE reinit
 *
 *  This function will make the BLE reset pin to high.
 *
 *  @param  None
 *
 *  @return  None
 *
 */
void BLE_reinit(void)
{
    HAL_GPIO_WritePin(GPIOI, GPIO_PIN_8, GPIO_PIN_SET);
    bluetooth_module_state = FALSE;
}
#endif	//SDK_SERVICE_PM

/** @brief BLE DB Initialization
 *
 *  This function takes the default configuration from the config header
 *  file and store the data into the DB.
 *
 *  @param  None
 *
 *  @return  0 : PS_SUCCESS
 *          -1 : PS_FAILURE
 *
 */
int8_t BLE_DB_Init(void)
{
	uint8_t port_state = TRUE;
	uint32_t cNotifiedValue;

	vTaskDelay(1100);
	port_state = HAL_GPIO_ReadPin(GPIOF, GPIO_PIN_6);
	if(port_state == FALSE)
	{
	/* Initialize the BLE */
		TakeSPIBusLock();
		BLE_CS_LOW();
		/* Update the BLE Device Name from the configuration file */
		Send_BLE_Name(strlen((char const *)BLE_DEVICE_NAME),
								B_Data_Write_Pkt_Resp,
								CMD_PC_WRITE,
								1,
								(uint8_t *)BLE_DEVICE_NAME);
		BLE_CS_HIGH();
		GiveSPIBusLock();

		/* Wait for receiving ACK */
		xTaskNotifyWait( CLEAR_BITS_ONENTRY, ULONG_MAX ,
					&cNotifiedValue, PS_BLE_TASK_TIMEOUT);
		if(cNotifiedValue & (1<<BLE_WKUP_EVENT))
		{
			bluetooth_module_state = TRUE;
		}
	}

	return PS_SUCCESS;
}

static void BLEWakeupExternal_interrupt_init(void)
{

	GPIO_InitTypeDef GPIO_InitStruct1= {0};

	/* Initialize the BLE Wake up Pin as Interrupt */
	/* Make the BLE_WAKEUP Pin to input */
	GPIO_InitStruct1.Pin = GPIO_PIN_6;
	GPIO_InitStruct1.Mode = GPIO_MODE_IT_RISING_FALLING;
	GPIO_InitStruct1.Pull = GPIO_PULLUP;
	GPIO_InitStruct1.Speed = GPIO_SPEED_FREQ_HIGH;
	HAL_GPIO_Init(GPIOF, &GPIO_InitStruct1);
}

static void BLE_CS_init(void)
{

	GPIO_InitTypeDef GPIO_InitStruct1= {0};

    /* Make the CS pin to Output */
    GPIO_InitStruct1.Pin = GPIO_PIN_7;
    GPIO_InitStruct1.Mode = GPIO_MODE_OUTPUT_PP;
    GPIO_InitStruct1.Pull = GPIO_NOPULL;
    GPIO_InitStruct1.Speed = GPIO_SPEED_FREQ_HIGH;
    HAL_GPIO_Init(GPIOF, &GPIO_InitStruct1);
    HAL_GPIO_WritePin(GPIOF, GPIO_PIN_7, GPIO_PIN_SET);
}


/**
  * @brief : IS_SPI_Data_Available
  BLE Data will be read through SPI
  * @param None
  * @note
  * @retval True or False
  */
/** @brief IS_SPI_Data_Available
 *
 *  This function checks whether any BLE data is availble
 *  in the BLE chip.
 *
 *  @param  none
 *
 *  @return TRUE : SUCCESS
 *          FALSE: Failure
 *
 */
uint8_t IS_BLE_Data_Available()
{
	/* Clear the buffer */
	memset(&pv.blerxpkt[0], 0x00, sizeof(pv.blerxpkt));

    /* Select the BLE: Chip Select low	*/
	TakeSPIBusLock();
	BLE_CS_LOW();

	while (HAL_SPI_Receive(pv.hspi1, &pv.blerxpkt[0], sizeof(pv.blerxpkt), sizeof(pv.blerxpkt)*2 ) == HAL_BUSY)
	{
		HAL_Delay(1);
    };

    /* Select the BLE: Chip Select high */
	BLE_CS_HIGH();
	GiveSPIBusLock();


	return TRUE;
}

/** @brief Process the BLE USER packet
 *
 *  This function processes the received BLE packet from the
 *  Host PC.
 *
 *  @param  rxpkt : Received Packet
 *          rxlen : Received Packet length
 *
 *  @return none
 *
 */
void Process_USER_BLE_RX_Packet(uint8_t *rxpkt, uint8_t rxlen)
{
	uint8_t  flag;
	/* Check the packet size */
	if((rxpkt[3]-2) > DB_MAX_VAL_SIZE)
		return;

	/* Set the data into the DB */
	Set_DL(BLE_RX_DATA, &rxpkt[5]);

	/* Set Status of the RX buffer */
	flag = BLE_RX_MSG_PENDING;
	Set_DL(BLE_RX_BUFFER_STATUS, &flag);

}

/** @brief Process the received BLE packet
 *
 *  This function processes the received BLE packet from the
 *  Host PC terminal and sends the response to the BLE
 *  Terminal Software.
 *
 *  @param  rxpkt : Received Packet
 *          rxlen : Received Packet length
 *
 *  @return none
 *
 */
void Process_BLE_Received_Data(uint8_t *rxpkt, uint8_t rxlen)
{
	uint8_t senddata = TRUE;

	/* Check for the NULL pointer */
	if (NULL == rxpkt)
		return;

	/* Validate the header */
	if (((RXMODE != rxpkt[0]) && (TXMODE != rxpkt[0])) &&
			(DEST_ADDRESS != rxpkt[1]) &&
		    (TOOL_ADDRESS != rxpkt[2]))
		return;

	/* Check for the USER Packet */
	if (userPacket == rxpkt[4])
	{
		Process_USER_BLE_RX_Packet(rxpkt, rxlen);
		return;
	}

	if ((ECUReset == rxpkt[4]) ||
		(readECUIdentification == rxpkt[4]) ||
		(readDataByCommonIdentifier == rxpkt[4]) ||
		(readMemoryByAddress == rxpkt[4]) ||
		(writeDataByCommonIdentifier == rxpkt[4]) ||
		(writeMemoryByAddress == rxpkt[4]))
	{
	    /* Check for the communication started */
		/* if not started, discard the packet */
	    if (FALSE == pv.blestart_com)
	    {
	    	return;
	    }
	}

	switch(rxpkt[4])
	{
		case startCOM :
		    if (SUCCESS == SetstartCOM(rxpkt, &rxlen))
		    {
		    	pv.blestart_com = TRUE;
		    }
			break;
		case stopCOM :
			if (SUCCESS == SetstopCOM(rxpkt, &rxlen))
			{
				pv.blestart_com = FALSE;
			}
			break;
		case ECUReset :
			SetecuReset(rxpkt, &rxlen);
			break;
		case readECUIdentification :
		    GetreadEcuIdentification(rxpkt, &rxlen);
			break;
		case readDataByCommonIdentifier :
		    GetreadDataByCommonIdentifier(rxpkt, &rxlen);
			break;
		case readMemoryByAddress :
		     GetreadMemoryByAddress(rxpkt, &rxlen);
			break;
		case writeDataByCommonIdentifier :
		     SetwriteDataByCommonIdentifier(rxpkt, &rxlen);

			break;
		case accessTimParameters :
		case testerPresent :
		case startDiagnosticSession :
		case stopDiagnosticSession :
		case securityAccess :
		case readDataByLocalIdentifier :
		case dynamicallyDefineLocalIdentifier :
		case writeDataByLocalIdentifier :
		case setDataRates :
		case stopRepeatedDataTransmission :
		case readDiagnosticTroubleCodes :
			senddata = FALSE;
		default:
			break;
	}

	if ((FALSE == senddata) || (0 == rxlen))
		return;

	/* Send the packet to the BLE */
    /*	Select the BLE: Chip Select low	*/
	TakeSPIBusLock();
	BLE_CS_LOW();

	SPI_Send(rxpkt, rxlen);

    /* Deselect the BLE: Chip Select high */
	BLE_CS_HIGH();
	GiveSPIBusLock();


}

/** @brief BLE Platform service task
 *
 *  This function starts the BLE Platform Service
 *  task.
 *
 *  @param  pvParameters : Task Private structure
 *
 *  @return none
 *
 */
void BLE_ServiceStart(void *pvParameters)
{
	uint32_t cNotifiedValue;
	uint32_t addr;
	uint8_t *blebuf;
	uint8_t res;
	uint8_t func;
	uint8_t data_len;
    TickType_t  th_timeout = PS_BLE_TASK_TIMEOUT;
    uint8_t Init_SDK_Done = 0;

#if (SDK_CAM_BLE_STOP == PS_ENABLE)
	StartStopSDKServiceReg(Stop_BLE_Service);
#endif

#if (SDK_SERVICE_PM == PS_ENABLE)
	/* Register the Power Mode callback */
	PM_Register_Callback(BLE_deinit,NULL,BLE_reinit);
#endif

	/* Initialize the BLE Wakeup pin as interrupt */
	BLEWakeupExternal_interrupt_init();
	/* Make the CS pin to Output */
	BLE_CS_init();

	while(1)
	{

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
		/* Ping the watchdog timer */
		res = SetWD(WD_PING_BLE_TASK);

		if(res != SUCCESS)
		{
			LOGERROR("BLE Task failed to ping the WD Timer\r\n");
		}
#endif

		if(bluetooth_module_state == FALSE)
		{
		  Get_DL(IS_PS_INIT_DONE, &Init_SDK_Done);
		  if(Init_SDK_Done == TRUE)
		  {
			/*turn on ble when the SDK is ready*/
			HAL_GPIO_WritePin(GPIOI, GPIO_PIN_8, GPIO_PIN_SET);
			BLE_DB_Init();
		  }
		  else
		  {
			/*no init*/
			bluetooth_module_state = FALSE;
		  }
		}
		else
		{
		/* Wait for receiving the Event from the SDK API */
		res = xTaskNotifyWait( CLEAR_BITS_ONENTRY, ULONG_MAX , &cNotifiedValue, th_timeout);

		if(res != pdTRUE)
		{
			continue;
		}

#if (SDK_CAM_BLE_STOP == PS_ENABLE)

		/* Camera is streaming, stop the SDK thread */
		if ((cNotifiedValue & (1<< BLE_CAM_STOP_EVENT)) &&
				(pv.ble_cam_state != BLE_THREAD_STATE_STOP))
		{
			pv.ble_cam_state = WL_THREAD_STATE_STOP;
		    th_timeout = portMAX_DELAY;

			/* Update the result */
			blebuf[BLE_RESULT_INDEX] = SUCCESS;

			/* Send the response to the SDK API */
			xQueueSend( pv.blerxq, ( void * )&blebuf, ( TickType_t ) Q_TICKSTOWAIT );

			continue;
		}

		/* Camera is stopped streaming, start the SDK thread */
		if ((cNotifiedValue & (1<< BLE_CAM_START_EVENT)) &&
			(pv.ble_cam_state != BLE_THREAD_STATE_RUN))
		{
			pv.ble_cam_state = BLE_THREAD_STATE_RUN;
			th_timeout = PS_BLE_TASK_TIMEOUT;
			/* Update the result */
			blebuf[BLE_RESULT_INDEX] = SUCCESS;

			/* Send the response to the SDK API */
			xQueueSend( pv.blerxq, ( void * )&blebuf, ( TickType_t ) Q_TICKSTOWAIT );
		    continue;
		}

		/* Receive any event, do not accept. Since the camera is running */
		if (BLE_THREAD_STATE_STOP == pv.ble_cam_state)
		{
			/* Update the result */
			blebuf[BLE_RESULT_INDEX] = FAILURE;

			/* Send the response to the SDK API */
			xQueueSend( pv.blerxq, ( void * )&blebuf, ( TickType_t ) Q_TICKSTOWAIT );

			continue;
		}
#endif

		if(cNotifiedValue & (1<<BLE_WKUP_EVENT))
		{
			/*check for any data availbale*/
			if ( TRUE == IS_BLE_Data_Available())
			{
				/* Process the Receive Thread */
				Process_BLE_Received_Data(&pv.blerxpkt[0], 6);

				/* Update the TX status to the DB */
				if (TRUE == pv.bletx_status)
				{
					pv.bletx_status = FALSE;
					Set_DL(BLE_TX_STATUS, &pv.bletx_status);

					data_len = BLE_TX_BUFF_NOTFULL;
					Set_DL(BLE_TX_BUFFER_STATUS, &data_len);
				}
			}
		}

		if (cNotifiedValue & (1<<BLE_MSG_EVENT))
		{
				/* Receive Message from the BLE SDK API */
				res = xQueueReceive(pv.bletxq, &blebuf , ( TickType_t ) 100 );

				if(res != pdTRUE)
				{
					break;
				}

				func = blebuf[BLE_FUNC_INDEX];

				/* Update the result */
				blebuf[BLE_RESULT_INDEX] = SUCCESS;

				switch(func)
				{
					case BLE_SET:

					    //if (TRUE == pv.blestart_com)
					    {
	                        /* Get the data address from the packet */
						    memcpy(&addr, (uint8_t *)&blebuf[BLE_DATA_INDEX], sizeof(addr));

						    /* Get the data len */
						    memcpy(&data_len, (uint8_t *)&blebuf[BLE_LEN_INDEX + sizeof(addr)], sizeof(data_len));

							/* Construct the packet */
							pv.bletxpkt[PKT_MODE_INDEX] = TXMODE;
							pv.bletxpkt[PKT_DADR_INDEX] = DEST_ADDRESS;
							pv.bletxpkt[PKT_TADR_INDEX] = TOOL_ADDRESS;

							pv.bletxpkt[PKT_SIZE_INDEX] = data_len + 2;

							/* Copy the packet to the BLE packet */
							memcpy(&pv.bletxpkt[PKT_SIZE_INDEX+1], (uint8_t *)addr, data_len);

							/* Update the checksum */
							pv.bletxpkt[CMD_PKT_HEADER_SIZE + data_len + 2] =
									CalCheckSum(&pv.bletxpkt[PKT_SIZE_INDEX+1], data_len + 2);

							/* Send the data Packet */
						    TakeSPIBusLock();
						    Send_BLE_PKT((uint8_t *)&pv.bletxpkt[0], CMD_PKT_HEADER_SIZE + data_len + 3);
							GiveSPIBusLock();

							/* Wait for the transfer complete */
							pv.bletx_status = TRUE;
					    }

						break;

					case BLE_GET:

                        /* Get the data address from the packet */
					    memcpy(&addr, (uint8_t *)&blebuf[BLE_DATA_INDEX], sizeof(addr));

					    /* Get the data len */
					    memcpy(&data_len, (uint8_t *)&blebuf[BLE_LEN_INDEX + sizeof(addr)], sizeof(data_len));

						/* Send the data Packet */
					    TakeSPIBusLock();
						Send_BLE_Data(data_len, B_Data_Read_Pkt_Req, CMD_PC_READ, 1, (uint8_t *)addr);
						GiveSPIBusLock();
						break;
				}

				/* Send the response to the SDK API */
				xQueueSend( pv.blerxq, ( void * )&blebuf, ( TickType_t ) Q_TICKSTOWAIT );
		}
	  }
	}
}

/** @brief Start BLE Platform service
 *
 *  This function initializes the following modules
 *     ===> BLE DB
 *     ===> BLE platform driver
 *     ===> BLE software resources
 *     ===> Start the BLE service
 *
 *  @param  None
 *
 *  @return 0 : PS_SUCCESS
 *          1 : PS_FAILURE
 *
 */
int8_t BLE_PS_Start(void)
{
	BaseType_t xReturned;

	/* Create BLE TxQ for receiving value from the SDK API */
	pv.bletxq = xQueueCreate( BLE_RX_TX_MAX_Q_SIZE, sizeof(uint32_t*));
	if(NULL == pv.bletxq)
	{
		LOGERROR("Unable to initialize the BLE TxQ\r\n");
		return PS_FAILURE;
	}

	/* Create BLE RxQ for sending return value to the SDK API */
	pv.blerxq = xQueueCreate( BLE_RX_TX_MAX_Q_SIZE, sizeof(uint32_t*));
	if(NULL == pv.blerxq)
	{
		LOGERROR("Unable to initialize the BLE RxQ\r\n");
		return PS_FAILURE;
	}

	/* Start the BLE Platform service thread */
	xReturned = xTaskCreate(BLE_ServiceStart, "BLE",
			512, NULL, PS_BLE_TASK_PRIORITY,   &pv.ble_task);

	if (xReturned != pdPASS)
	{
		LOGERROR("Unable to initialize the BLE Thread\r\n");
		return PS_FAILURE;
	}

	LOGERROR("BLE Platform Service task created Successfully \r\n");

	return PS_SUCCESS;
}
#endif	//SDK_SERVICE_BLE

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
