/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : Conf_platformservice.c
   Author             : Rajesh
   Version            : V0.0.0.1
   Origination Date   : 21/01/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file configures USER provided default configuration into the DB and
   peripherals

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             21/01/2022           Rajesh

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../Inc/Common.h"
/* USER CODE END Includes */

/* USER PV BEGIN */
extern pvt_variable pv;

/* Interface function for the Warninglight */
#if ((SDK_SERVICE_WARNING_LIGHT == PS_ENABLE) || \
		(SDK_SERVICE_LED == PS_ENABLE) ||        \
		(SDK_SERVICE_CFG_INPUT == PS_ENABLE) ||  \
		(SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE))
extern I2C_HandleTypeDef hi2c3;
#endif

#if (SDK_SERVICE_RTC == PS_ENABLE)
extern RTC_HandleTypeDef hrtc;
#endif

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
extern IWDG_HandleTypeDef hiwdg1;
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
extern TIM_HandleTypeDef htim1;
#endif

#if (SDK_SERVICE_SDRAM == PS_ENABLE)
extern SDRAM_HandleTypeDef hsdram1;
#endif

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
extern ADC_HandleTypeDef hadc1;
extern ADC_HandleTypeDef hadc3;
extern TIM_HandleTypeDef htim2;
extern TIM_HandleTypeDef htim3;
extern TIM_HandleTypeDef htim13;
extern TIM_HandleTypeDef htim14;
#endif

#if (SDK_SERVICE_SWTIMER == PS_ENABLE)
extern TIM_HandleTypeDef htim4;
extern TIM_HandleTypeDef htim16;
extern TIM_HandleTypeDef htim7;
extern TIM_HandleTypeDef htim8;
extern TIM_HandleTypeDef htim12;
extern TIM_HandleTypeDef htim17;
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE || \
		(SDK_SERVICE_BLE == PS_ENABLE))
extern SPI_HandleTypeDef hspi1;
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
extern CRC_HandleTypeDef hcrc;
#endif

#if (SDK_SERVICE_FDCAN == PS_ENABLE)
extern FDCAN_HandleTypeDef hfdcan1;
extern FDCAN_HandleTypeDef hfdcan2;
#endif

/* USER PV END */

/* USER CODE BEGIN 0 */

/** @brief Enable power down
 *
 *  This function write the Power Down pin to SET.
 *
 *  @param  None
 *
 *  @return None
 *
 */
void Enable_Powerdown(void)
{
	FMC_Bank1_R->BTCR[0] &= ~FMC_BCRx_MBKEN;
	SCnSCB->ACTLR |= 0x2;

	/*Configure GPIO pin Output Level */
	HAL_GPIO_WritePin(PWRDWN_GPIO_Port, PWRDWN_Pin, GPIO_PIN_SET);
	HAL_Delay(10);

#if (SDK_SERVICE_SDRAM == PS_ENABLE)
	HAL_FMC_SDRAM_Configure();
#endif

	/*Configure GPIO pin Output Level */
	HAL_GPIO_WritePin(DISP_EN_GPIO_Port, DISP_EN_Pin, GPIO_PIN_SET);
	HAL_Delay(10);
}

/* USER CODE END 0 */

/** @brief Configuration Platform service
 *
 *  This function starts the Configuration Platform Service
 *
 *
 *  @param  pvParameters - Private data pointer
 *
 *  @return None
 *
 */
void Conf_ServiceStart(void *pvParameters)
{
	uint8_t val;

#if (SDK_SERVICE_SDRAM == PS_ENABLE)
	pv.hsdram1 = &hsdram1;
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE || \
		(SDK_SERVICE_BLE == PS_ENABLE))
	/* Get the SPI Handle */
	pv.hspi1 = &hspi1;
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
	pv.hcrc  = &hcrc;
#endif

#if (SDK_SERVICE_FDCAN == PS_ENABLE)

#if (FDCAN1_ENABLE == PS_ENABLE)
	/* Get the CAN Handle */
	pv.hfdcan1 = &hfdcan1;

	PS_FDCAN1_Init(FDCAN1_BAUDRATE);
#endif

#if (FDCAN2_ENABLE == PS_ENABLE)
	/* Get the CAN Handle */
	pv.hfdcan2 = &hfdcan2;

	PS_FDCAN2_Init(FDCAN2_BAUDRATE);
#endif

#endif

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
	/* Get the ADC1 Handle */
	pv.hadc1 = &hadc1;
	/* Get the ADC3 Handle */
	pv.hadc3 = &hadc3;
	/* Get the TIM2 Handle */
	pv.htim2 = &htim2;
	/* Get the TIM3 Handle */
	pv.htim3 = &htim3;
	/* Get the TIM13 Handle */
	pv.htim13 = &htim13;
	/* Get the TIM14 Handle */
	pv.htim14 = &htim14;

	ADC_Initialization();

	Timer_Initialization();
#endif

#if (SDK_SERVICE_SWTIMER == PS_ENABLE)

	/* Get the timer Handle */
	pv.htim4 = &htim4;
	pv.htim7 = &htim7;
	pv.htim8 = &htim8;
	pv.htim12 = &htim12;
	pv.htim17 = &htim17;
	pv.htim16 = &htim16;

	/* Start the PS_Timer4 */
	PS_TIM4_Init();

	/* Start the PS_Timer7 */
	PS_TIM7_Init();

	/* Start the PS_Timer8 */
	PS_TIM8_Init();

	/* Start the PS_Timer12 */
	PS_TIM12_Init();

	/* Start the PS_Timer15 */
	PS_TIM17_Init();

	/* Start the PS_Timer16 */
	PS_TIM16_Init();

#endif

	/* Enable the power down GPIO */
	Enable_Powerdown();
	/*
	 * Register the Callback function for the each DB field
	 * for validating the field
     */
	DB_u8_Field_Validation_Reg();
	DB_u16_Field_Validation_Reg();
	DB_float_Field_Validation_Reg();
	DB_u32_Field_Validation_Reg();
	DB_EEPROM_Field_Validation_Reg();
	DB_Buf_Field_Validation_Reg();
	DB_ju8_Field_Validation_Reg();
	DB_ju16_Field_Validation_Reg();
	DB_ju32_Field_Validation_Reg();


#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
	/* Get the Watchdog Handle */
	pv.iwdg = &hiwdg1;
#endif

	/* Initialize the I2C interface for the Warning Light */
#if ((SDK_SERVICE_WARNING_LIGHT == PS_ENABLE) || \
		(SDK_SERVICE_LED == PS_ENABLE) ||        \
		(SDK_SERVICE_CFG_INPUT == PS_ENABLE) ||  \
		(SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE))
	pv.hi2c = &hi2c3;

	/* Initialize the IO Expander Software resource */
	Init_IOExpander(pv.hi2c);
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
	/* Initialize the LCD DB fields */
	pv.htim1 = &htim1;
#endif

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)
	/* Initialize the CI DB fields */
	CI_DB_Init();
#endif

#if (SDK_SERVICE_POWER_MONITOR == PS_ENABLE)
	PowerMonitor_DB_Init();
#endif

#if (SDK_SERVICE_WARNING_LIGHT == PS_ENABLE)
	/* Configure the User provided default configuration of the
	 * Warning light */
	Warning_Light_DB_Init();
#endif

#if (SDK_SERVICE_KEYPAD == PS_ENABLE)
	/* Initialize the Keypad DB fields */
	Keypad_DB_Init();
#endif

#if (SDK_SERVICE_RTC == PS_ENABLE)
	/* Get the RTC Handle */
	pv.hrtc = &hrtc;
#endif

#if (SDK_SERVICE_PM == PS_ENABLE)
	/* Initialize the PM DB fields */
	PM_DB_Init();
#endif

#if (SDK_SERVICE_DIGITAL_OUTPUT == PS_ENABLE)
	/* Initialize the DIO DB fields */
	DIO_DB_Init();
#endif

#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)
	/* Initialize the LS DB fields */
	LS_DB_Init();
#endif

#if (SDK_SERVICE_LED == PS_ENABLE)
	/* Initialize the LED DB fields */
	LED_DB_Init();
#endif

#if (SDK_SERVICE_LCD == PS_ENABLE)
	/* Initialize the LCD DB fields */
	Lcd_DB_Init();
#endif


#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
	/* Initialize the Watchdog DB fields */
	Watchdog_DB_Init();
#endif

#if (SDK_SERVICE_USB == PS_ENABLE)
	/* Initialize the USB DB fields */
	USB_DB_Init();
#endif

#if (SDK_SERVICE_CAMERA == PS_ENABLE)
	/* Initialize the Camera DB fields */
	Camera_DB_Init();
#endif

#if (SDK_SERVICE_FDCAN == PS_ENABLE)
	FDCAN_DB_Init();
#endif

#if (SDK_SERVICE_EEPROM == PS_ENABLE)
	/* Initialize the EEPROM DB fields */
	EEPROM_DB_Init();
#endif

	/* Platform Initialization has been done here */
	/* Update the DB flag                         */
	val = TRUE;
	Set_DL(IS_PS_INIT_DONE, &val);

	/* Delete this task */
	vTaskDelete( pv.Conf_task );

}

/** @brief Start Configuration Platform service
 *
 *  This function creates the configuration task
 *  for configuring the peripheral device with the default
 *  values.
 *
 *  @param  None
 *
 *  @return 0 : PS_SUCCESS
 *         -1 : PS_FAILURE
 *
 */
int8_t Conf_PS_Start(void)
{
	BaseType_t xReturned;

	/* Create the config platform service task */
	xReturned = xTaskCreate(Conf_ServiceStart, "ConfService",
			512, NULL, osPriorityNormal,   &pv.Conf_task);

    if( xReturned != pdPASS )
    {
		LOGERROR("Unable to initialize the Configuration Service Task\r\n");
		return PS_FAILURE;
    }

    LOGERROR("Configuration service task created Successfully \r\n");

	return PS_SUCCESS;
}

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
