/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : Frequency_Timer_Init.c
   Author             : Zaid
   Version            : V0.0.0.2
   Origination Date   : 04/02/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the Frequency Timer platform service initialization

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             04/02/2022           Zaid
   0.0.0.2             10/04/2022           FOC (Corrected period and pre-scaler values)

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../Inc/common.h"
#include "../../../Drivers/Maximatecc/inc/Input_Frequency.h"
#include "../Inc/Frequency_Timer_Init.h"
/* USER CODE END Includes */

#if (SDK_SERVICE_CFG_INPUT == PS_ENABLE)

extern ci_conf_param ci_conf[MAX_NUM_CFG_INPUT];
extern pvt_variable pv;
extern uint8_t ci_frequency_1;
extern uint8_t ci_frequency_2;
extern uint8_t ci_frequency_3;
extern uint8_t ci_frequency_4;
extern uint8_t ci_frequency_5;
/**
  * @brief Timer Initialization Function
  * @param None
  * @retval None
  */
void Timer_Initialization(void)
{
	Timer2_Init();
	Timer3_Init();
	Timer13_Init();
	Timer14_Init();
}

/**
* @brief TIM2 Initialization Function
* @param None
* @retval None
*/
void Timer2_Init(void)
{
	/* USER CODE BEGIN TIM2_Init 0 */
	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_IC_DeInit(pv.htim2);
	/* USER CODE END TIM2_Init 0 */

	TIM_MasterConfigTypeDef sMasterConfig = {0};
	TIM_IC_InitTypeDef sConfigIC = {0};

	/* USER CODE BEGIN TIM2_Init 1 */

	/* USER CODE END TIM2_Init 1 */
	pv.htim2->Instance = TIM2;
	pv.htim2->Init.Prescaler = 430;
	pv.htim2->Init.CounterMode = TIM_COUNTERMODE_UP;
	pv.htim2->Init.Period = PERIOD_TIM_2;
	pv.htim2->Init.ClockDivision = TIM_CLOCKDIVISION_DIV1;
	pv.htim2->Init.AutoReloadPreload = TIM_AUTORELOAD_PRELOAD_DISABLE;
	if (HAL_TIM_IC_Init(pv.htim2) != HAL_OK)
	{
		Error_Handler();
	}

	/* Deinitialize Default IOC Generated configuration */
	//HAL_TIM_IC_MspDeInit(pv.htim2);
	if(ci_frequency_3 == INPUT_FREQUENCY)
	{
		 HAL_GPIO_DeInit(GPIOA, GPIO_PIN_1);
	}
	if(ci_frequency_4 == INPUT_FREQUENCY)
	{
		 HAL_GPIO_DeInit(GPIOA, GPIO_PIN_0);
	}

	/* Reinitialize timer with user defined */
	HAL_TIM_Base_MspInit_2(pv.htim2);

	sMasterConfig.MasterOutputTrigger = TIM_TRGO_RESET;
	sMasterConfig.MasterSlaveMode = TIM_MASTERSLAVEMODE_DISABLE;
	if (HAL_TIMEx_MasterConfigSynchronization(pv.htim2, &sMasterConfig) != HAL_OK)
	{
		Error_Handler();
	}

	sConfigIC.ICPolarity = TIM_INPUTCHANNELPOLARITY_RISING;
	sConfigIC.ICSelection = TIM_ICSELECTION_DIRECTTI;
	sConfigIC.ICPrescaler = TIM_ICPSC_DIV1;
	sConfigIC.ICFilter = 0;

	if(ci_frequency_4 == INPUT_FREQUENCY)
	{
		if (HAL_TIM_IC_ConfigChannel(pv.htim2, &sConfigIC, TIM_CHANNEL_1) != HAL_OK)/*AIN4*/
		{
			Error_Handler();
		}
		ci_frequency_4 = 0;
		FreqAI_Start(4);
	}

	if(ci_frequency_3 == INPUT_FREQUENCY)
	{
		if (HAL_TIM_IC_ConfigChannel(pv.htim2, &sConfigIC, TIM_CHANNEL_2) != HAL_OK)/*AIN3*/
		{
			Error_Handler();
		}
		ci_frequency_3 = 0;
		FreqAI_Start(3);
	}
}

/**
 * @brief TIM3 Initialization Function
 * @param None
 * @retval None
 */
void Timer3_Init(void)
{
	/* USER CODE BEGIN TIM3_Init 0 */
	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_IC_DeInit(pv.htim3);
	/* USER CODE END TIM3_Init 0 */

	TIM_MasterConfigTypeDef sMasterConfig = {0};
	TIM_IC_InitTypeDef sConfigIC = {0};

	/* USER CODE BEGIN TIM3_Init 1 */
	pv.htim3->Instance = TIM3;
	pv.htim3->Init.Prescaler = 430;
	pv.htim3->Init.CounterMode = TIM_COUNTERMODE_UP;
	pv.htim3->Init.Period = PERIOD_TIM_3;
	pv.htim3->Init.ClockDivision = TIM_CLOCKDIVISION_DIV1;
	pv.htim3->Init.AutoReloadPreload = TIM_AUTORELOAD_PRELOAD_DISABLE;
	if (HAL_TIM_IC_Init(pv.htim3) != HAL_OK)
	{
		Error_Handler();
	}

	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_IC_MspDeInit(pv.htim3);

	/* Reinitialize timer with user defined */
	HAL_TIM_Base_MspInit_2(pv.htim3);

	sMasterConfig.MasterOutputTrigger = TIM_TRGO_RESET;
	sMasterConfig.MasterSlaveMode = TIM_MASTERSLAVEMODE_DISABLE;
	if (HAL_TIMEx_MasterConfigSynchronization(pv.htim3, &sMasterConfig) != HAL_OK)
	{
		Error_Handler();
	}

	sConfigIC.ICPolarity = TIM_INPUTCHANNELPOLARITY_RISING;
	sConfigIC.ICSelection = TIM_ICSELECTION_DIRECTTI;
	sConfigIC.ICPrescaler = TIM_ICPSC_DIV1;
	sConfigIC.ICFilter = 0;

	if(ci_frequency_5 == INPUT_FREQUENCY)
	{
		if(HAL_TIM_IC_ConfigChannel(pv.htim3, &sConfigIC, TIM_CHANNEL_2) != HAL_OK)
		{
			Error_Handler();
		}
		ci_frequency_5 = 0;
		FreqAI_Start(5);
	}
}

/**
  * @brief TIM13 Initialization Function
  * @param None
  * @retval None
  * */
void Timer13_Init(void)
{
	/* USER CODE BEGIN TIM13_Init 0 */
	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_Base_DeInit(pv.htim13);
	HAL_TIM_IC_DeInit(pv.htim13);
	/* USER CODE END TIM13_Init 0 */

	TIM_IC_InitTypeDef sConfigIC = {0};

	/* USER CODE BEGIN TIM13_Init 1 */

	/* USER CODE END TIM13_Init 1 */
	pv.htim13->Instance = TIM13;
	pv.htim13->Init.Prescaler = 430;
	pv.htim13->Init.CounterMode = TIM_COUNTERMODE_UP;
	pv.htim13->Init.Period = PERIOD_TIM_13;
	pv.htim13->Init.ClockDivision = TIM_CLOCKDIVISION_DIV1;
	pv.htim13->Init.AutoReloadPreload = TIM_AUTORELOAD_PRELOAD_DISABLE;
	if (HAL_TIM_Base_Init(pv.htim13) != HAL_OK)
	{
		Error_Handler();
	}

	if (HAL_TIM_IC_Init(pv.htim13) != HAL_OK)
	{
		Error_Handler();
	}

	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_Base_MspDeInit(pv.htim13);
	HAL_TIM_IC_MspDeInit(pv.htim13);

	/* Reinitialize timer with user defined */
	HAL_TIM_Base_MspInit_2(pv.htim13);

	sConfigIC.ICPolarity = TIM_INPUTCHANNELPOLARITY_RISING;
	sConfigIC.ICSelection = TIM_ICSELECTION_DIRECTTI;
	sConfigIC.ICPrescaler = TIM_ICPSC_DIV1;
	sConfigIC.ICFilter = 0;

	if(ci_frequency_1 == INPUT_FREQUENCY)
	{
		if (HAL_TIM_IC_ConfigChannel(pv.htim13, &sConfigIC, TIM_CHANNEL_1) != HAL_OK)
		{
			Error_Handler();
		}
		ci_frequency_1 = 0;
		FreqAI_Start(1);
	}
}

/**
  * @brief TIM14 Initialization Function
  * @param None
  * @retval None
  * */
void Timer14_Init(void)
{
	/* USER CODE BEGIN TIM14_Init 0 */
	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_Base_DeInit(pv.htim14);
	HAL_TIM_IC_DeInit(pv.htim14);
	/* USER CODE END TIM14_Init 0 */

	TIM_IC_InitTypeDef sConfigIC = {0};

	/* USER CODE BEGIN TIM14_Init 1 */

	/* USER CODE END TIM14_Init 1 */
	pv.htim14->Instance = TIM14;
	pv.htim14->Init.Prescaler = 430;
	pv.htim14->Init.CounterMode = TIM_COUNTERMODE_UP;
	pv.htim14->Init.Period = PERIOD_TIM_14;
	pv.htim14->Init.ClockDivision = TIM_CLOCKDIVISION_DIV1;
	pv.htim14->Init.AutoReloadPreload = TIM_AUTORELOAD_PRELOAD_DISABLE;
	if (HAL_TIM_Base_Init(pv.htim14) != HAL_OK)
	{
		Error_Handler();
	}

	if (HAL_TIM_IC_Init(pv.htim14) != HAL_OK)
	{
		Error_Handler();
	}

	/* Deinitialize Default IOC Generated configuration */
	HAL_TIM_Base_MspDeInit(pv.htim14);
	HAL_TIM_IC_MspDeInit(pv.htim14);

	/* Reinitialize timer with user defined */
	HAL_TIM_Base_MspInit_2(pv.htim14);

	sConfigIC.ICPolarity = TIM_INPUTCHANNELPOLARITY_RISING;
	sConfigIC.ICSelection = TIM_ICSELECTION_DIRECTTI;
	sConfigIC.ICPrescaler = TIM_ICPSC_DIV1;
	sConfigIC.ICFilter = 0;

	if(ci_frequency_2 == INPUT_FREQUENCY)
	{
		if (HAL_TIM_IC_ConfigChannel(pv.htim14, &sConfigIC, TIM_CHANNEL_1) != HAL_OK)
		{
			Error_Handler();
		}
		ci_frequency_2 = 0;
		FreqAI_Start(2);
	}
}

/**
* @brief TIM_Base MSP Initialization
* This function configures the hardware resources used in this example
* @param htim_base: TIM_Base handle pointer
* @retval None
*/
void HAL_TIM_Base_MspInit_2(TIM_HandleTypeDef* htim_base)
{
	GPIO_InitTypeDef GPIO_InitStruct = {0};

	if(htim_base->Instance==TIM2)
	{
		/* USER CODE BEGIN TIM2_MspInit 0 */

		/* USER CODE END TIM2_MspInit 0 */
		/* Peripheral clock enable */
		__HAL_RCC_TIM2_CLK_ENABLE();
		__HAL_RCC_GPIOA_CLK_ENABLE();

		/**TIM2 GPIO Configuration
		 * PA0/WKUP     ------> TIM2_CH1
		 * PA1     ------> TIM2_CH2
		 * */
		if(ci_frequency_4 == INPUT_FREQUENCY)
		{
			GPIO_InitStruct.Pin = GPIO_PIN_0;
			GPIO_InitStruct.Mode = GPIO_MODE_AF_PP;
			GPIO_InitStruct.Pull = GPIO_NOPULL;
			GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_LOW;
			GPIO_InitStruct.Alternate = GPIO_AF1_TIM2;
			HAL_GPIO_Init(GPIOA, &GPIO_InitStruct);
		}

		if(ci_frequency_3 == INPUT_FREQUENCY)
		{
			GPIO_InitStruct.Pin = GPIO_PIN_1;
			GPIO_InitStruct.Mode = GPIO_MODE_AF_PP;
			GPIO_InitStruct.Pull = GPIO_NOPULL;
			GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_LOW;
			GPIO_InitStruct.Alternate = GPIO_AF1_TIM2;
			HAL_GPIO_Init(GPIOA, &GPIO_InitStruct);
		}

		/* TIM2 interrupt Init */
		HAL_NVIC_SetPriority(TIM2_IRQn, 15, 1);
		HAL_NVIC_EnableIRQ(TIM2_IRQn);
		/* USER CODE BEGIN TIM2_MspInit 1 */

		/* USER CODE END TIM2_MspInit 1 */
	}
	else if(htim_base->Instance==TIM3)
	{
		/* USER CODE BEGIN TIM3_MspInit 0 */

		/* USER CODE END TIM3_MspInit 0 */
		/* Peripheral clock enable */
		__HAL_RCC_TIM3_CLK_ENABLE();

		__HAL_RCC_GPIOA_CLK_ENABLE();
		__HAL_RCC_GPIOB_CLK_ENABLE();

		/**TIM3 GPIO Configuration
		 * PA7     ------> TIM3_CH2
		 * PB0     ------> TIM3_CH3
		 * */
		if(ci_frequency_5 == INPUT_FREQUENCY)
		{
			GPIO_InitStruct.Pin = GPIO_PIN_7;
			GPIO_InitStruct.Mode = GPIO_MODE_AF_PP;
			GPIO_InitStruct.Pull = GPIO_NOPULL;
			GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_LOW;
			GPIO_InitStruct.Alternate = GPIO_AF2_TIM3;
			HAL_GPIO_Init(GPIOA, &GPIO_InitStruct);
		}

		/* TIM3 interrupt Init */
		HAL_NVIC_SetPriority(TIM3_IRQn, 15, 1);
		HAL_NVIC_EnableIRQ(TIM3_IRQn);
		/* USER CODE BEGIN TIM3_MspInit 1 */

		/* USER CODE END TIM3_MspInit 1 */
	}
	else if(htim_base->Instance==TIM13)
	{
		/* USER CODE BEGIN TIM13_MspInit 0 */

		/* USER CODE END TIM13_MspInit 0 */
		/* Peripheral clock enable */
		__HAL_RCC_TIM13_CLK_ENABLE();

		__HAL_RCC_GPIOF_CLK_ENABLE();
		/**TIM13 GPIO Configuration
		 * PF8     ------> TIM13_CH1
		 * */
		if(ci_frequency_1 == INPUT_FREQUENCY)
		{
			GPIO_InitStruct.Pin = GPIO_PIN_8;
			GPIO_InitStruct.Mode = GPIO_MODE_AF_PP;
			GPIO_InitStruct.Pull = GPIO_NOPULL;
			GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_LOW;
			GPIO_InitStruct.Alternate = GPIO_AF9_TIM13;
			HAL_GPIO_Init(GPIOF, &GPIO_InitStruct);
		}

		/* TIM13 interrupt Init */
		HAL_NVIC_SetPriority(TIM8_UP_TIM13_IRQn, 15, 1);
		HAL_NVIC_EnableIRQ(TIM8_UP_TIM13_IRQn);
		/* USER CODE BEGIN TIM13_MspInit 1 */

		/* USER CODE END TIM13_MspInit 1 */
	}
	else if(htim_base->Instance==TIM14)
	{
		/* USER CODE BEGIN TIM14_MspInit 0 */

		/* USER CODE END TIM14_MspInit 0 */
		/* Peripheral clock enable */
		__HAL_RCC_TIM14_CLK_ENABLE();

		__HAL_RCC_GPIOF_CLK_ENABLE();
		/**TIM14 GPIO Configuration
		 * PF9     ------> TIM14_CH1
		 * */
		if(ci_frequency_2 == INPUT_FREQUENCY)
		{
			GPIO_InitStruct.Pin = GPIO_PIN_9;
			GPIO_InitStruct.Mode = GPIO_MODE_AF_PP;
			GPIO_InitStruct.Pull = GPIO_NOPULL;
			GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_LOW;
			GPIO_InitStruct.Alternate = GPIO_AF9_TIM14;
			HAL_GPIO_Init(GPIOF, &GPIO_InitStruct);
		}

		/* TIM14 interrupt Init */
		HAL_NVIC_SetPriority(TIM8_TRG_COM_TIM14_IRQn, 15, 1);
		HAL_NVIC_EnableIRQ(TIM8_TRG_COM_TIM14_IRQn);
		/* USER CODE BEGIN TIM14_MspInit 1 */

		/* USER CODE END TIM14_MspInit 1 */
	}
}

#endif
 /**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
 /***************************** END OF FILE *********************************/
