/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : SWTimer_platformservice.c
   Author             :	Adrush
   Version            : V0.0.0.1
   Origination Date   : 04/03/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the SWTimer platform service initialization

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             04/03/2022			Adrush

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../Inc/Common.h"

/* USER CODE END Includes */

/* USER CODE BEGIN Macros */

/* USER CODE END Macros */

/* USER CODE BEGIN Global Variables */
#if (SDK_SERVICE_SWTIMER == PS_ENABLE)
extern pvt_variable pv;

#define __TIMERTEST__
uint8_t count = 0;
/* USER CODE End Global Variables */

/**
  * @brief Platform Service TIM4 Initialization Function
  * @param None
  * @retval None
  */
void PS_TIM4_Init(void)
{
	RCC_ClkInitTypeDef    clkconfig;
	uint32_t              uwTimclock, uwAPB1Prescaler;
	uint32_t              uwPrescalerValue;
	uint32_t              pFLatency;

	/* Deinitialize the Timer4 */
	HAL_TIM_Base_DeInit(pv.htim4);

	HAL_NVIC_SetPriority(TIM4_IRQn, 15UL ,0U);
	/* Enable the TIM4 global Interrupt */
	HAL_NVIC_EnableIRQ(TIM4_IRQn);

	/* Enable TIM4 clock */
	__HAL_RCC_TIM4_CLK_ENABLE();

	/* Get clock configuration */
	HAL_RCC_GetClockConfig(&clkconfig, &pFLatency);

	/* Get APB1 prescaler */
	uwAPB1Prescaler = clkconfig.APB1CLKDivider;

	/* Compute TIM4 clock */
	if (uwAPB1Prescaler == RCC_HCLK_DIV1)
	{
		uwTimclock = HAL_RCC_GetPCLK1Freq();
	}
	else
	{
		uwTimclock = 2UL * HAL_RCC_GetPCLK1Freq();
	}

	/* Compute the prescaler value to have TIM4 counter clock equal to 1MHz */
	uwPrescalerValue = (uint32_t) ((uwTimclock / 1000000U) - 1U);

	/* Initialize TIM4 */
	pv.htim4->Instance = TIM4;

	/* Initialize TIMx peripheral as follow:
	 * Period = [(TIM4CLK/1000) - 1]. to have a (1/1000) s time base.
	 * Prescaler = (uwTimclock/1000000 - 1) to have a 1MHz counter clock.
	 * ClockDivision = 0
	 * Counter direction = Up
	 * */
	pv.htim4->Init.Period = (1000000U / 1000U) - 1U;
	pv.htim4->Init.Prescaler = (uwPrescalerValue);
	pv.htim4->Init.ClockDivision = 0;
	pv.htim4->Init.CounterMode = TIM_COUNTERMODE_UP;

	if(HAL_TIM_Base_Init(pv.htim4) != HAL_OK)
	{
		Error_Handler();
	}
}

/**
  * @brief Platform Service TIM7 Initialization Function
  * @param None
  * @retval None
  */
void PS_TIM7_Init(void)
{
	RCC_ClkInitTypeDef    clkconfig;
	uint32_t              uwTimclock, uwAPB1Prescaler;
	uint32_t              uwPrescalerValue;
	uint32_t              pFLatency;

	/* Deinitialize the Timer7 */
	HAL_TIM_Base_DeInit(pv.htim7);

	HAL_NVIC_SetPriority(TIM7_IRQn, 15UL ,0U);

	/* Enable the TIM7 global Interrupt */
	HAL_NVIC_EnableIRQ(TIM7_IRQn);

	/* Enable TIM7 clock */
	__HAL_RCC_TIM7_CLK_ENABLE();

	/* Get clock configuration */
	HAL_RCC_GetClockConfig(&clkconfig, &pFLatency);

	/* Get APB1 prescaler */
	uwAPB1Prescaler = clkconfig.APB1CLKDivider;

	/* Compute TIM7 clock */
	if (uwAPB1Prescaler == RCC_HCLK_DIV1)
	{
		uwTimclock = HAL_RCC_GetPCLK1Freq();
	}
	else
	{
		uwTimclock = 2UL * HAL_RCC_GetPCLK1Freq();
	}

	/* Compute the prescaler value to have TIM7 counter clock equal to 1MHz */
	uwPrescalerValue = (uint32_t) ((uwTimclock / 1000000U) - 1U);

	/* Initialize TIM7 */
	pv.htim7->Instance = TIM7;

	/* Initialize TIMx peripheral as follow:
	 * Period = [(TIM7CLK/1000) - 1]. to have a (1/1000) s time base.
	 * Prescaler = (uwTimclock/1000000 - 1) to have a 1MHz counter clock.
	 * ClockDivision = 0
	 * Counter direction = Up
	 */
	pv.htim7->Init.Period = (1000000U / 1000U) - 1U;
	pv.htim7->Init.Prescaler = (uwPrescalerValue);
	pv.htim7->Init.ClockDivision = 0;
	pv.htim7->Init.CounterMode = TIM_COUNTERMODE_UP;

	if(HAL_TIM_Base_Init(pv.htim7) != HAL_OK)
	{
		Error_Handler();
	}

}

/**
  * @brief Platform Service TIM8 Initialization Function
  * @param None
  * @retval None
  */
void PS_TIM8_Init(void)
{
	RCC_ClkInitTypeDef    clkconfig;
	uint32_t              uwTimclock, uwAPB2Prescaler;
	uint32_t              uwPrescalerValue;
	uint32_t              pFLatency;

	/* Deinitialize the Timer8 */
	HAL_TIM_Base_DeInit(pv.htim8);

	HAL_NVIC_SetPriority(TIM8_CC_IRQn, 15UL ,0U);

	/* Enable the TIM8 global Interrupt */
	HAL_NVIC_EnableIRQ(TIM8_CC_IRQn);

	/* Enable TIM8 clock */
	__HAL_RCC_TIM8_CLK_ENABLE();

	/* Get clock configuration */
	HAL_RCC_GetClockConfig(&clkconfig, &pFLatency);

	/* Get APB2 prescaler */
	uwAPB2Prescaler = clkconfig.APB2CLKDivider;

	/* Compute TIM8 clock */
	if (uwAPB2Prescaler == RCC_HCLK_DIV1)
	{
		uwTimclock = HAL_RCC_GetPCLK1Freq();
	}
	else
	{
		uwTimclock = 2UL * HAL_RCC_GetPCLK1Freq();
	}

	/* Compute the prescaler value to have TIM8 counter clock equal to 1MHz */
	uwPrescalerValue = (uint32_t) ((uwTimclock / 1000000U) - 1U);

	/* Initialize TIM8 */
	pv.htim8->Instance = TIM8;

	/* Initialize TIMx peripheral as follow:
	 * Period = [(TIM8CLK/1000) - 1]. to have a (1/1000) s time base.
	 * Prescaler = (uwTimclock/1000000 - 1) to have a 1MHz counter clock.
	 * ClockDivision = 0
	 * Counter direction = Up
	 * */
	pv.htim8->Init.Period = (1000000U / 1000U) - 1U;
	pv.htim8->Init.Prescaler = (uwPrescalerValue);
	pv.htim8->Init.ClockDivision = 0;
	pv.htim8->Init.CounterMode = TIM_COUNTERMODE_UP;

	if(HAL_TIM_Base_Init(pv.htim8) != HAL_OK)
	{
		Error_Handler();
	}
}

/**
  * @brief Platform Service TIM12 Initialization Function
  * @param None
  * @retval None
  */
void PS_TIM12_Init(void)
{
	RCC_ClkInitTypeDef    clkconfig;
	uint32_t              uwTimclock, uwAPB1Prescaler;
	uint32_t              uwPrescalerValue;
	uint32_t              pFLatency;

	/* Deinitialize the Timer12 */
	HAL_TIM_Base_DeInit(pv.htim12);

	HAL_NVIC_SetPriority(TIM8_BRK_TIM12_IRQn, 15UL ,0U);

	/* Enable the TIM12 global Interrupt */
	HAL_NVIC_EnableIRQ(TIM8_BRK_TIM12_IRQn);

	/* Enable TIM12 clock */
	__HAL_RCC_TIM12_CLK_ENABLE();

	/* Get clock configuration */
	HAL_RCC_GetClockConfig(&clkconfig, &pFLatency);

	/* Get APB1 prescaler */
	uwAPB1Prescaler = clkconfig.APB1CLKDivider;

	/* Compute TIM12 clock */
	if (uwAPB1Prescaler == RCC_HCLK_DIV1)
	{
		uwTimclock = HAL_RCC_GetPCLK1Freq();
	}
	else
	{
		uwTimclock = 2UL * HAL_RCC_GetPCLK1Freq();
	}

	/* Compute the prescaler value to have TIM12 counter clock equal to 1MHz */
	uwPrescalerValue = (uint32_t) ((uwTimclock / 1000000U) - 1U);

	/* Initialize TIM12 */
	pv.htim12->Instance = TIM12;

	/* Initialize TIMx peripheral as follow:
	 * Period = [(TIM12CLK/1000) - 1]. to have a (1/1000) s time base.
	 * Prescaler = (uwTimclock/1000000 - 1) to have a 1MHz counter clock.
	 * ClockDivision = 0
	 * Counter direction = Up
	 * */
	pv.htim12->Init.Period = (1000000U / 1000U) - 1U;
	pv.htim12->Init.Prescaler = (uwPrescalerValue);
	pv.htim12->Init.ClockDivision = 0;
	pv.htim12->Init.CounterMode = TIM_COUNTERMODE_UP;

	if(HAL_TIM_Base_Init(pv.htim12) != HAL_OK)
	{
		Error_Handler();
	}
}

/**
  * @brief Platform Service TIM17 Initialization Function
  * @param None
  * @retval None
  */
void PS_TIM17_Init(void)
{
	RCC_ClkInitTypeDef    clkconfig;
	uint32_t              uwTimclock, uwAPB2Prescaler;
	uint32_t              uwPrescalerValue;
	uint32_t              pFLatency;

	/* Deinitialize the Timer15 */
	HAL_TIM_Base_DeInit(pv.htim17);

	HAL_NVIC_SetPriority(TIM17_IRQn, 5UL ,0U);

	/* Enable the TIM17 global Interrupt */
	HAL_NVIC_EnableIRQ(TIM17_IRQn);

	/* Enable TIM17 clock */
	__HAL_RCC_TIM17_CLK_ENABLE();

	/* Get clock configuration */
	HAL_RCC_GetClockConfig(&clkconfig, &pFLatency);

	/* Get APB2 prescaler */
	uwAPB2Prescaler = clkconfig.APB2CLKDivider;

	/* Compute TIM17 clock */
	if (uwAPB2Prescaler == RCC_HCLK_DIV1)
	{
		uwTimclock = HAL_RCC_GetPCLK1Freq();
	}
	else
	{
		uwTimclock = 2UL * HAL_RCC_GetPCLK1Freq();
	}

	/* Compute the prescaler value to have TIM17 counter clock equal to 1MHz */
	uwPrescalerValue = (uint32_t) ((uwTimclock / 1000000U) - 1U);

	/* Initialize TIM17 */
	pv.htim17->Instance = TIM17;

	/* Initialize TIMx peripheral as follow:
	 * Period = [(TIM17CLK/1000) - 1]. to have a (1/1000) s time base.
	 * Prescaler = (uwTimclock/1000000 - 1) to have a 1MHz counter clock.
	 * ClockDivision = 0
	 * Counter direction = Up
	 * */
	pv.htim17->Init.Period = (1000000U / 1000U) - 1U;
	pv.htim17->Init.Prescaler = (uwPrescalerValue);
	pv.htim17->Init.ClockDivision = 0;
	pv.htim17->Init.CounterMode = TIM_COUNTERMODE_UP;

	if(HAL_TIM_Base_Init(pv.htim17) != HAL_OK)
	{
		Error_Handler();
	}

}

/**
  * @brief Platform Service TIM16 Initialization Function
  * @param None
  * @retval None
  */
void PS_TIM16_Init(void)
{
	RCC_ClkInitTypeDef    clkconfig;
	uint32_t              uwTimclock, uwAPB2Prescaler;
	uint32_t              uwPrescalerValue;
	uint32_t              pFLatency;

	/* Deinitialize the Timer16 */
	HAL_TIM_Base_DeInit(pv.htim16);

	HAL_NVIC_SetPriority(TIM16_IRQn, 15UL ,0U);

	/* Enable the TIM16 global Interrupt */
	HAL_NVIC_EnableIRQ(TIM16_IRQn);

	/* Enable TIM16 clock */
	__HAL_RCC_TIM16_CLK_ENABLE();

	/* Get clock configuration */
	HAL_RCC_GetClockConfig(&clkconfig, &pFLatency);

	/* Get APB2 prescaler */
	uwAPB2Prescaler = clkconfig.APB2CLKDivider;

	/* Compute TIM16 clock */
	if (uwAPB2Prescaler == RCC_HCLK_DIV1)
	{
		uwTimclock = HAL_RCC_GetPCLK1Freq();
	}
	else
	{
		uwTimclock = 2UL * HAL_RCC_GetPCLK1Freq();
	}

	/* Compute the prescaler value to have TIM16 counter clock equal to 1MHz */
	uwPrescalerValue = (uint32_t) ((uwTimclock / 1000000U) - 1U);

	/* Initialize TIM16 */
	pv.htim16->Instance = TIM16;

	/* Initialize TIMx peripheral as follow:
	 * Period = [(TIM16CLK/1000) - 1]. to have a (1/1000) s time base.
	 * Prescaler = (uwTimclock/1000000 - 1) to have a 1MHz counter clock.
	 * ClockDivision = 0
	 * Counter direction = Up
	 * */
	pv.htim16->Init.Period = (1000000U / 1000U) - 1U;
	pv.htim16->Init.Prescaler = (uwPrescalerValue);
	pv.htim16->Init.ClockDivision = 0;
	pv.htim16->Init.CounterMode = TIM_COUNTERMODE_UP;

	if(HAL_TIM_Base_Init(pv.htim16) != HAL_OK)
	{
		Error_Handler();
	}

}

/** @brief Timer callback status
 *
 *  This function clear the callback status
 *  task.
 *
 *  @param  None
 *
 *  @return None
 *
 */
void clear_timer_callback(uint16_t db_idx)
{
	uint8_t swt_status;

	if((TIMER_CALLBACK_01 == db_idx) ||
			(TIMER_CALLBACK_02 == db_idx) ||
			(TIMER_CALLBACK_03 == db_idx) ||
			(TIMER_CALLBACK_04 == db_idx) ||
			(TIMER_CALLBACK_05 == db_idx) ||
			(TIMER_CALLBACK_06 == db_idx))
	{
		swt_status = CALLBACK_CLEAR;

		/* Set the Software timer callback status into the DB */
		Set_DL(db_idx, &swt_status);
	}
}

void SWTimer_Callback_1()
{
	if(pv.sw1_count++ == pv.sw1_timeout)
	{
		/* Reset the timer count value */
		pv.sw1_count = 0;

		if(SWT_ONESHOT == pv.sw1_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT1_OCCURED) , eSetBits, NULL );

			/* Stop the timer4 */
			HAL_TIM_Base_Stop_IT(pv.htim4);
		}
		else if(SWT_CONTINUOUS == pv.sw1_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT1_OCCURED) , eSetBits, NULL );
		}
	}
}

void SWTimer_Callback_2()
{
	if(pv.sw2_count++ == pv.sw2_timeout)
	{
		/* Reset the timer count value */
		pv.sw2_count = 0;

		if(SWT_ONESHOT == pv.sw2_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT2_OCCURED) , eSetBits, NULL );

			/* Stop the timer7 */
			HAL_TIM_Base_Stop_IT(pv.htim7);
		}
		else if(SWT_CONTINUOUS == pv.sw2_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT2_OCCURED) , eSetBits, NULL );
		}
	}
}

void SWTimer_Callback_3()
{
	if(pv.sw3_count++ == pv.sw3_timeout)
	{
		/* Reset the timer count value */
		pv.sw3_count = 0;

		if(SWT_ONESHOT == pv.sw3_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT3_OCCURED) , eSetBits, NULL );

			/* Stop the timer8 */
			HAL_TIM_Base_Stop_IT(pv.htim8);
		}
		else if(SWT_CONTINUOUS == pv.sw3_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT3_OCCURED) , eSetBits, NULL );
		}
	}
}

void SWTimer_Callback_4()
{
	if(pv.sw4_count++ == pv.sw4_timeout)
	{
		/* Reset the timer count value */
		pv.sw4_count = 0;

		if(SWT_ONESHOT == pv.sw4_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT4_OCCURED) , eSetBits, NULL );

			/* Stop the timer12 */
			HAL_TIM_Base_Stop_IT(pv.htim12);
		}
		else if(SWT_CONTINUOUS == pv.sw4_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT4_OCCURED) , eSetBits, NULL );
		}
	}
}

void SWTimer_Callback_5()
{
	if(pv.sw5_count++ == pv.sw5_timeout)
	{
		/* Reset the timer count value */
		pv.sw5_count = 0;

		if(SWT_ONESHOT == pv.sw5_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT5_OCCURED) , eSetBits, NULL );

			/* Stop the timer15 */
			HAL_TIM_Base_Stop_IT(pv.htim17);
		}
		else if(SWT_CONTINUOUS == pv.sw5_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT5_OCCURED) , eSetBits, NULL );
		}
	}
}

void SWTimer_Callback_6()
{
	if(pv.sw6_count++ == pv.sw6_timeout)
	{
		/* Reset the timer count value */
		pv.sw6_count = 0;

		if(SWT_ONESHOT == pv.sw6_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT6_OCCURED) , eSetBits, NULL );

			/* Stop the timer16 */
			HAL_TIM_Base_Stop_IT(pv.htim16);
		}
		else if(SWT_CONTINUOUS == pv.sw6_mode)
		{
			/* Notify to SWTimer Platform Service */
			xTaskNotifyFromISR( pv.swt_task, (1<<SWT6_OCCURED) , eSetBits, NULL );
		}
	}
}

/** @brief SWTimer Platform service task
 *
 *  This function starts the SWTimer Platform Service
 *  task.
 *
 *  @param  None
 *
 *  @return 0 : PS_SUCCESS
 *          1 : PS_FAILURE
 *
 */
static void SWTimer_ServiceStart(void * pvParameters)
{
	uint32_t cNotifiedValue;
	uint8_t *swtbuf;
	uint8_t res;
	uint8_t func;
	uint16_t timeout;

	while(1)
	{

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
		/* Ping the watchdog timer */
		res = SetWD(WD_PING_SWTIMER_TASK);

		if(res != SUCCESS)
		{
			LOGERROR("SWTimer Task failed to ping the WD Timer\r\n");
		}
#endif

		/* Wait for receiving the Event from the SDK API */
		res = xTaskNotifyWait( CLEAR_BITS_ONENTRY, ULONG_MAX ,
				&cNotifiedValue, PS_SWT_TASK_TIMEOUT);

		if(res != pdTRUE)
		{
			continue;
		}

		if (cNotifiedValue & (1 << SWT1_OCCURED))
		{
#ifdef __TIMERTEST__
		if(count == 0)
		{
			HAL_GPIO_WritePin(GPIOG, GPIO_PIN_10, GPIO_PIN_SET);
			count = 1;
		}
		else
		if(count == 1)
		{
			HAL_GPIO_WritePin(GPIOG, GPIO_PIN_10, GPIO_PIN_RESET);
			count = 0;
		}
#endif
			res = CALLBACK_OCCURED;

			/* Set the Software timer callback status into the DB */
			Set_DL(TIMER_CALLBACK_01, &res);
		}

		if (cNotifiedValue & (1 << SWT2_OCCURED))
		{
			res = CALLBACK_OCCURED;

			/* Set the Software timer callback status into the DB */
			Set_DL(TIMER_CALLBACK_02, &res);
		}

		if (cNotifiedValue & (1 << SWT3_OCCURED))
		{
			res = CALLBACK_OCCURED;

			/* Set the Software timer callback status into the DB */
			Set_DL(TIMER_CALLBACK_03, &res);
		}

		if (cNotifiedValue & (1 << SWT4_OCCURED))
		{
			res = CALLBACK_OCCURED;

			/* Set the Software timer callback status into the DB */
			Set_DL(TIMER_CALLBACK_04, &res);
		}

		if (cNotifiedValue & (1 << SWT5_OCCURED))
		{
			res = CALLBACK_OCCURED;

			/* Set the Software timer callback status into the DB */
			Set_DL(TIMER_CALLBACK_05, &res);
		}

		if (cNotifiedValue & (1 << SWT6_OCCURED))
		{
			res = CALLBACK_OCCURED;

			/* Set the Software timer callback status into the DB */
			Set_DL(TIMER_CALLBACK_06, &res);
		}

		if (cNotifiedValue & (1<< SWT_MSG_EVENT))
		{
				/* Receive Message from the SWTimer SDK API */
				res = xQueueReceive(pv.swttxq, &swtbuf , ( TickType_t ) Q_TICKSTOWAIT );
				if(res != pdTRUE)
				{
					break;
				}

				func = swtbuf[SWT_FUNC_INDEX];
				/* Update the result */
				swtbuf[SWT_RESULT_INDEX] = SUCCESS;

				switch(func)
				{
					case SWT_SET:

						/* Copy the timeout value */
						memcpy(&timeout, &swtbuf[SWT_TIMEMS_INDEX], sizeof(timeout));

						if(SWT1 == swtbuf[SWT_COUNT_INDEX])
						{
							/* Update the Timer1 mode */
							pv.sw1_mode = swtbuf[SWT_MODE_INDEX];

							/* Update the Timer1 Timeout */
							pv.sw1_timeout = timeout;

							if(SWT_ACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Start_IT(pv.htim4);
							}
							else if(SWT_INACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Stop_IT(pv.htim4);
							}

							/* Reset the sw1 timer count value */
							pv.sw1_count = 0;
						}

						if(SWT2 == swtbuf[SWT_COUNT_INDEX])
						{
							/* Update the Timer2 mode */
							pv.sw2_mode = swtbuf[SWT_MODE_INDEX];

							/* Update the Timer2 Timeout */
							pv.sw2_timeout = timeout;

							if(SWT_ACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Start_IT(pv.htim7);
							}
							else if(SWT_INACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Stop_IT(pv.htim7);
							}

							/* Reset the sw2 timer count value */
							pv.sw2_count = 0;
						}

						if(SWT3 == swtbuf[SWT_COUNT_INDEX])
						{
							/* Update the Timer3 mode */
							pv.sw3_mode = swtbuf[SWT_MODE_INDEX];

							/* Update the Timer3 Timeout */
							pv.sw3_timeout = timeout;

							if(SWT_ACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Start_IT(pv.htim8);
							}
							else if(SWT_INACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Stop_IT(pv.htim8);
							}

							/* Reset the sw3 timer count value */
							pv.sw3_count = 0;
						}

						if(SWT4 == swtbuf[SWT_COUNT_INDEX])
						{
							/* Update the Timer4 mode */
							pv.sw4_mode = swtbuf[SWT_MODE_INDEX];

							/* Update the Timer4 Timeout */
							pv.sw4_timeout = timeout;

							if(SWT_ACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Start_IT(pv.htim12);
							}
							else if(SWT_INACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Stop_IT(pv.htim12);
							}

							/* Reset the sw4 timer count value */
							pv.sw4_count = 0;
						}

						if(SWT5 == swtbuf[SWT_COUNT_INDEX])
						{
							/* Update the Timer5 mode */
							pv.sw5_mode = swtbuf[SWT_MODE_INDEX];

							/* Update the Timer5 Timeout */
							pv.sw5_timeout = timeout;

							if(SWT_ACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Start_IT(pv.htim17);
							}
							else if(SWT_INACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Stop_IT(pv.htim17);
							}

							/* Reset the sw5 timer count value */
							pv.sw5_count = 0;
						}

						if(SWT6 == swtbuf[SWT_COUNT_INDEX])
						{
							/* Update the Timer6 mode */
							pv.sw6_mode = swtbuf[SWT_MODE_INDEX];

							/* Update the Timer6 Timeout */
							pv.sw6_timeout = timeout;

							if(SWT_ACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Start_IT(pv.htim16);
							}
							else if(SWT_INACTIVE == swtbuf[SWT_STATUS_INDEX])
							{
								HAL_TIM_Base_Stop_IT(pv.htim16);
							}

							/* Reset the sw6 timer count value */
							pv.sw6_count = 0;
						}

						break;

					default:
						/* Update the result */
						swtbuf[SWT_RESULT_INDEX] = FAILURE;
						break;
				}

				/* Send the response to the SDK API */
				xQueueSend( pv.swtrxq, ( void * )&swtbuf, ( TickType_t ) Q_TICKSTOWAIT );
		}
	}
}


/** @brief Start SWTimer Platform service
 *
 *  This function initializes the following modules
 *     ===> SWT DB
 *     ===> SWT platform driver
 *     ===> SWT software resources
 *     ===> Start the SWT service
 *
 *  @param  None
 *
 *  @return 0 : PS_SUCCESS
 *          1 : PS_FAILURE
 *
 */
int8_t SWT_PS_Start(void)
{
	BaseType_t xReturned;

	/* Create SWTimer TxQ for receiving value from the SDK API */
	pv.swttxq = xQueueCreate( SWT_RX_TX_MAX_Q_SIZE, sizeof(uint32_t*));
	if(NULL == pv.swttxq)
	{
		LOGERROR("Unable to create the SWTimer TxQ \r\n");
		return PS_FAILURE;
	}

	/* Create SWTimer RxQ for sending return value to the SDK API */
	pv.swtrxq = xQueueCreate( SWT_RX_TX_MAX_Q_SIZE, sizeof(uint32_t*));
	if(NULL == pv.swtrxq)
	{
		LOGERROR("Unable to create the SWT RxQ \r\n");
		return PS_FAILURE;
	}

	/* Start the SWtimer Platform service thread */
	xReturned = xTaskCreate(SWTimer_ServiceStart, "SWTimer",
			SWT_STACK_DEPTH, NULL, PS_SWT_TASK_PRIORITY, &pv.swt_task);

	if( xReturned != pdPASS )
	{
		LOGERROR("Unable to create the SWT Task \r\n");
		return PS_FAILURE;
	}

	LOGERROR("SWT Platform Service task created Successfully \r\n");

	return PS_SUCCESS;
}
#endif	//SDK_SERVICE_SWTimer

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
