/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : USB_Platformservice.c
   Author             :
   Version            : V0.0.0.1
   Origination Date   : 14/02/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the USB platform service initialization

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             04/02/2022           Adrush

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../Inc/Common.h"
/* USER CODE END Includes */

/* USER CODE BEGIN Global Variables */
#if (SDK_SERVICE_USB == PS_ENABLE)
#include "stm32h7xx_hal_pcd.h"
#include "usbd_def.h"
#include "usbd_core.h"
#include "usbd_cdc.h"
#include "usbd_cdc_if.h"

extern pvt_variable pv;

extern uint8_t UserRxBufferHS[APP_RX_DATA_SIZE];
extern USBD_HandleTypeDef hUsbDeviceHS;
extern USBD_CDC_ItfTypeDef USBD_Interface_fops_HS;
extern PCD_HandleTypeDef hpcd_USB_OTG_HS;

/** @brief USB Timer Callback
 *
 *  This function is used for the USB blink
 *  functionality
 *
 *  @param  xTimer : USB timer handle
 *
 *  @return none
 *
 */
void USBTimerCallback( TimerHandle_t xTimer )
{
	/* Notify to the USB task to blink */
	xTaskNotify( pv.usb_task, (1<<USB_TMR_EVENT), eSetBits );
}

/* USER CODE BEGIN 11 */
int8_t CDC_Receive(uint8_t* Buf, uint32_t *Len)
{
	USBD_CDC_SetRxBuffer(&hUsbDeviceHS, &Buf[0]);
	USBD_CDC_ReceivePacket(&hUsbDeviceHS);
	pv.rcvd_len = *Len;
	xTaskNotifyFromISR( pv.usb_task, (1<<USB_RX_EVENT) , eSetBits, NULL );

	return (USBD_OK);
}

/* USER CODE END 11 */

void PS_HAL_PCD_ConnectCallback(PCD_HandleTypeDef *hpcd)
{
	USBD_LL_DevConnected((USBD_HandleTypeDef*)hpcd->pData);
	xTaskNotifyFromISR( pv.usb_task, (1<<USB_CONN_EVENT) , eSetBits, NULL );
}

/**
  * @brief  Disconnect callback.
  * @param  hpcd: PCD handle
  * @retval None
  */
void PS_HAL_PCD_DisconnectCallback(PCD_HandleTypeDef *hpcd)
{
	USBD_LL_DevDisconnected((USBD_HandleTypeDef*)hpcd->pData);
	xTaskNotifyFromISR( pv.usb_task, (1<<USB_DISC_EVENT) , eSetBits, NULL );
}

#if (SDK_CAM_USB_STOP == PS_ENABLE)
/** @brief Stop/Start USB Platform service task
 *
 *  This function starts/stops the USB Platform Service
 *  task.
 *
 *  @param  state : Switch the state of running thread
 *
 *  @return SUCCESS
 *          FAILURE
 *
 */
uint8_t Stop_USB_Service(uint8_t state)
{
	uint8_t *buff;
	uint8_t res;
	/* Get the buffer from the Memory */
   	buff = (uint8_t *) ai430_memory_alloc();


   	/* Check the state */
	if (STATE_STOP == state)
	{
		state = USB_CAM_STOP_EVENT;
	}
	else
		state = USB_CAM_START_EVENT;

    buff[0]  = USB_CAM_STOP_EVENT;

	/* Send the data into the LED Q */
	if (xQueueSend( pv.usbtxq, ( void * )&buff, ( TickType_t ) Q_TICKSTOWAIT ) != pdPASS)
	{
		/* Release the buffer */
		ai430_memory_free(buff);
		return FAILURE;
	}

	/* Notify the USB task to update the USB data */
	if (xTaskNotify( pv.usb_task, (1<<state), eSetBits ) != pdPASS)
	{
		return FAILURE;
	}

	/* Wait for receiving the return data */
    /* Send the data to the USB platform service layer */
	if (xQueueReceive(pv.usbrxq, &buff, ( TickType_t ) Q_TICKSTOWAIT ) != pdPASS )
	{
		/* Release the buffer */
		ai430_memory_free(buff);
		return FAILURE;
	}

	res = buff[USB_RESULT_INDEX];

	/* Release the buffer */
	ai430_memory_free(buff);

	return res;
}
#endif

/** @brief USB DB Initialization
 *
 *  This function takes the default configuration from the config header
 *  file and store the data into the DB.
 *
 *  @param  None
 *
 *  @return 0 : PS_SUCCESS
 *         -1 : PS_FAILURE
 *
 */
int8_t USB_DB_Init(void)
{
	uint8_t status;

	USBD_Interface_fops_HS.Receive = CDC_Receive;

	HAL_PCD_RegisterCallback(&hpcd_USB_OTG_HS, PS_HAL_PCD_CONNECT_CB_ID, PS_HAL_PCD_ConnectCallback);
	HAL_PCD_RegisterCallback(&hpcd_USB_OTG_HS, PS_HAL_PCD_DISCONNECT_CB_ID, PS_HAL_PCD_DisconnectCallback);

	status = USB_TX_BUFF_NOTFULL;
	Set_DL(USB_TX_BUFFER_STATUS, &status);

	pv.urxtimeout = TIMER_NOT_STARTED;

	return PS_SUCCESS;
}

/** @brief Partial receive packet handling
 *
 *  This function handles the paritally received packet and
 *  accumulate the data packet until it receives the complete
 *  packet.
 *
 *  @param  rxpkt : Received Packet
 *          rxlen : Received Packet length
 *
 *  @return POINTER_ERROR
 *          INVALID_FRAME
 *          NOT_COMPLETE_FRAME
 *          VALID_FRAME
 *
 */

int8_t IsCompleteUSBPktReceived(uint8_t *rxdata, uint8_t len)
{
	baFrame *rxframe = (baFrame *)rxdata;
	uint8_t csum;

	pv.rxlen += len;

	/* Check for the NULL Parameter */
	if(NULL == rxdata)
	{
		pv.rxlen = 0;
		return POINTER_ERROR;
	}
#if 0
    /* Check for the timeout */
	if(pv.urxtimeout == TIMER_TIMEDOUT)
	{
		pv.urxtimeout = TIMER_NOT_STARTED;
		pv.rxlen = 0;
		return INVALID_FRAME;
	}
#endif
    /* Check all the bytes are received */
	if ((rxframe->bSize + ADDITIONAL_FRAME_SIZE) > pv.rxlen)
	{
		pv.urxtimeout = TIMER_NOT_STARTED;
		return NOT_COMPLETE_FRAME;
	}

	/* Received packet size is more than 256 bytes */
	if ( MAX_USB_RX_LEN < pv.rxlen)
	{
		pv.rxlen = 0;
		return INVALID_FRAME;
	}

	/* Validate the Checksum */
	csum = CalCheckSum(rxdata, len-1);
	if (csum != rxdata[ADDITIONAL_FRAME_SIZE + rxframe->bSize])
	{
		pv.rxlen = 0;
		return INVALID_FRAME;
	}

	pv.rxlen = 0;

    return VALID_FRAME;
}

/** @brief Process the USER packet
 *
 *  This function processes the received usb packet from the
 *  Host PC.
 *
 *  @param  rxpkt : Received Packet
 *          rxlen : Received Packet length
 *
 *  @return none
 *
 */
void Process_USER_RX_Packet(uint8_t *rxpkt, uint8_t rxlen)
{
	uint8_t  flag;
	/* Check the packet size */
	if((rxpkt[3]-2) > DB_MAX_VAL_SIZE)
		return;

	/* Copy only the data portion */
	memcpy(&pv.trxpkt[0], &rxpkt[5], rxpkt[3] - 1);
	/* Set the data into the DB */
	Set_DL(USB_RX_DATA, &pv.trxpkt[0]);
	memset(&pv.trxpkt[0], 0x00, sizeof(pv.trxpkt));

	/* Set Status of the RX buffer */
	flag = RX_MSG_PENDING;
	Set_DL(USB_RX_BUFFER_STATUS, &flag);

}

/** @brief Process the received packet
 *
 *  This function processes the received usb packet from the
 *  Host PC terminal and sends the response to the USB
 *  Terminal Software.
 *
 *  @param  rxpkt : Received Packet
 *          rxlen : Received Packet length
 *
 *  @return none
 *
 */
void Process_Received_Data(uint8_t *rxpkt, uint8_t rxlen)
{
	uint8_t senddata = TRUE;

	/* Check for the NULL pointer */
	if (NULL == rxpkt)
		return;

	/* Validate the header */
	if (((RXMODE != rxpkt[0]) && (TXMODE != rxpkt[0])) &&
			(DEST_ADDRESS != rxpkt[1]) &&
		    (TOOL_ADDRESS != rxpkt[2]))
		return;

	/* Check for the USER Packet */
	if (userPacket == rxpkt[4])
	{
		Process_USER_RX_Packet(rxpkt, rxlen);
		return;
	}

	/* Check for the other packet */
	if ((ECUReset == rxpkt[4]) ||
		(readECUIdentification == rxpkt[4]) ||
		(readDataByCommonIdentifier == rxpkt[4]) ||
		(readMemoryByAddress == rxpkt[4]) ||
		(writeDataByCommonIdentifier == rxpkt[4]) ||
		(writeMemoryByAddress == rxpkt[4]))
	{
	    /* Check for the communication started */
		/* if not started, discard the packet */
	    if (FALSE == pv.start_com)
	    {
	    	return;
	    }
	}

	switch(rxpkt[4])
	{
		case startCOM :
			if (SUCCESS == SetstartCOM(rxpkt, &rxlen))
				pv.start_com = TRUE;
			break;
		case stopCOM :
			if (SUCCESS == SetstopCOM(rxpkt, &rxlen))
				pv.start_com = FALSE;
			break;
		case ECUReset :
			SetecuReset(rxpkt, &rxlen);
			break;
		case readECUIdentification :
		    GetreadEcuIdentification(rxpkt, &rxlen);
			break;
		case readDataByCommonIdentifier :
		    GetreadDataByCommonIdentifier(rxpkt, &rxlen);
			break;
		case readMemoryByAddress :
		     GetreadMemoryByAddress(rxpkt, &rxlen);
			break;
		case writeDataByCommonIdentifier :
		     SetwriteDataByCommonIdentifier(rxpkt, &rxlen);
			break;
		case accessTimParameters :
		case testerPresent :
		case startDiagnosticSession :
		case stopDiagnosticSession :
		case securityAccess :
		case readDataByLocalIdentifier :
		case dynamicallyDefineLocalIdentifier :
		case writeDataByLocalIdentifier :
		case setDataRates :
		case stopRepeatedDataTransmission :
		case readDiagnosticTroubleCodes :
			senddata = FALSE;
		default:
			break;
	}

	if ((FALSE == senddata) || (0 == rxlen))
		return;

	/* Send the packet to the USB */
	CDC_Transmit_HS(rxpkt, rxlen);

}

/** @brief USB Platform service task
 *
 *  This function starts the USB Platform Service
 *  task.
 *
 *  @param  pvParameters - Private data pointer
 *
 *  @return none
 *
 */
void USB_ServiceStart(void *pvParameters)
{
	uint32_t cNotifiedValue;
	uint32_t addr;
	uint8_t  len;
	int8_t   res = 0;
	uint8_t  func;
	uint8_t  *usbbuf;
	TickType_t  th_timeout = PS_USB_TASK_TIMEOUT;

	memset(&pv.rxpkt[0], 0x00, sizeof(pv.rxpkt[0]));

#if (SDK_CAM_USB_STOP == PS_ENABLE)
	StartStopSDKServiceReg(Stop_USB_Service);
#endif

	memset(&pv.rxpkt[0], 0x00, sizeof(pv.rxpkt[0]));

	while(1)
	{

#if (SDK_SERVICE_WATCHDOG == PS_ENABLE)
		/* Ping the watchdog timer */
		res = SetWD(WD_PING_USB_TASK);

		if(res != SUCCESS)
		{
			LOGERROR("USB Task failed to ping the WD Timer\r\n");
		}

#endif

		/* Wait for receiving the Event from the SDK API and USB timer */
		res = xTaskNotifyWait( CLEAR_BITS_ONENTRY, ULONG_MAX , &cNotifiedValue, th_timeout);

		if(res != pdTRUE)
		{
			continue;
		}


#if (SDK_CAM_USB_STOP == PS_ENABLE)

		/* Camera is streaming, stop the SDK thread */
		if ((cNotifiedValue & (1<< USB_CAM_STOP_EVENT)) &&
				(pv.usb_cam_state != USB_THREAD_STATE_STOP))
		{
			pv.usb_cam_state = WL_THREAD_STATE_STOP;
		    th_timeout = portMAX_DELAY;

			/* Update the result */
			usbbuf[USB_RESULT_INDEX] = SUCCESS;

			/* Send the response to the SDK API */
			xQueueSend( pv.usbrxq, ( void * )&usbbuf, ( TickType_t ) Q_TICKSTOWAIT );

			continue;
		}

		/* Camera is stopped streaming, start the SDK thread */
		if ((cNotifiedValue & (1<< USB_CAM_START_EVENT)) &&
			(pv.usb_cam_state != USB_THREAD_STATE_RUN))
		{
			pv.usb_cam_state = USB_THREAD_STATE_RUN;
			th_timeout = PS_USB_TASK_TIMEOUT;
			/* Update the result */
			usbbuf[USB_RESULT_INDEX] = SUCCESS;

			/* Send the response to the SDK API */
			xQueueSend( pv.usbrxq, ( void * )&usbbuf, ( TickType_t ) Q_TICKSTOWAIT );
		    continue;
		}

		/* Receive any event, do not accept. Since the camera is running */
		if (USB_THREAD_STATE_STOP == pv.usb_cam_state)
		{
			/* Update the result */
			usbbuf[USB_RESULT_INDEX] = FAILURE;

			/* Send the response to the SDK API */
			xQueueSend( pv.usbrxq, ( void * )&usbbuf, ( TickType_t ) Q_TICKSTOWAIT );

			continue;
		}
#endif

		/* USB Connect Event */
		if (cNotifiedValue & (1<<USB_CONN_EVENT))
		{
			/* Update the status into the DB */
			len = TRUE;
			Set_DL(USB_COMMUNICATION_STATUS, &len);
		}

		/* USB Disconnect Event */
		if (cNotifiedValue & (1<<USB_DISC_EVENT))
		{
			/* Update the status into the DB */
			len = FALSE;
			Set_DL(USB_COMMUNICATION_STATUS, &len);
		}
		/* Event from SDK USB API */
		if (cNotifiedValue & (1<<USB_RX_EVENT))
		{
			memcpy(&pv.rxpkt[pv.rxindex], &UserRxBufferHS[0], pv.rcvd_len);

			/* Validate the packet */
			res = IsCompleteUSBPktReceived(&pv.rxpkt[pv.rxindex], pv.rcvd_len);

			if ((VALID_FRAME != res) && (NOT_COMPLETE_FRAME != res))
			{
				pv.rxindex = 0;
			}
			else
			/* Not received the complete packet, start the timer for the timeout */
			if (NOT_COMPLETE_FRAME == res)
			{
				pv.rxindex += pv.rcvd_len;

				/* Start the timer */
				xTimerStart( pv.xTimers[ PS_USB_TIMER ], 0 );
			}
			else
			{
				/* if timer is active, stop the timer */
				if (pdTRUE == xTimerIsTimerActive(pv.xTimers[PS_USB_TIMER]))
				{
					 /* STOP USB timer */
					 xTimerStop( pv.xTimers[ PS_USB_TIMER ], 0 );
				}

				/* Process the Receive Thread */
				Process_Received_Data(&pv.rxpkt[0], pv.rcvd_len);

				memset(&pv.rxpkt[0], 0x00, sizeof(pv.rxpkt[0]));
			}

			/* Update the TX status to the DB */
			if (TRUE == pv.tx_status)
			{
				pv.tx_status = FALSE;
				Set_DL(USB_TX_STATUS, &pv.tx_status);

				len = USB_TX_BUFF_NOTFULL;
				Set_DL(USB_TX_BUFFER_STATUS, &len);
			}
		}

		/* Event from SDK USB API */
		if (cNotifiedValue & (1<<USB_TMR_EVENT))
		{

			/* Initialize the variables */
			pv.rxindex = 0;
			//pv.urxtimeout = TIMER_TIMEDOUT;

			/* STOP USB timer */
			xTimerStop( pv.xTimers[ PS_USB_TIMER ], 0 );
		}

		if (cNotifiedValue & (1<<USB_MSG_EVENT))
		{
				/* Receive Message from the USB SDK API */
				res = xQueueReceive(pv.usbtxq, &usbbuf , ( TickType_t ) Q_TICKSTOWAIT );

				if(res != pdTRUE)
				{
					break;
				}

				func = usbbuf[USB_FUNC_INDEX];

				/* Update the result */
				usbbuf[USB_RESULT_INDEX] = SUCCESS;

				switch(func)
				{
					case USB_ACT:

						break;

					case USB_SET:
						/* Check for the communication started */
						/* if not started, discard the packet */
					    if (TRUE == pv.start_com)
					    {
							/* Get the USER Buffer pointer */
							memcpy((uint8_t *)&addr, &usbbuf[USB_DATA_INDEX], sizeof(addr));

							/* Get the Length */
							memcpy(&len, &usbbuf[USB_LEN_INDEX + sizeof(addr)], sizeof(len));

							/* Construct the packet */
							pv.txpkt[PKT_MODE_INDEX] = TXMODE;
							pv.txpkt[PKT_DADR_INDEX] = DEST_ADDRESS;
							pv.txpkt[PKT_TADR_INDEX] = TOOL_ADDRESS;

							pv.txpkt[PKT_SIZE_INDEX] = len + 1;

							/* Message ID */
							pv.txpkt[MSG_ID_INDEX] = PS_USB_USER_PACKET;

							/* Copy the packet to the USB packet */
							memcpy(&pv.txpkt[MSG_ID_INDEX+1], (uint8_t *)addr, len);

							/* Update the checksum */
							pv.txpkt[CMD_PKT_HEADER_SIZE + len + 1] =
									CalCheckSum(&pv.txpkt[0], CMD_PKT_HEADER_SIZE + len + 1);

							/* Send the packet to the USB */
							CDC_Transmit_HS((uint8_t *)&pv.txpkt[0], CMD_PKT_HEADER_SIZE + len + 2);

							/* Wait for the transfer complete */
							pv.tx_status = TRUE;
					    }
					    else
					    {
					    	/* Update the result */
					    	usbbuf[USB_RESULT_INDEX] = FAILURE;
					    }
						break;

					default:
						/* Update the result */
						usbbuf[USB_RESULT_INDEX] = FAILURE;
						break;
				}
				/* Send the response to the SDK API */
				xQueueSend( pv.usbrxq, ( void * )&usbbuf, ( TickType_t ) Q_TICKSTOWAIT );
		}

		/* Clear the Notify Value */
		cNotifiedValue = 0;
	}
}

/** @brief Start USB Platform service
 *
 *  This function initializes the following modules
 *     ===> USB DB
 *     ===> USB platform driver
 *     ===> USB software resources
 *     ===> Start the USB service
 *
 *  @param  None
 *
 *  @return 0 : PS_SUCCESS
 *         -1 : PS_FAILURE
 *
 */
int8_t USB_PS_Start(void)
{
	BaseType_t xReturned;

	/* Create the USB timer for blinking */
	pv.xTimers[ PS_USB_TIMER ] = xTimerCreate
	                   ( "USB_Timer",
	                	PS_USB_TIMER_COUNT,
	                    pdTRUE,
	                    ( void * ) 0,
	                    USBTimerCallback
	                   );

	if (NULL == pv.xTimers[ PS_USB_TIMER ])
	{
		LOGERROR("Unable to initialize the USB timer\r\n");
		return PS_FAILURE;
	}

	/* Create USB TxQ for receiving value from the SDK API */
	pv.usbtxq = xQueueCreate( USB_RX_TX_MAX_Q_SIZE, sizeof(uint32_t*));
	if(NULL == pv.usbtxq)
	{
		LOGERROR("Unable to initialize the USB TxQ \r\n");
		return PS_FAILURE;
	}

	/* Create USB RxQ for sending return value to the SDK API */
	pv.usbrxq = xQueueCreate( USB_RX_TX_MAX_Q_SIZE, sizeof(uint32_t*));
	if(NULL == pv.usbrxq)
	{
		LOGERROR("Unable to initialize the USB RxQ \r\n");
		return PS_FAILURE;
	}

	/* Create the USB task */
	xReturned = xTaskCreate(USB_ServiceStart, "USB_Service",
			USB_TASK_SIZE, NULL, PS_USB_TASK_PRIORITY,   &pv.usb_task);

    if( pdPASS != xReturned )
    {
		LOGERROR("Unable to initialize the USB Task\r\n");
		return PS_FAILURE;
    }

    LOGERROR("USB Platform Service task created Successfully \r\n");

	return PS_SUCCESS;
}

#endif	//SDK_SERVICE_USB

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
