/****************************************************************************
              Copyright (c) 2021 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : EE_User_define.h
   Author             :	Rajesh
   Version            : V0.0.0.1
   Origination Date   : 04/03/2022
   Description        : Header File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the EEPROM USER define data

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             04/03/2022			Rajesh

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/
#ifndef _EE_USER_DEFINE_H_
#define	_EE_USER_DEFINE_H_


#define END_EEPROM    (64 * 1024)    // 64 KB Size


/*!
 * EEPROM Element for the USER configuration
 */
typedef struct __EE_Element_info
{
    EE_Element        ID;                  /* ID from the EE_Element       */
	uint16_t          Size;                /* Size of the variable in byte */
	uint8_t           CRC_enable;          /* CRC enable or disable        */
	uint16_t          Redundancy;          /* Number of Redundancy copy    */
	uint8_t           Default_data_enable; /* Enable default data          */
	const int8_t      *Default_data;       /* Point to the default data    */
} EE_Element_info;


/*!
 * EEPROM Place holder mapping with shadow memory
 */
typedef struct  __EE_PLACEHOLDER
{
    EE_Element        ID;
	EE_Element_info   *EE_info;
	uint8_t           *Shadow_EE_data_addr;
	uint8_t           Update_data;
	uint16_t          EE_status;
} EE_PLACEHOLDER;


/*
 * USER EEPROM Place holder
 *
 * If the USER wants to store the data into EEPORM, the USER
 * has to update into this structure.
 *
 */
int8_t EE_CAL01_default = 10;

EE_Element_info     EE_user_elements[] =
{
    /* ID,	Size,	CRC_enable,		Redundancy,		Default_data_enable,	Default_data */
    {EE_CAL01 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL02 , sizeof(EE_CAL01_default), TRUE, 2, TRUE, &EE_CAL01_default},
	{EE_CAL03 , sizeof(EE_CAL01_default), TRUE, 3, TRUE, &EE_CAL01_default},
	{EE_CAL04 , sizeof(EE_CAL01_default), TRUE, 4, TRUE, &EE_CAL01_default},

#if 0
	{EE_CAL05 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL06 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL07 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL08 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL09 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL10 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL11 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL12 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL13 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL14 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL15 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL16 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL17 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL18 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL19 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL20 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL21 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL22 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL23 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL24 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL25 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL26 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL27 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL28 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL29 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL30 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL31 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL32 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL33 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL34 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL35 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL36 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL37 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL38 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL39 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL40 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL41 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL42 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL43 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL44 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL45 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL46 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL47 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL48 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL49 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL50 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL51 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL52 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL53 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL54 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL55 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL56 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL57 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL58 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL59 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL60 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL61 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL62 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL63 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL64 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL65 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL66 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL67 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL68 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL69 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL70 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL71 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL72 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL73 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL74 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL75 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL76 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL77 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL78 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL79 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL80 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL81 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL82 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL83 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL84 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL85 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL86 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL87 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL88 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL89 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL90 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL91 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL92 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL93 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL94 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL95 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL96 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL97 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL98 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL99 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL100 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL101 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL102 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL103 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL104 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL105 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL106 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL107 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL108 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL109 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL110 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL111 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL112 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL113 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL114 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL115 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL116 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL117 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL118 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL119 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL120 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL121 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL122 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL123 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL124 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL125 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL126 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL127 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL128 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL129 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL130 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL131 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL132 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL133 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL134 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL135 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL136 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL137 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL138 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL139 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL140 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL141 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL142 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL143 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL144 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL145 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL146 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL147 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL148 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL149 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL150 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL151 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL152 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL153 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL154 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL155 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL156 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL157 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL158 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL159 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL160 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL161 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL162 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL163 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL164 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL165 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL166 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL167 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL168 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL169 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL170 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL171 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL172 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL173 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL174 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL175 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL176 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL177 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL178 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL179 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL180 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL181 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL182 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL183 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL184 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL185 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL186 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL187 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL188 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL189 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL190 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL191 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL192 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL193 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL194 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL195 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL196 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL197 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL198 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL199 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL200 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL201 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL202 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL203 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL204 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL205 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL206 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL207 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL208 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL209 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL210 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL211 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL212 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL213 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL214 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL215 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL216 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL217 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL218 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL219 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL220 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL221 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL222 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL223 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL224 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL225 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL226 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL227 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL228 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL229 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL230 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL231 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL232 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL233 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL234 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL235 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL236 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL237 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL238 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL239 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL240 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL241 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL242 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL243 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL244 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL245 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL246 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL247 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL248 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL249 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL250 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL251 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL252 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL253 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL254 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL255 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL256 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL257 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL258 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL259 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL260 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL261 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL262 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL263 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL264 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL265 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL266 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL267 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL268 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL269 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL270 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL271 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL272 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL273 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL274 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL275 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL276 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL277 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL278 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL279 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL280 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL281 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL282 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL283 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL284 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL285 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL286 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL287 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL288 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL289 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL290 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL291 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL292 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL293 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL294 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL295 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL296 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL297 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL298 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL299 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
	{EE_CAL300 , sizeof(EE_CAL01_default), TRUE, 1, TRUE, &EE_CAL01_default},
#endif
};

#endif	//_EEPROM_PLATFORM_SERVICE_H_

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
