/****************************************************************************
              Copyright (c) 2020 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : bluetooth.h
   Author             : Alejandro Mendoza
   Version            : V0.0.0.1
   Origination Date   : 03/23/2020
   Description        : C Header File.
   Environment        : Independant
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

		General File Description
-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.0              04/04/2011         Name Last_Name

   Notes:              - Initial Version
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1              31/03/2011         Name Last_Name

   Notes:              - Second Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

#ifndef __BLUETOOTH_H
#define __BLUETOOTH_H

/* Includes ---------------------------------------------------------------*/
/* Public typedef ---------------------------------------------------------*/
/* Public define ----------------------------------------------------------*/
/* Public macro -----------------------------------------------------------*/
/* Public variables -------------------------------------------------------*/
/* Public functions declaration -------------------------------------------*/

enum
{
	Success,
	Fail,
	ack_fail,
	invalid_pkt,
	ack_received,
	File_TX_Done
};

#define BLE_CFILE_LEN	        255
#define PASS_PKT_SIZE	        7
#define DATA_PKT_SIZE           8
#define BLENAME_ACKRSP	        "OK"
#define BLE_Name	        	"SunSt#1234#"
#define BLE_PASSCODE	        1234
#define INVALD_PASSCODE	        0000
#define BLEPKT_SIZE				11 		/* total 12 excluding size field 11 */
#define BLE_DEV_PASSCODE		"1234"
#define BLE_APP_PASSCODE		"aaaa"
#define BLE_NAK_PASSCODE		"0000"
#define RETRY_COUNT             3
#define PASSWORD_INSTANCE_ID    0x01
#define FUNC_ECU_PC_PASS_RESP   0x01
#define RECV_TIMEOUT            5      /* 500 milliseconds */
#define MAX_RETRANSMIT_COUNT    3
/*******protocol************/
#define CMD_PC_WRITE	        0xF1
#define CMD_PC_READ				0xF2
#define CMD_DATA_RX_RSP         0x02
#define CMD_DATA_RX_REQ         0x01 
#define CMD_READ_FUNC_CODE		0x03

#define RSP_PKT_SIZE            0x08
/***************************/
#define CONFIG_MEM_RAM_LOC      0x100000
#define CONFIG_MEM_RAM_SIZE     1024

/*GPIO PIN  NO FOR THE BLE_WAKEUP*/
#define Pin_BLEWP         		6

#define BLE_CS_HIGH()    		HAL_GPIO_WritePin(GPIOF, GPIO_PIN_7, GPIO_PIN_SET)
#define BLE_CS_LOW()     		HAL_GPIO_WritePin(GPIOF, GPIO_PIN_7, GPIO_PIN_RESET)

/* PC to ECU Function ids */
enum func_pc_ecu_id
{
	B_Password_Validate_Req=1,
	B_Data_Write_Pkt_Req,
	B_Data_Read_Pkt_Req_Resp
};

/* ECU to PC Function ids */
enum func_ecu_pc_id
{
	B_Password_Validate_Resp=1,
	B_Data_Write_Pkt_Resp,
	B_Data_Read_Pkt_Req
};

enum command_id
{
	None,
	B_password_validate,
	B_Req_Send_data
};

typedef struct _BLEPara
{
	uint8_t  Cmd_ID;
	uint8_t  Rx_Buff[30];
	uint8_t  Config_File_Data[BLE_CFILE_LEN];
	uint8_t  Instance_ID;
    uint16_t EndofFile;
	_Bool 	 passcode;
}BLE_t;

typedef struct _BProtos
{
	uint8_t  Pkt_size;
	uint8_t  function_code;
	uint8_t  command_Byte;
	uint8_t  instance_ID;
	uint8_t  Data[8];
}Proto_t;

uint8_t Waitfor_BLE_RSP(uint8_t *ACKRSPdata, uint16_t No_OfRetry);
void    Bluetooth_Init();
uint8_t Bluetooth_configfile_Send();
uint8_t Send_BLE_Config_Data(uint8_t sizeofpkt, uint8_t Fun_Code,uint8_t CByte,
								uint8_t Instance_ID,uint8_t *Cdata);
void    Send_BLE_Packet_Rsp(uint8_t sizeofpkt, uint8_t Fun_Code,uint8_t CByte,
								uint8_t Instance_ID);
void    Send_BLE_Data(uint8_t sizeofpkt, uint8_t Fun_Code, uint8_t CByte,
								uint8_t Instance_ID, uint8_t *Cdata);
void Send_BLE_Name(uint8_t sizeofpkt,
                             uint8_t Fun_Code,
                             uint8_t CByte,
                             uint8_t Instance_ID,
                             uint8_t *Cdata);
void Send_BLE_PKT(uint8_t *Cdata, uint8_t len);

void    SPI_Send(uint8_t *Data, uint8_t Len);
uint8_t proto_Data_process(uint8_t *Data);
uint8_t IS_SPI_Data_Available();
uint8_t Bluetooth_task();
uint8_t sendSDKPkt(uint8_t *buff, uint16_t size);

#endif	//__BLUETOOTH_H
/**************** (C) COPYRIGHT 2012 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/ 
