/****************************************************************************
              Copyright (c) 2022 Maxima Technologies and Systems
                           All Rights Reserved

   File Name          : LCD.c
   Author             :
   Version            : V0.0.0.1
   Origination Date   : 18/03/2022
   Description        : C Source File.
   Environment        : Independent
   Processor:         : STM32H743IIT6

-----------------------------------------------------------------------------
   Description:

   This file contains the LCD initialization

-----------------------------------------------------------------------------
	File Revision History:
-----------------------------------------------------------------------------
   Version             Date                 Programmer
   0.0.0.1             18/03/2022

   Notes:              - Initial Version
-----------------------------------------------------------------------------
*****************************************************************************
THIS FILE CONTAINS INTELLECTUAL PROPERTY OF MAXIMA TECHNOLOGIES AND SYSTEMS.
UNAUTHORIZED REDISTRIBUTION OF THIS SOURCE CODE, IN WHOLE OR PART, WITHOUT
THE EXPRESS WRITTEN PERMISSION OF MAXIMA TECHNOLOGIES IS STRICTLY PROHIBITED.
****************************************************************************/

/* USER CODE BEGIN Includes */
#include "../../../Core/Maximatecc/Inc/Common.h"
#include "stm32h7xx_hal_ltdc.h"
extern LTDC_HandleTypeDef hltdc;
/* Default LCD configuration with LCD Layer 1 */
#define LCD_LayerCfgTypeDef    LTDC_LayerCfgTypeDef

//static uint32_t            ActiveLayer = 0;

/** @brief Initializes the LCD layers
 *
 *  This function initialize the LCD Framebuffer layer.
 *
 *  @param  LayerIndex: the layer foreground or background.
 *          FB_Address: the layer frame buffer.
 *
 *  @return  None
 *
 */
#if 0
void BSP_LCD_LayerDefaultInit(uint16_t LayerIndex, uint32_t FB_Address)
{
	LTDC_LayerCfgTypeDef   Layercfg;

 /* Layer Init */
  Layercfg.WindowX0 = 0;
  Layercfg.WindowX1 = LCD_RESOlUTION_X0;
  Layercfg.WindowY0 = 0;
  Layercfg.WindowY1 = LCD_RESOlUTION_Y0;
  Layercfg.PixelFormat = LTDC_PIXEL_FORMAT_ARGB8888;
  Layercfg.FBStartAdress = FB_Address;
  Layercfg.Alpha = 255;
  Layercfg.Alpha0 = 0;
  Layercfg.Backcolor.Blue = 0;
  Layercfg.Backcolor.Green = 0;
  Layercfg.Backcolor.Red = 0;
  Layercfg.BlendingFactor1 = LTDC_BLENDING_FACTOR1_PAxCA;
  Layercfg.BlendingFactor2 = LTDC_BLENDING_FACTOR2_PAxCA;
  //Layercfg.ImageWidth = BSP_LCD_GetXSize();
  //Layercfg.ImageHeight = BSP_LCD_GetYSize();

  HAL_LTDC_ConfigLayer(&hltdc, &Layercfg, LayerIndex);

  /* Dithering activation */
  HAL_LTDC_EnableDither(&hltdc);
}
#endif

/**
  * @brief  Initializes the LCD layers.
  * @param  LayerIndex: Layer foreground or background
  * @param  FB_Address: Layer frame buffer
  * @retval None
  */
void BSP_LCD_LayerDefaultInit(uint16_t LayerIndex, uint32_t FB_Address, uint8_t format,
		   uint16_t X0,
		   uint16_t Y0,
		   uint16_t W0,
		   uint16_t H0
)
{
	LCD_LayerCfgTypeDef  Layercfg;

	/* Layer Init */
	Layercfg.WindowX0 = X0;
	Layercfg.WindowX1 = X0 + W0;
	Layercfg.WindowY0 = Y0;
	Layercfg.WindowY1 = Y0 + H0;

	if (0 == format)
		Layercfg.PixelFormat = LTDC_PIXEL_FORMAT_L8;
	else
		if(1 == format)
			Layercfg.PixelFormat = LTDC_PIXEL_FORMAT_RGB565;
		else
			if(2 == format)
				Layercfg.PixelFormat = LTDC_PIXEL_FORMAT_ARGB8888;
	Layercfg.FBStartAdress = FB_Address;
	Layercfg.Alpha = 255;
	Layercfg.Alpha0 = 0;
	Layercfg.Backcolor.Blue = 0;
	Layercfg.Backcolor.Green = 0;
	Layercfg.Backcolor.Red = 0;
	Layercfg.BlendingFactor1 = LTDC_BLENDING_FACTOR1_PAxCA;
	Layercfg.BlendingFactor2 = LTDC_BLENDING_FACTOR2_PAxCA;
	Layercfg.ImageWidth = W0;
	Layercfg.ImageHeight = H0;

	HAL_LTDC_ConfigLayer(&hltdc, &Layercfg, LayerIndex);
}

/**
  * @brief  Sets the Display window.
  * @param  LayerIndex: layer index
  * @param  Xpos: LCD X position
  * @param  Ypos: LCD Y position
  * @param  Width: LCD window width
  * @param  Height: LCD window height
  */
void BSP_LCD_SetLayerWindow(uint16_t LayerIndex, uint16_t Xpos, uint16_t Ypos, uint16_t Width, uint16_t Height)
{
	/* reconfigure the layer size */
	HAL_LTDC_SetWindowSize(&hltdc, Width, Height, LayerIndex);

	/* reconfigure the layer position */
	HAL_LTDC_SetWindowPosition(&hltdc, Xpos, Ypos, LayerIndex);
}


/**
  * @brief  Sets the Display window.
  * @param  LayerIndex: layer index
  * @param  Xpos: LCD X position
  * @param  Ypos: LCD Y position
  * @param  Width: LCD window width
  * @param  Height: LCD window height
  */

HAL_StatusTypeDef SetWindowPosition(LTDC_HandleTypeDef *hltdc,
		                            uint32_t X0,
									uint32_t Y0,
									uint16_t W0,
									uint16_t H0,
									uint32_t LayerIdx)
{
	LTDC_LayerCfgTypeDef *pLayerCfg;

	/* Change LTDC peripheral state */
	hltdc->State = HAL_LTDC_STATE_BUSY;

	/* Get layer configuration from handle structure */
	pLayerCfg = &hltdc->LayerCfg[LayerIdx];

	/* update horizontal start/stop */
	pLayerCfg->WindowX0 = X0;
	pLayerCfg->WindowX1 = X0 + W0;

	/* update vertical start/stop */
	pLayerCfg->WindowY0 = Y0;
	pLayerCfg->WindowY1 = Y0 + H0;

	/* Reconfigure the layer1 position  without Reloading*/
	HAL_LTDC_SetWindowPosition_NoReload(hltdc, X0, Y0, LayerIdx);

	/* Change the LTDC state*/
	hltdc->State = HAL_LTDC_STATE_READY;

	return HAL_OK;
}



void BSP_LCD_Config()
{
	/* LTDC Initialization -------------------------------------------------------*/

	/* Polarity configuration */
	/* Initialize the horizontal synchronization polarity as active low */
	hltdc.Init.HSPolarity = LTDC_HSPOLARITY_AL;

	/* Initialize the vertical synchronization polarity as active low */
	hltdc.Init.VSPolarity = LTDC_VSPOLARITY_AH;

	/* Initialize the data enable polarity as active low */
	hltdc.Init.DEPolarity = LTDC_DEPOLARITY_AL;

	/* Initialize the pixel clock polarity as input pixel clock */
	hltdc.Init.PCPolarity = LTDC_PCPOLARITY_IPC;

	/* Timing configuration */
	/* The RK043FN48H-CT672B LCD 480x272 is selected */
	/* Timing Configuration */
	hltdc.Init.HorizontalSync = 0;
	hltdc.Init.VerticalSync = 0;
	hltdc.Init.AccumulatedHBP = 43;
	hltdc.Init.AccumulatedVBP = 12;
	hltdc.Init.AccumulatedActiveH = 284;
	hltdc.Init.AccumulatedActiveW = 523;
	hltdc.Init.TotalHeigh = 285;
	hltdc.Init.TotalWidth = 525;

	/* Configure R,G,B component values for LCD background color */
	hltdc.Init.Backcolor.Blue = 0;
	hltdc.Init.Backcolor.Green = 0;
	hltdc.Init.Backcolor.Red = 0;

	hltdc.Instance = LTDC;
	/* Configure the LTDC */
	if(HAL_LTDC_Init(&hltdc) != HAL_OK)
	{
		/* Initialization Error */
		Error_Handler();
	}
}

/**************** (C) COPYRIGHT 2022 Maxima Technologies *******************/
/***************************** END OF FILE *********************************/
