#include <gui/lts_screen/LTSView.hpp>
#include "string.h"
#include <touchgfx/Color.hpp>
#include "../../../../Core/Maximatecc/user_modify_files/User_Define.h"

LTSView::LTSView()
{
#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)

	refresh_val = 0;
	uint8_t val = 0;
	key_position = 1;
	/* Active the first button */
	CT100.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
	CT100.invalidate();


	/* Get the Light Sensor conversion time */
	Get_DL(LIGHT_SENSOR_CONVERSION_TIME, &state);
	Unicode::snprintf(LTSCTBuffer, LTSCT_SIZE, "100");
	LTSCT.invalidate();

	/* Get the Light Sensor conversion mode */
	Get_DL(LIGHT_SENSOR_CONVERSION_MODE, &val);

	if (LS_SHUTDOWN == val)
	{
		STDWN.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		STDWN.invalidate();
		SMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		SMC.invalidate();
		CMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CMC.invalidate();

		Unicode::snprintf(LTSMTABuffer, LTSDATA_SIZE, "Shutdown");
		LTSMTA.invalidate();
		mode = val;
	}
	else
	if (LS_SINGLE_MODE_CONV == val)
	{
		STDWN.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		STDWN.invalidate();
		SMC.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		SMC.invalidate();
		CMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CMC.invalidate();

		Unicode::snprintf(LTSMTABuffer, LTSDATA_SIZE, "Single Mode");
		LTSMTA.invalidate();
		mode = val;
	}
	else
	if (LS_CONTINUOUS_MODE_CONV == val)
	{
		STDWN.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		STDWN.invalidate();
		SMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		SMC.invalidate();
		CMC.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CMC.invalidate();

		Unicode::snprintf(LTSMTABuffer, LTSDATA_SIZE, "Cont Mode");
		LTSMTA.invalidate();
		mode = val;
	}

#endif
}

#define REFRESH_TIME_IN_SEC 33
void LTSView::trigger()
{
#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)

	uint32_t val = 0;
	uint8_t lmode = 0;
	refresh_val++;
	if (REFRESH_TIME_IN_SEC == refresh_val)
	{
		refresh_val = 0;

		/* Get the Light Sensor Data */
		Get_DL(LIGHT_SENSOR_DATA , (uint8_t *)&val);
		Unicode::snprintf(LTSDATABuffer, LTSDATA_SIZE, "%d", val);
		LTSDATA.invalidate();

#if (SDK_SERVICE_LCD == PS_ENABLE)
		/* Set the LCD Brightness */
		if ((0 <= val) && (150 >= val) && (90 != brightness_value))
		{
			brightness_value = 90;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
		}
		else
		if ((150 < val) && (2500 >= val) && (50 != brightness_value))
		{
			brightness_value = 50;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
		}
		else
		if ((2501 <= val) && (10 != brightness_value))
		{
			brightness_value = 10;
			Set_DL(LCD_BRIGHTNESS, (uint8_t *)&brightness_value);
		}
#endif

	}

	if (LS_SINGLE_MODE_CONV == mode)
	{
		lmode = 0;

		/* Get the Light Sensor Data */
		Get_DL(LIGHT_SENSOR_TRIGGER , (uint8_t *)&lmode);
		if (0 == lmode)
		{
			Unicode::snprintf(LTSCMBuffer, LTSCM_SIZE, "SM Triggered");
			LTSCM.invalidate();
		}
	}
	else
	{

		Unicode::snprintf(LTSCMBuffer, LTSCM_SIZE, "  ");
		LTSCM.invalidate();
	}
#endif
}

void LTSView::setupScreen()
{
    LTSViewBase::setupScreen();
}

void LTSView::tearDownScreen()
{
    LTSViewBase::tearDownScreen();
}

void LTSView::keyUpdate(uint8_t val)
{
	if((KEY1_SHORT_PRESS == val) || (KEY1_LONG_PRESS == val))
		movePrevious();
	else
	if((KEY2_SHORT_PRESS == val) || (KEY2_LONG_PRESS == val))
		moveNext();
	else
	if((KEY3_SHORT_PRESS == val) || (KEY3_LONG_PRESS == val))
		moveEnter();
	else
	if((KEY4_SHORT_PRESS == val) || (KEY4_LONG_PRESS == val))
		moveBackScreen();
}


void LTSView::moveEnter()
{
#if (SDK_SERVICE_LIGHT_SENSOR == PS_ENABLE)

	uint8_t val;

	switch(key_position)
	{
		case 1:
			state = LS_CONVERSION_TIME_100;

			/* Set the Light Sensor conversion time */
			Set_DL(LIGHT_SENSOR_CONVERSION_TIME, &state);

			Unicode::snprintf(LTSCTBuffer, LTSCT_SIZE, "100");
			LTSCT.invalidate();
			break;
		case 2:
			state = LS_CONVERSION_TIME_800;

			/* Set the Light Sensor conversion time */
			Set_DL(LIGHT_SENSOR_CONVERSION_TIME, &state);

			Unicode::snprintf(LTSCTBuffer, LTSCT_SIZE, "800");
			LTSCT.invalidate();
			break;
		case 3:
			val = LS_SHUTDOWN;

			/* Set the Light Sensor conversion mode */
			Set_DL(LIGHT_SENSOR_CONVERSION_MODE, &val);

			Unicode::snprintf(LTSMTABuffer, LTSDATA_SIZE, "Shutdown");
			LTSMTA.invalidate();

			mode = val;

			break;
		case 4:
			val = LS_SINGLE_MODE_CONV;

			/* Set the Light Sensor conversion mode */
			Set_DL(LIGHT_SENSOR_CONVERSION_MODE, &val);
			Unicode::snprintf(LTSMTABuffer, LTSDATA_SIZE, "Single Mode");
			LTSMTA.invalidate();

			mode = val;
			break;
		case 5:
			val = LS_CONTINUOUS_MODE_CONV;

			/* Set the Light Sensor conversion mode */
			Set_DL(LIGHT_SENSOR_CONVERSION_MODE, &val);
			Unicode::snprintf(LTSMTABuffer, LTSDATA_SIZE, "Cont Mode");
			LTSMTA.invalidate();

			mode = val;
			break;

		default:
			break;
	}

#endif
}

void LTSView::moveBackScreen()
{
	application().gotoIngtestScreenNoTransition();
}

void LTSView::movePrevious()
{
	key_position--;

	if (0 == key_position)
		key_position = 6;

	switch(key_position)
	{
	case 1:
		/* DESelect the Keypad button */
		CT100.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CT100.invalidate();

		/* Select the Keypad button */
		CT800.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CT800.invalidate();
		break;

	case 2:
		/* DESelect the Keypad button */
		CT800.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CT800.invalidate();

		/* Select the Keypad button */
		STDWN.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		STDWN.invalidate();
		break;

	case 3:
		/* DESelect the Keypad button */
		STDWN.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		STDWN.invalidate();

		/* Select the Keypad button */
		SMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		SMC.invalidate();
		break;

	case 4:
		/* DESelect the Keypad button */
		SMC.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		SMC.invalidate();

		/* Select the Keypad button */
		CMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CMC.invalidate();
		break;

	case 5:
		/* DESelect the Keypad button */
		CMC.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CMC.invalidate();

		/* Select the Keypad button */
		CT100.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CT100.invalidate();

		break;
	default :
        break;
	}
}

void LTSView::moveNext()
{
	key_position++;

	if (6 == key_position)
		key_position = 1;

	switch(key_position)
	{
	case 1:
		/* DESelect the Keypad button */
		CMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CMC.invalidate();

		/* Select the Keypad button */
		CT100.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CT100.invalidate();
		break;

	case 2:
		/* DESelect the Keypad button */
		CT100.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CT100.invalidate();

		/* Select the Keypad button */
		CT800.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CT800.invalidate();
		break;

	case 3:
		/* DESelect the Keypad button */
		CT800.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		CT800.invalidate();

		/* Select the Keypad button */
		STDWN.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		STDWN.invalidate();
		break;

	case 4:
		/* DESelect the Keypad button */
		STDWN.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		STDWN.invalidate();

		/* Select the Keypad button */
		SMC.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		SMC.invalidate();
		break;

	case 5:
		/* DESelect the Keypad button */
		SMC.setColor(touchgfx::Color::getColorFromRGB(255, 255, 255));
		SMC.invalidate();

		/* Select the Keypad button */
		CMC.setColor(touchgfx::Color::getColorFromRGB(0, 0, 255));
		CMC.invalidate();
		break;

	default :
		break;
	}
}


void LTSView::watchdogstatus(uint8_t *val)
{
	*val = 0;
}
