/*
* j1939Slots.h - contains defines for all slot functions
*
* Copyright (c) 2014-2019 emotas embedded communication GmbH
*
*-------------------------------------------------------------------
* $Id: j1939_slots.h 29508 2019-10-14 14:49:54Z hil $
*-------------------------------------------------------------------
*
*
*
*/

/**
* \brief defines for all slot functions
*
* \file j1939Slots.h - contains defines for all slot functions
*
*/

#ifndef J1939_SLOTS_H
#define J1939_SLOTS_H 1

#include <co_datatype.h>


/***************************************************************************/
/**
* \brief j1939Slot1_toCAN - convert bit value to display value for slot 1
*
* Slot Name: SAEpr11
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098,
* 7471, 7472
*
* \param bitVal of Slot 1 has valid bit values from 0 to 1250
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot1_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot1_toDisp - convert bit value to display value for slot 1
*
* Slot Name: SAEpr11
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098,
* 7471, 7472
*
* \param bitVal of Slot 1 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot1_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot2_toCAN - convert bit value to display value for slot 2
*
* Slot Name: SAEpr13
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 46, 1086, 1087, 1088, 1089, 1090, 2603, 2604,
* 2605, 2606, 2607, 2608, 3191, 3193, 4334, 4335, 4387, 4388, 6305, 6306,
* 7350, 7459, 7464
*
* \param bitVal of Slot 2 has valid bit values from 0 to 2000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot2_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot2_toDisp - convert bit value to display value for slot 2
*
* Slot Name: SAEpr13
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 46, 1086, 1087, 1088, 1089, 1090, 2603, 2604,
* 2605, 2606, 2607, 2608, 3191, 3193, 4334, 4335, 4387, 4388, 6305, 6306,
* 7350, 7459, 7464
*
* \param bitVal of Slot 2 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot2_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot4_toCAN - convert bit value to display value for slot 4
*
* Slot Name: SAEtm10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1602, 1610
*
* \param bitVal of Slot 4 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot4_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot4_toDisp - convert bit value to display value for slot 4
*
* Slot Name: SAEtm10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1602, 1610
*
* \param bitVal of Slot 4 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot4_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot5_toCAN - convert bit value to display value for slot 5
*
* Slot Name: SAEtm12
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 916, 1350
*
* \param bitVal of Slot 5 has valid bit values from -32127 to 32128
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot5_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot5_toDisp - convert bit value to display value for slot 5
*
* Slot Name: SAEtm12
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 916, 1350
*
* \param bitVal of Slot 5 has valid bit values from 0 to 64255
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot5_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot7_toCAN - convert bit value to display value for slot 7
*
* Slot Name: SAEad01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 584, 585
*
* \param bitVal of Slot 7 has valid bit values from -210 to 211,1081215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot7_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot7_toDisp - convert bit value to display value for slot 7
*
* Slot Name: SAEad01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 584, 585
*
* \param bitVal of Slot 7 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot7_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot8_toCAN - convert bit value to display value for slot 8
*
* Slot Name: SAEad04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 583, 1413, 1414, 1415, 1416, 1417, 1418, 1419,
* 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431,
* 1432, 1433, 1434, 1435, 1436, 2516, 2517, 3331, 3623, 7355
*
* \param bitVal of Slot 8 has valid bit values from -200 to 301,99
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot8_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot8_toDisp - convert bit value to display value for slot 8
*
* Slot Name: SAEad04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 583, 1413, 1414, 1415, 1416, 1417, 1418, 1419,
* 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431,
* 1432, 1433, 1434, 1435, 1436, 2516, 2517, 3331, 3623, 7355
*
* \param bitVal of Slot 8 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot8_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot9_toCAN - convert bit value to display value for slot 9
*
* Slot Name: SAEad05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 165, 6486, 6490, 6494, 6498, 6502, 6506, 6510,
* 6514, 6518, 6522, 6526, 6530, 6534, 6538, 6542, 6546, 6550, 6554, 6558,
* 6562, 7940
*
* \param bitVal of Slot 9 has valid bit values from 0 to 501,99
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot9_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot9_toDisp - convert bit value to display value for slot 9
*
* Slot Name: SAEad05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 165, 6486, 6490, 6494, 6498, 6502, 6506, 6510,
* 6514, 6518, 6522, 6526, 6530, 6534, 6538, 6542, 6546, 6550, 6554, 6558,
* 6562, 7940
*
* \param bitVal of Slot 9 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot9_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot10_toCAN - convert bit value to display value for slot 10
*
* Slot Name: SAEad02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1577
*
* \param bitVal of Slot 10 has valid bit values from -3276,8 to 3148,7
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot10_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot10_toDisp - convert bit value to display value for slot 10
*
* Slot Name: SAEad02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1577
*
* \param bitVal of Slot 10 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot10_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot11_toCAN - convert bit value to display value for slot 11
*
* Slot Name: SAEad06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1120, 5582
*
* \param bitVal of Slot 11 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot11_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot11_toDisp - convert bit value to display value for slot 11
*
* Slot Name: SAEad06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1120, 5582
*
* \param bitVal of Slot 11 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot11_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot13_toCAN - convert bit value to display value for slot 13
*
* Slot Name: SAEds03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1574, 1575, 1576, 1579, 1721, 1722, 1723, 1724,
* 1732, 1735, 1757, 1758, 3365
*
* \param bitVal of Slot 13 has valid bit values from -3200 to 3225,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot13_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot13_toDisp - convert bit value to display value for slot 13
*
* Slot Name: SAEds03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1574, 1575, 1576, 1579, 1721, 1722, 1723, 1724,
* 1732, 1735, 1757, 1758, 3365
*
* \param bitVal of Slot 13 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot13_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot14_toCAN - convert bit value to display value for slot 14
*
* Slot Name: SAEds04
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 1580, 2794, 3087, 3517, 4369, 4428, 4435, 5823
*
* \param bitVal of Slot 14 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot14_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot14_toDisp - convert bit value to display value for slot 14
*
* Slot Name: SAEds04
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 1580, 2794, 3087, 3517, 4369, 4428, 4435, 5823
*
* \param bitVal of Slot 14 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot14_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot15_toCAN - convert bit value to display value for slot 15
*
* Slot Name: SAEds08
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 15 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot15_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot15_toDisp - convert bit value to display value for slot 15
*
* Slot Name: SAEds08
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 15 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot15_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot16_toCAN - convert bit value to display value for slot 16
*
* Slot Name: SAEel01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 184, 185, 1006, 1835
*
* \param bitVal of Slot 16 has valid bit values from 0 to 125,498046875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot16_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot16_toDisp - convert bit value to display value for slot 16
*
* Slot Name: SAEel01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 184, 185, 1006, 1835
*
* \param bitVal of Slot 16 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot16_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot17_toCAN - convert bit value to display value for slot 17
*
* Slot Name: SAEeg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1012
*
* \param bitVal of Slot 17 has valid bit values from 0 to 125,498046875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot17_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot17_toDisp - convert bit value to display value for slot 17
*
* Slot Name: SAEeg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1012
*
* \param bitVal of Slot 17 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot17_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot18_toCAN - convert bit value to display value for slot 18
*
* Slot Name: SAEfg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 132, 1031, 1241, 2659, 3467, 5257, 5684
*
* \param bitVal of Slot 18 has valid bit values from 0 to 3212,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot18_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot18_toDisp - convert bit value to display value for slot 18
*
* Slot Name: SAEfg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 132, 1031, 1241, 2659, 3467, 5257, 5684
*
* \param bitVal of Slot 18 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot18_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot19_toCAN - convert bit value to display value for slot 19
*
* Slot Name: SAEfv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1440, 1441
*
* \param bitVal of Slot 19 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot19_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot19_toDisp - convert bit value to display value for slot 19
*
* Slot Name: SAEfv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1440, 1441
*
* \param bitVal of Slot 19 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot19_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot20_toCAN - convert bit value to display value for slot 20
*
* Slot Name: SAEful01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 182, 236, 250, 1001, 1002, 1003, 1004, 1005,
* 1028
*
* \param bitVal of Slot 20 has valid bit values from 0 to 2105540607,5
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot20_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot20_toDisp - convert bit value to display value for slot 20
*
* Slot Name: SAEful01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 182, 236, 250, 1001, 1002, 1003, 1004, 1005,
* 1028
*
* \param bitVal of Slot 20 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot20_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot21_toCAN - convert bit value to display value for slot 21
*
* Slot Name: SAEfug01
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 1007, 1008, 1009, 1010, 1011, 1030, 1039, 1040
*
* \param bitVal of Slot 21 has valid bit values from 0 to 2105540607,5
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot21_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot21_toDisp - convert bit value to display value for slot 21
*
* Slot Name: SAEfug01
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 1007, 1008, 1009, 1010, 1011, 1030, 1039, 1040
*
* \param bitVal of Slot 21 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot21_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot22_toCAN - convert bit value to display value for slot 22
*
* Slot Name: SAEgg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 545
*
* \param bitVal of Slot 22 has valid bit values from 0 to 50,2
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot22_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot22_toDisp - convert bit value to display value for slot 22
*
* Slot Name: SAEgg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 545
*
* \param bitVal of Slot 22 has valid bit values from 0 to 64256
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot22_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot23_toCAN - convert bit value to display value for slot 23
*
* Slot Name: SAEgr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1255, 1257, 1259
*
* \param bitVal of Slot 23 has valid bit values from 0 to 642,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot23_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot23_toDisp - convert bit value to display value for slot 23
*
* Slot Name: SAEgr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1255, 1257, 1259
*
* \param bitVal of Slot 23 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot23_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot24_toCAN - convert bit value to display value for slot 24
*
* Slot Name: SAEgv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 523, 524, 525, 1113, 1114, 1115, 3289, 5957,
* 5958
*
* \param bitVal of Slot 24 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot24_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot24_toDisp - convert bit value to display value for slot 24
*
* Slot Name: SAEgv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 523, 524, 525, 1113, 1114, 1115, 3289, 5957,
* 5958
*
* \param bitVal of Slot 24 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot24_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot27_toCAN - convert bit value to display value for slot 27
*
* Slot Name: SAEma11
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 582
*
* \param bitVal of Slot 27 has valid bit values from 0 to 32127,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot27_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot27_toDisp - convert bit value to display value for slot 27
*
* Slot Name: SAEma11
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 582
*
* \param bitVal of Slot 27 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot27_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot28_toCAN - convert bit value to display value for slot 28
*
* Slot Name: SAEma02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 180, 181, 407, 408, 409, 6841, 6853, 6872
*
* \param bitVal of Slot 28 has valid bit values from 0 to 128510
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot28_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot28_toDisp - convert bit value to display value for slot 28
*
* Slot Name: SAEma02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 180, 181, 407, 408, 409, 6841, 6853, 6872
*
* \param bitVal of Slot 28 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot28_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot29_toCAN - convert bit value to display value for slot 29
*
* Slot Name: SAEma03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1585, 1760
*
* \param bitVal of Slot 29 has valid bit values from 0 to 642550
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot29_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot29_toDisp - convert bit value to display value for slot 29
*
* Slot Name: SAEma03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1585, 1760
*
* \param bitVal of Slot 29 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot29_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot30_toCAN - convert bit value to display value for slot 30
*
* Slot Name: SAEpc01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 27, 633, 649, 1117, 1118, 1119, 1244, 2791,
* 3464, 3465, 3470, 3479, 3487, 3493, 3501, 3821, 3822, 4078, 4783, 4784, 4788,
* 4789, 5262, 5263, 5264, 5265, 5266, 5267, 5268, 5269, 5270, 5271, 5276, 5277,
* 5278, 5279, 5369, 5386, 5387, 5425, 5428, 5458, 5464, 5466, 5467, 5495, 5496,
* 5497, 5498, 5502, 5637, 5639, 5641, 5643, 5649, 5651, 5653, 5655, 5867, 5981,
* 6201, 6719, 6720, 7094, 7421, 7422, 7593, 7594, 7903, 7911, 7919, 7927
*
* \param bitVal of Slot 30 has valid bit values from 0 to 160,6375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot30_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot30_toDisp - convert bit value to display value for slot 30
*
* Slot Name: SAEpc01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 27, 633, 649, 1117, 1118, 1119, 1244, 2791,
* 3464, 3465, 3470, 3479, 3487, 3493, 3501, 3821, 3822, 4078, 4783, 4784, 4788,
* 4789, 5262, 5263, 5264, 5265, 5266, 5267, 5268, 5269, 5270, 5271, 5276, 5277,
* 5278, 5279, 5369, 5386, 5387, 5425, 5428, 5458, 5464, 5466, 5467, 5495, 5496,
* 5497, 5498, 5502, 5637, 5639, 5641, 5643, 5649, 5651, 5653, 5655, 5867, 5981,
* 6201, 6719, 6720, 7094, 7421, 7422, 7593, 7594, 7903, 7911, 7919, 7927
*
* \param bitVal of Slot 30 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot30_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot31_toCAN - convert bit value to display value for slot 31
*
* Slot Name: SAEr02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 31 has valid bit values from 0 to 25
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot31_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot31_toDisp - convert bit value to display value for slot 31
*
* Slot Name: SAEr02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 31 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot31_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot32_toCAN - convert bit value to display value for slot 32
*
* Slot Name: SAEr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 526, 581, 1767, 3030, 5024, 5031, 5038, 5045,
* 6392, 6575, 6576, 6577, 6578
*
* \param bitVal of Slot 32 has valid bit values from 0 to 64,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot32_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot32_toDisp - convert bit value to display value for slot 32
*
* Slot Name: SAEr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 526, 581, 1767, 3030, 5024, 5031, 5038, 5045,
* 6392, 6575, 6576, 6577, 6578
*
* \param bitVal of Slot 32 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot32_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot34_toCAN - convert bit value to display value for slot 34
*
* Slot Name: SAErv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 249
*
* \param bitVal of Slot 34 has valid bit values from 0 to 4211081215000
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot34_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot34_toDisp - convert bit value to display value for slot 34
*
* Slot Name: SAErv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 249
*
* \param bitVal of Slot 34 has valid bit values from 0 to 4211081215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot34_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot36_toCAN - convert bit value to display value for slot 36
*
* Slot Name: SAEds10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 244, 245, 990, 991, 992, 998, 999, 1000, 1019,
* 1032, 5827, 5828, 6940, 6947
*
* \param bitVal of Slot 36 has valid bit values from 0 to 526385151,875
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot36_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot36_toDisp - convert bit value to display value for slot 36
*
* Slot Name: SAEds10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 244, 245, 990, 991, 992, 998, 999, 1000, 1019,
* 1032, 5827, 5828, 6940, 6947
*
* \param bitVal of Slot 36 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot36_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot37_toCAN - convert bit value to display value for slot 37
*
* Slot Name: SAEds11
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 914
*
* \param bitVal of Slot 37 has valid bit values from -160635 to 160640
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot37_toCAN(INTEGER32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot37_toDisp - convert bit value to display value for slot 37
*
* Slot Name: SAEds11
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 914
*
* \param bitVal of Slot 37 has valid bit values from 0 to 64255
*
* \return INTEGER32 display value
*
*/
EXTERN_DECL INTEGER32 j1939Slot37_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot38_toCAN - convert bit value to display value for slot 38
*
* Slot Name: SAEds09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 917, 918
*
* \param bitVal of Slot 38 has valid bit values from 0 to 21055406075
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot38_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot38_toDisp - convert bit value to display value for slot 38
*
* Slot Name: SAEds09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 917, 918
*
* \param bitVal of Slot 38 has valid bit values from 0 to 4211081215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot38_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot39_toCAN - convert bit value to display value for slot 39
*
* Slot Name: SAEds06
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 580
*
* \param bitVal of Slot 39 has valid bit values from -2500 to 5531,875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot39_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot39_toDisp - convert bit value to display value for slot 39
*
* Slot Name: SAEds06
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 580
*
* \param bitVal of Slot 39 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot39_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot40_toCAN - convert bit value to display value for slot 40
*
* Slot Name: SAEec02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 114, 5563
*
* \param bitVal of Slot 40 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot40_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot40_toDisp - convert bit value to display value for slot 40
*
* Slot Name: SAEec02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 114, 5563
*
* \param bitVal of Slot 40 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot40_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot42_toCAN - convert bit value to display value for slot 42
*
* Slot Name: SAEfl01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 183, 1029, 1834, 3481, 3495, 3826, 3828, 4417,
* 4418, 7596
*
* \param bitVal of Slot 42 has valid bit values from 0 to 3212,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot42_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot42_toDisp - convert bit value to display value for slot 42
*
* Slot Name: SAEfl01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 183, 1029, 1834, 3481, 3495, 3826, 3828, 4417,
* 4418, 7596
*
* \param bitVal of Slot 42 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot42_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot43_toCAN - convert bit value to display value for slot 43
*
* Slot Name: SAEfr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3308
*
* \param bitVal of Slot 43 has valid bit values from 0 to 321275
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot43_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot43_toDisp - convert bit value to display value for slot 43
*
* Slot Name: SAEfr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3308
*
* \param bitVal of Slot 43 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot43_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot44_toCAN - convert bit value to display value for slot 44
*
* Slot Name: SAEpc03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 28, 29, 38, 51, 53, 54, 59, 60, 72, 80, 91,
* 96, 98, 111, 124, 354, 521, 522, 641, 684, 973, 974, 975, 986, 1015, 1016,
* 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106, 1134, 1188, 1189, 1190, 1191,
* 1210, 1380, 1442, 1443, 1487, 1550, 1689, 1693, 1708, 1716, 1718, 1719, 1720,
* 1729, 1730, 1731, 1761, 1765, 1766, 1844, 2602, 2610, 2623, 2624, 2625, 2626,
* 2795, 2802, 2869, 2870, 2871, 2878, 2983, 3357, 3363, 3371, 3445, 3488, 3502,
* 3548, 3644, 3668, 3672, 3673, 3675, 3676, 4099, 4177, 4194, 4197, 4200, 4212,
* 4218, 4219, 4220, 4301, 4302, 4336, 4364, 4367, 4372, 4375, 4376, 4389, 4419,
* 4426, 4431, 4433, 4438, 4441, 4442, 4752, 4812, 4813, 4814, 5137, 5138, 5260,
* 5261, 5282, 5285, 5288, 5292, 5366, 5370, 5373, 5374, 5377, 5388, 5389, 5414,
* 5415, 5434, 5436, 5437, 5439, 5532, 5543, 5546, 5547, 5548, 5625, 5706, 5707,
* 5766, 5770, 5776, 5780, 5789, 5941, 5942, 5943, 5944, 5945, 5946, 5947, 5948,
* 6270, 6271, 6272, 6273, 6274, 6275, 6276, 6277, 6278, 6279, 6280, 6281, 6282,
* 6283, 6284, 6285, 6286, 6287, 6288, 6289, 6290, 6291, 6292, 6293, 6314, 6315,
* 6582, 6642, 6643, 6644, 6645, 6730, 6820, 6874, 7016, 7017, 7018, 7025, 7081,
* 7082, 7083, 7084, 7085, 7086, 7087, 7091, 7092, 7347, 7348, 7349, 7442, 7474,
* 7530, 7531, 7536, 7537, 7556, 7573, 7575, 7606, 7785, 7797, 7799, 7800, 7801,
* 7809, 7811, 7812, 7813, 7834, 7891, 7892, 7895
*
* \param bitVal of Slot 44 has valid bit values from 0 to 100
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot44_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot44_toDisp - convert bit value to display value for slot 44
*
* Slot Name: SAEpc03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 28, 29, 38, 51, 53, 54, 59, 60, 72, 80, 91,
* 96, 98, 111, 124, 354, 521, 522, 641, 684, 973, 974, 975, 986, 1015, 1016,
* 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106, 1134, 1188, 1189, 1190, 1191,
* 1210, 1380, 1442, 1443, 1487, 1550, 1689, 1693, 1708, 1716, 1718, 1719, 1720,
* 1729, 1730, 1731, 1761, 1765, 1766, 1844, 2602, 2610, 2623, 2624, 2625, 2626,
* 2795, 2802, 2869, 2870, 2871, 2878, 2983, 3357, 3363, 3371, 3445, 3488, 3502,
* 3548, 3644, 3668, 3672, 3673, 3675, 3676, 4099, 4177, 4194, 4197, 4200, 4212,
* 4218, 4219, 4220, 4301, 4302, 4336, 4364, 4367, 4372, 4375, 4376, 4389, 4419,
* 4426, 4431, 4433, 4438, 4441, 4442, 4752, 4812, 4813, 4814, 5137, 5138, 5260,
* 5261, 5282, 5285, 5288, 5292, 5366, 5370, 5373, 5374, 5377, 5388, 5389, 5414,
* 5415, 5434, 5436, 5437, 5439, 5532, 5543, 5546, 5547, 5548, 5625, 5706, 5707,
* 5766, 5770, 5776, 5780, 5789, 5941, 5942, 5943, 5944, 5945, 5946, 5947, 5948,
* 6270, 6271, 6272, 6273, 6274, 6275, 6276, 6277, 6278, 6279, 6280, 6281, 6282,
* 6283, 6284, 6285, 6286, 6287, 6288, 6289, 6290, 6291, 6292, 6293, 6314, 6315,
* 6582, 6642, 6643, 6644, 6645, 6730, 6820, 6874, 7016, 7017, 7018, 7025, 7081,
* 7082, 7083, 7084, 7085, 7086, 7087, 7091, 7092, 7347, 7348, 7349, 7442, 7474,
* 7530, 7531, 7536, 7537, 7556, 7573, 7575, 7606, 7785, 7797, 7799, 7800, 7801,
* 7809, 7811, 7812, 7813, 7834, 7891, 7892, 7895
*
* \param bitVal of Slot 44 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot44_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot45_toCAN - convert bit value to display value for slot 45
*
* Slot Name: SAEpc05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 512, 513, 514, 518, 520, 537, 538, 539, 540,
* 541, 542, 543, 551, 552, 553, 554, 555, 1085, 1393, 1394, 1395, 1396, 1397,
* 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410,
* 1411, 1412, 1694, 1695, 1715, 1717, 1770, 1771, 1774, 1775, 1778, 1779, 1782,
* 1783, 1786, 1787, 1790, 1791, 2432, 2601, 2978, 5398, 5471, 5472, 5473, 5474,
* 5475, 5476, 5477, 6807, 6873, 7040, 7827, 7828
*
* \param bitVal of Slot 45 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot45_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot45_toDisp - convert bit value to display value for slot 45
*
* Slot Name: SAEpc05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 512, 513, 514, 518, 520, 537, 538, 539, 540,
* 541, 542, 543, 551, 552, 553, 554, 555, 1085, 1393, 1394, 1395, 1396, 1397,
* 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410,
* 1411, 1412, 1694, 1695, 1715, 1717, 1770, 1771, 1774, 1775, 1778, 1779, 1782,
* 1783, 1786, 1787, 1790, 1791, 2432, 2601, 2978, 5398, 5471, 5472, 5473, 5474,
* 5475, 5476, 5477, 6807, 6873, 7040, 7827, 7828
*
* \param bitVal of Slot 45 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot45_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot47_toCAN - convert bit value to display value for slot 47
*
* Slot Name: SAEpr10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 20, 82, 94, 100, 104, 116, 117, 118, 241, 579,
* 1168, 1192, 1203, 1208, 2613, 2614, 3549, 4811, 5578, 5579, 5580, 6811,
* 6812, 6813, 6832, 6837, 6838, 6839, 6875, 6876, 7313, 7720, 7721
*
* \param bitVal of Slot 47 has valid bit values from 0 to 1000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot47_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot47_toDisp - convert bit value to display value for slot 47
*
* Slot Name: SAEpr10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 20, 82, 94, 100, 104, 116, 117, 118, 241, 579,
* 1168, 1192, 1203, 1208, 2613, 2614, 3549, 4811, 5578, 5579, 5580, 6811,
* 6812, 6813, 6832, 6837, 6838, 6839, 6875, 6876, 7313, 7720, 7721
*
* \param bitVal of Slot 47 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot47_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot48_toCAN - convert bit value to display value for slot 48
*
* Slot Name: SAEpr02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 22, 107, 1264, 2809, 2810, 2811
*
* \param bitVal of Slot 48 has valid bit values from 0 to 12,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot48_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot48_toDisp - convert bit value to display value for slot 48
*
* Slot Name: SAEpr02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 22, 107, 1264, 2809, 2810, 2811
*
* \param bitVal of Slot 48 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot48_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot49_toCAN - convert bit value to display value for slot 49
*
* Slot Name: SAEpr14
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 73, 119, 123, 127, 1387, 1388, 2609, 4087, 5937,
* 6831
*
* \param bitVal of Slot 49 has valid bit values from 0 to 4000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot49_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot49_toDisp - convert bit value to display value for slot 49
*
* Slot Name: SAEpr14
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 73, 119, 123, 127, 1387, 1388, 2609, 4087, 5937,
* 6831
*
* \param bitVal of Slot 49 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot49_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot50_toCAN - convert bit value to display value for slot 50
*
* Slot Name: SAEpr06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 136, 137, 138, 141, 142, 143, 144, 145, 146,
* 159, 1320, 1707, 4211, 4751, 4773, 5259, 6715, 6814, 7063, 7064, 7065, 7066,
* 7067, 7068
*
* \param bitVal of Slot 50 has valid bit values from 0 to 32127,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot50_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot50_toDisp - convert bit value to display value for slot 50
*
* Slot Name: SAEpr06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 136, 137, 138, 141, 142, 143, 144, 145, 146,
* 159, 1320, 1707, 4211, 4751, 4773, 5259, 6715, 6814, 7063, 7064, 7065, 7066,
* 7067, 7068
*
* \param bitVal of Slot 50 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot50_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot51_toCAN - convert bit value to display value for slot 51
*
* Slot Name: SAEpr09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 129, 156, 157, 164, 1349, 2948, 4287, 5313,
* 5314, 6589, 6590, 6591, 6592, 6646
*
* \param bitVal of Slot 51 has valid bit values from 0 to 250,996
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot51_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot51_toDisp - convert bit value to display value for slot 51
*
* Slot Name: SAEpr09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 129, 156, 157, 164, 1349, 2948, 4287, 5313,
* 5314, 6589, 6590, 6591, 6592, 6646
*
* \param bitVal of Slot 51 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot51_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot52_toCAN - convert bit value to display value for slot 52
*
* Slot Name: SAEpr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 101, 411, 1176, 1177, 1178, 1179, 1209, 3830,
* 3833, 5252, 6321
*
* \param bitVal of Slot 52 has valid bit values from -250 to 251,99
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot52_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot52_toDisp - convert bit value to display value for slot 52
*
* Slot Name: SAEpr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 101, 411, 1176, 1177, 1178, 1179, 1209, 3830,
* 3833, 5252, 6321
*
* \param bitVal of Slot 52 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot52_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot53_toCAN - convert bit value to display value for slot 53
*
* Slot Name: SAEpr07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 16, 95, 102, 106, 109, 126, 1381, 1382, 2435,
* 2631, 3340, 3341, 3358, 3562, 3563, 5019, 5253, 5417, 5422, 5541, 5542,
* 5544, 5545, 5708, 7104
*
* \param bitVal of Slot 53 has valid bit values from 0 to 500
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot53_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot53_toDisp - convert bit value to display value for slot 53
*
* Slot Name: SAEpr07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 16, 95, 102, 106, 109, 126, 1381, 1382, 2435,
* 2631, 3340, 3341, 3358, 3562, 3563, 5019, 5253, 5417, 5422, 5541, 5542,
* 5544, 5545, 5708, 7104
*
* \param bitVal of Slot 53 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot53_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot54_toCAN - convert bit value to display value for slot 54
*
* Slot Name: SAEpr05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 81, 99, 108, 112
*
* \param bitVal of Slot 54 has valid bit values from 0 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot54_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot54_toDisp - convert bit value to display value for slot 54
*
* Slot Name: SAEpr05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 81, 99, 108, 112
*
* \param bitVal of Slot 54 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot54_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot55_toCAN - convert bit value to display value for slot 55
*
* Slot Name: SAEpw03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 166, 1204, 1242, 1247, 4999
*
* \param bitVal of Slot 55 has valid bit values from 0 to 32127,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot55_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot55_toDisp - convert bit value to display value for slot 55
*
* Slot Name: SAEpw03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 166, 1204, 1242, 1247, 4999
*
* \param bitVal of Slot 55 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot55_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot57_toCAN - convert bit value to display value for slot 57
*
* Slot Name: SAEtm01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451,
* 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463,
* 1464, 1465
*
* \param bitVal of Slot 57 has valid bit values from 0 to 642,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot57_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot57_toDisp - convert bit value to display value for slot 57
*
* Slot Name: SAEtm01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451,
* 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463,
* 1464, 1465
*
* \param bitVal of Slot 57 has valid bit values from 0 to 64254999
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot57_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot58_toCAN - convert bit value to display value for slot 58
*
* Slot Name: SAEtm09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 235, 246, 247, 248, 994, 995, 996, 997, 1017,
* 1024, 1025, 1026, 1027, 1033, 1034, 1035, 1036, 1037, 1038, 1253, 6220,
* 6221, 6319, 6320
*
* \param bitVal of Slot 58 has valid bit values from 0 to 210554060,75
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot58_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot58_toDisp - convert bit value to display value for slot 58
*
* Slot Name: SAEtm09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 235, 246, 247, 248, 994, 995, 996, 997, 1017,
* 1024, 1025, 1026, 1027, 1033, 1034, 1035, 1036, 1037, 1038, 1253, 6220,
* 6221, 6319, 6320
*
* \param bitVal of Slot 58 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot58_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot59_toCAN - convert bit value to display value for slot 59
*
* Slot Name: SAEtm03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 534, 7591
*
* \param bitVal of Slot 59 has valid bit values from 0 to 25
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot59_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot59_toDisp - convert bit value to display value for slot 59
*
* Slot Name: SAEtm03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 534, 7591
*
* \param bitVal of Slot 59 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot59_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot60_toCAN - convert bit value to display value for slot 60
*
* Slot Name: SAEcd01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 962, 1251, 1607
*
* \param bitVal of Slot 60 has valid bit values from 0 to 62,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot60_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot60_toDisp - convert bit value to display value for slot 60
*
* Slot Name: SAEcd01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 962, 1251, 1607
*
* \param bitVal of Slot 60 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot60_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot63_toCAN - convert bit value to display value for slot 63
*
* Slot Name: SAEtm04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 959, 1603, 4998
*
* \param bitVal of Slot 63 has valid bit values from 0 to 62,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot63_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot63_toDisp - convert bit value to display value for slot 63
*
* Slot Name: SAEtm04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 959, 1603, 4998
*
* \param bitVal of Slot 63 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot63_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot65_toCAN - convert bit value to display value for slot 65
*
* Slot Name: SAEcw01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 915
*
* \param bitVal of Slot 65 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot65_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot65_toDisp - convert bit value to display value for slot 65
*
* Slot Name: SAEcw01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 915
*
* \param bitVal of Slot 65 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot65_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot66_toCAN - convert bit value to display value for slot 66
*
* Slot Name: SAEcy01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 964, 1252, 1608
*
* \param bitVal of Slot 66 has valid bit values from 1985 to 2235
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot66_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot66_toDisp - convert bit value to display value for slot 66
*
* Slot Name: SAEcy01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 964, 1252, 1608
*
* \param bitVal of Slot 66 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot66_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot67_toCAN - convert bit value to display value for slot 67
*
* Slot Name: SAEtp01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 52, 75, 90, 105, 110, 120, 172, 174, 441, 442,
* 578, 1122, 1123, 1124, 1125, 1126, 1131, 1132, 1133, 1212, 1385, 1386,
* 1638, 1687, 1688, 1800, 1801, 1802, 1803, 2775, 2776, 2779, 2780, 3031, 3468,
* 3515, 4076, 4193, 4196, 4199, 4337, 4368, 4390, 4420, 4427, 4434, 5148, 5456,
* 5480, 5561, 5569, 5570, 5656, 5765, 5769, 5775, 5779, 5783, 5784, 5785, 5786,
* 5787, 5788, 5790, 5791, 5792, 5938, 6209, 6214, 6215, 6313, 6610, 6815, 6978,
* 6984, 7020, 7023, 7024, 7043, 7044, 7045, 7046, 7047, 7048, 7049, 7050, 7051,
* 7052, 7053, 7054, 7055, 7056, 7057, 7058, 7059, 7060, 7061, 7062, 7090, 7314,
* 7460, 7465, 7514, 7528, 7529, 7535, 7572, 7574, 7607, 7850, 7901, 7909, 7917,
* 7925
*
* \param bitVal of Slot 67 has valid bit values from -40 to 210
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot67_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot67_toDisp - convert bit value to display value for slot 67
*
* Slot Name: SAEtp01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 52, 75, 90, 105, 110, 120, 172, 174, 441, 442,
* 578, 1122, 1123, 1124, 1125, 1126, 1131, 1132, 1133, 1212, 1385, 1386,
* 1638, 1687, 1688, 1800, 1801, 1802, 1803, 2775, 2776, 2779, 2780, 3031, 3468,
* 3515, 4076, 4193, 4196, 4199, 4337, 4368, 4390, 4420, 4427, 4434, 5148, 5456,
* 5480, 5561, 5569, 5570, 5656, 5765, 5769, 5775, 5779, 5783, 5784, 5785, 5786,
* 5787, 5788, 5790, 5791, 5792, 5938, 6209, 6214, 6215, 6313, 6610, 6815, 6978,
* 6984, 7020, 7023, 7024, 7043, 7044, 7045, 7046, 7047, 7048, 7049, 7050, 7051,
* 7052, 7053, 7054, 7055, 7056, 7057, 7058, 7059, 7060, 7061, 7062, 7090, 7314,
* 7460, 7465, 7514, 7528, 7529, 7535, 7572, 7574, 7607, 7850, 7901, 7909, 7917,
* 7925
*
* \param bitVal of Slot 67 has valid bit values from 0 to 250
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot67_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot68_toCAN - convert bit value to display value for slot 68
*
* Slot Name: SAEtp02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 21, 79, 169, 170, 171, 173, 175, 176, 177,
* 242, 412, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145,
* 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158,
* 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166, 1167, 1172, 1173, 1174, 1175,
* 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1207, 1636, 1637, 1691, 2433,
* 2434, 2629, 2630, 2789, 2790, 2799, 2800, 2801, 2986, 3241, 3242, 3245, 3246,
* 3249, 3250, 3275, 3276, 3279, 3280, 3283, 3284, 3823, 3831, 3834, 4151, 4152,
* 4153, 4288, 4289, 4290, 4295, 4296, 4360, 4363, 4413, 4415, 4750, 4753, 4754,
* 4759, 4760, 4765, 4766, 4771, 4772, 4777, 4778, 4779, 4780, 4809, 4810, 5020,
* 5255, 5256, 5258, 5280, 5281, 5283, 5284, 5286, 5287, 5289, 5290, 5291, 5315,
* 5316, 5501, 5536, 5540, 5581, 5862, 5864, 5913, 5925, 5969, 5970, 6374, 6780,
* 6785, 6830, 7441, 7693, 7703, 7704, 7705, 7706, 7707, 7951, 7975, 7987, 7999,
* 8011, 8023, 8035, 8047, 8059, 8071
*
* \param bitVal of Slot 68 has valid bit values from -273 to 1734,96875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot68_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot68_toDisp - convert bit value to display value for slot 68
*
* Slot Name: SAEtp02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 21, 79, 169, 170, 171, 173, 175, 176, 177,
* 242, 412, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145,
* 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158,
* 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166, 1167, 1172, 1173, 1174, 1175,
* 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1207, 1636, 1637, 1691, 2433,
* 2434, 2629, 2630, 2789, 2790, 2799, 2800, 2801, 2986, 3241, 3242, 3245, 3246,
* 3249, 3250, 3275, 3276, 3279, 3280, 3283, 3284, 3823, 3831, 3834, 4151, 4152,
* 4153, 4288, 4289, 4290, 4295, 4296, 4360, 4363, 4413, 4415, 4750, 4753, 4754,
* 4759, 4760, 4765, 4766, 4771, 4772, 4777, 4778, 4779, 4780, 4809, 4810, 5020,
* 5255, 5256, 5258, 5280, 5281, 5283, 5284, 5286, 5287, 5289, 5290, 5291, 5315,
* 5316, 5501, 5536, 5540, 5581, 5862, 5864, 5913, 5925, 5969, 5970, 6374, 6780,
* 6785, 6830, 7441, 7693, 7703, 7704, 7705, 7706, 7707, 7951, 7975, 7987, 7999,
* 8011, 8023, 8035, 8047, 8059, 8071
*
* \param bitVal of Slot 68 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot68_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot69_toCAN - convert bit value to display value for slot 69
*
* Slot Name: SAEtq01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 69 has valid bit values from -32000 to 32255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot69_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot69_toDisp - convert bit value to display value for slot 69
*
* Slot Name: SAEtq01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 69 has valid bit values from 0 to 64255
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot69_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot71_toCAN - convert bit value to display value for slot 71
*
* Slot Name: SAEvl02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 84, 517, 904, 1018, 1592, 1593, 1594, 1595,
* 1624, 6808, 6809, 6829, 7319, 7420, 7495
*
* \param bitVal of Slot 71 has valid bit values from 0 to 250,996
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot71_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot71_toDisp - convert bit value to display value for slot 71
*
* Slot Name: SAEvl02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 84, 517, 904, 1018, 1592, 1593, 1594, 1595,
* 1624, 6808, 6809, 6829, 7319, 7420, 7495
*
* \param bitVal of Slot 71 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot71_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot72_toCAN - convert bit value to display value for slot 72
*
* Slot Name: SAEvl03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 72 has valid bit values from -250 to 251,992
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot72_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot72_toDisp - convert bit value to display value for slot 72
*
* Slot Name: SAEvl03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 72 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot72_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot74_toCAN - convert bit value to display value for slot 74
*
* Slot Name: SAEvl04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 905, 906, 907, 908, 909, 910
*
* \param bitVal of Slot 74 has valid bit values from -7,8125 to 7,8125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot74_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot74_toDisp - convert bit value to display value for slot 74
*
* Slot Name: SAEvl04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 905, 906, 907, 908, 909, 910
*
* \param bitVal of Slot 74 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot74_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot75_toCAN - convert bit value to display value for slot 75
*
* Slot Name: SAEvm1
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3522, 3526, 3733, 3741, 5963, 5964, 7597
*
* \param bitVal of Slot 75 has valid bit values from 0 to 2105540607,5
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot75_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot75_toDisp - convert bit value to display value for slot 75
*
* Slot Name: SAEvm1
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3522, 3526, 3733, 3741, 5963, 5964, 7597
*
* \param bitVal of Slot 75 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot75_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot76_toCAN - convert bit value to display value for slot 76
*
* Slot Name: SAEvr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 160, 161, 186, 187, 188, 189, 190, 191, 515,
* 528, 529, 530, 531, 532, 533, 546, 547, 548, 549, 550, 898, 1013, 1014,
* 1598, 1623, 1639, 1712, 3560, 5052, 5960, 5961, 7779, 7780
*
* \param bitVal of Slot 76 has valid bit values from 0 to 8031,875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot76_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot76_toDisp - convert bit value to display value for slot 76
*
* Slot Name: SAEvr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 160, 161, 186, 187, 188, 189, 190, 191, 515,
* 528, 529, 530, 531, 532, 533, 546, 547, 548, 549, 550, 898, 1013, 1014,
* 1598, 1623, 1639, 1712, 3560, 5052, 5960, 5961, 7779, 7780
*
* \param bitVal of Slot 76 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot76_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot77_toCAN - convert bit value to display value for slot 77
*
* Slot Name: SAEvr03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 103, 1169, 1170, 1171, 3343, 5980
*
* \param bitVal of Slot 77 has valid bit values from 0 to 257020
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot77_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot77_toDisp - convert bit value to display value for slot 77
*
* Slot Name: SAEvr03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 103, 1169, 1170, 1171, 3343, 5980
*
* \param bitVal of Slot 77 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot77_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot78_toCAN - convert bit value to display value for slot 78
*
* Slot Name: SAEvr02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 589, 723, 4201, 4202, 4374, 4440, 5554, 5562,
* 7461, 7466, 7846, 7945, 7950, 7969, 7974, 7981, 7986, 7993, 7998, 8005,
* 8010, 8017, 8022, 8029, 8034, 8041, 8046, 8053, 8058, 8065, 8070
*
* \param bitVal of Slot 78 has valid bit values from 0 to 32127,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot78_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot78_toDisp - convert bit value to display value for slot 78
*
* Slot Name: SAEvr02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 589, 723, 4201, 4202, 4374, 4440, 5554, 5562,
* 7461, 7466, 7846, 7945, 7950, 7969, 7974, 7981, 7986, 7993, 7998, 8005,
* 8010, 8017, 8022, 8029, 8034, 8041, 8046, 8053, 8058, 8065, 8070
*
* \param bitVal of Slot 78 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot78_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot79_toCAN - convert bit value to display value for slot 79
*
* Slot Name: SAEvr04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 535, 536
*
* \param bitVal of Slot 79 has valid bit values from 0 to 2500
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot79_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot79_toDisp - convert bit value to display value for slot 79
*
* Slot Name: SAEvr04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 535, 536
*
* \param bitVal of Slot 79 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot79_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot80_toCAN - convert bit value to display value for slot 80
*
* Slot Name: SAEev01
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 158, 167, 168, 444, 1376, 3509, 3510, 3511,
* 3512, 3513, 3514, 3597, 3598, 3599, 4992, 4996, 5125, 5126, 5127, 5128, 5129,
* 5130, 5131, 5132, 5133, 5134, 5135, 5136, 7712, 7713, 7902, 7910, 7918, 7926
*
* \param bitVal of Slot 80 has valid bit values from 0 to 3212,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot80_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot80_toDisp - convert bit value to display value for slot 80
*
* Slot Name: SAEev01
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 158, 167, 168, 444, 1376, 3509, 3510, 3511,
* 3512, 3513, 3514, 3597, 3598, 3599, 4992, 4996, 5125, 5126, 5127, 5128, 5129,
* 5130, 5131, 5132, 5133, 5134, 5135, 5136, 7712, 7713, 7902, 7910, 7918, 7926
*
* \param bitVal of Slot 80 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot80_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot82_toCAN - convert bit value to display value for slot 82
*
* Slot Name: SAEsg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1389
*
* \param bitVal of Slot 82 has valid bit values from 0 to 6,4255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot82_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot82_toDisp - convert bit value to display value for slot 82
*
* Slot Name: SAEsg01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1389
*
* \param bitVal of Slot 82 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot82_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot83_toCAN - convert bit value to display value for slot 83
*
* Slot Name: SAEsr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1476
*
* \param bitVal of Slot 83 has valid bit values from 0 to 25
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot83_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot83_toDisp - convert bit value to display value for slot 83
*
* Slot Name: SAEsr01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1476
*
* \param bitVal of Slot 83 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot83_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot85_toCAN - convert bit value to display value for slot 85
*
* Slot Name: SAEpr03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1390, 1391, 1392, 1692, 1725, 1726, 1727, 1728,
* 2980, 3251, 3285, 3466, 3469, 3480, 3485, 3486, 3494, 3499, 3500, 3609,
* 3610, 3611, 3612, 3624, 3625, 3626, 3627, 3628, 3629, 3630, 3631, 3632, 3633,
* 3634, 3635, 3636, 3637, 3638, 3639, 3640, 3641, 3642, 3643, 3837, 3838, 4077,
* 4291, 4297, 4303, 4358, 4411, 4755, 4761, 4767, 4817, 5254, 5429, 5430, 5431,
* 5589, 5590, 5631, 5685, 6571, 6572, 6573, 6574, 6787, 6788, 6797, 6798, 7395,
* 7468, 7469, 7470, 7595, 7781
*
* \param bitVal of Slot 85 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot85_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot85_toDisp - convert bit value to display value for slot 85
*
* Slot Name: SAEpr03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1390, 1391, 1392, 1692, 1725, 1726, 1727, 1728,
* 2980, 3251, 3285, 3466, 3469, 3480, 3485, 3486, 3494, 3499, 3500, 3609,
* 3610, 3611, 3612, 3624, 3625, 3626, 3627, 3628, 3629, 3630, 3631, 3632, 3633,
* 3634, 3635, 3636, 3637, 3638, 3639, 3640, 3641, 3642, 3643, 3837, 3838, 4077,
* 4291, 4297, 4303, 4358, 4411, 4755, 4761, 4767, 4817, 5254, 5429, 5430, 5431,
* 5589, 5590, 5631, 5685, 6571, 6572, 6573, 6574, 6787, 6788, 6797, 6798, 7395,
* 7468, 7469, 7470, 7595, 7781
*
* \param bitVal of Slot 85 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot85_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot96_toCAN - convert bit value to display value for slot 96
*
* Slot Name: SAErc01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1591, 7478
*
* \param bitVal of Slot 96 has valid bit values from -250 to 251,992
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot96_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot96_toDisp - convert bit value to display value for slot 96
*
* Slot Name: SAErc01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1591, 7478
*
* \param bitVal of Slot 96 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot96_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot97_toCAN - convert bit value to display value for slot 97
*
* Slot Name: SAEvr05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1768, 1769, 1772, 1773, 1776, 1777, 1780, 1781,
* 1784, 1785, 1788, 1789, 7592
*
* \param bitVal of Slot 97 has valid bit values from 0 to 8000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot97_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot97_toDisp - convert bit value to display value for slot 97
*
* Slot Name: SAEvr05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1768, 1769, 1772, 1773, 1776, 1777, 1780, 1781,
* 1784, 1785, 1788, 1789, 7592
*
* \param bitVal of Slot 97 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot97_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot98_toCAN - convert bit value to display value for slot 98
*
* Slot Name: SAEtq03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1263
*
* \param bitVal of Slot 98 has valid bit values from 0 to 128510
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot98_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot98_toDisp - convert bit value to display value for slot 98
*
* Slot Name: SAEtq03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1263
*
* \param bitVal of Slot 98 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot98_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot99_toCAN - convert bit value to display value for slot 99
*
* Slot Name: SAEtm07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1601, 1609
*
* \param bitVal of Slot 99 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot99_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot99_toDisp - convert bit value to display value for slot 99
*
* Slot Name: SAEtm07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1601, 1609
*
* \param bitVal of Slot 99 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot99_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot104_toCAN - convert bit value to display value for slot 104
*
* Slot Name: SAEec01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1795, 2579, 4993, 4997, 7498, 7714, 7715, 7900,
* 7908, 7916, 7924
*
* \param bitVal of Slot 104 has valid bit values from -1600 to 1612,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot104_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot104_toDisp - convert bit value to display value for slot 104
*
* Slot Name: SAEec01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1795, 2579, 4993, 4997, 7498, 7714, 7715, 7900,
* 7908, 7916, 7924
*
* \param bitVal of Slot 104 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot104_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot106_toCAN - convert bit value to display value for slot 106
*
* Slot Name: SAEpr08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1762, 6708, 7019, 7021, 7022, 7513
*
* \param bitVal of Slot 106 has valid bit values from 0 to 128510
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot106_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot106_toDisp - convert bit value to display value for slot 106
*
* Slot Name: SAEpr08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1762, 6708, 7019, 7021, 7022, 7513
*
* \param bitVal of Slot 106 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot106_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot107_toCAN - convert bit value to display value for slot 107
*
* Slot Name: SAEpw02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1690
*
* \param bitVal of Slot 107 has valid bit values from 0 to 128510
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot107_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot107_toDisp - convert bit value to display value for slot 107
*
* Slot Name: SAEpw02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1690
*
* \param bitVal of Slot 107 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot107_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot112_toCAN - convert bit value to display value for slot 112
*
* Slot Name: SAEie01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1794
*
* \param bitVal of Slot 112 has valid bit values from 0 to 257,02
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot112_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot112_toDisp - convert bit value to display value for slot 112
*
* Slot Name: SAEie01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1794
*
* \param bitVal of Slot 112 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot112_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot113_toCAN - convert bit value to display value for slot 113
*
* Slot Name: SAEad03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1807, 3683, 3686
*
* \param bitVal of Slot 113 has valid bit values from -31,374 to 31,374
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot113_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot113_toDisp - convert bit value to display value for slot 113
*
* Slot Name: SAEad03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1807, 3683, 3686
*
* \param bitVal of Slot 113 has valid bit values from 0 to 64253
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot113_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot114_toCAN - convert bit value to display value for slot 114
*
* Slot Name: SAEva01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1808
*
* \param bitVal of Slot 114 has valid bit values from -3,92 to 3,92
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot114_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot114_toDisp - convert bit value to display value for slot 114
*
* Slot Name: SAEva01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1808
*
* \param bitVal of Slot 114 has valid bit values from 0 to 64225
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot114_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot115_toCAN - convert bit value to display value for slot 115
*
* Slot Name: SAEac01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1809, 2920
*
* \param bitVal of Slot 115 has valid bit values from -15,687 to 15,687
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot115_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot115_toDisp - convert bit value to display value for slot 115
*
* Slot Name: SAEac01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1809, 2920
*
* \param bitVal of Slot 115 has valid bit values from 0 to 64253
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot115_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot122_toCAN - convert bit value to display value for slot 122
*
* Slot Name: SAEma06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 417, 6849, 6851
*
* \param bitVal of Slot 122 has valid bit values from 0 to 32899070
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot122_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot122_toDisp - convert bit value to display value for slot 122
*
* Slot Name: SAEma06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 417, 6849, 6851
*
* \param bitVal of Slot 122 has valid bit values from 0 to 16449535
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot122_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot125_toCAN - convert bit value to display value for slot 125
*
* Slot Name: SAEvl01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 125 has valid bit values from 0 to 64,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot125_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot125_toDisp - convert bit value to display value for slot 125
*
* Slot Name: SAEvl01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 125 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot125_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot126_toCAN - convert bit value to display value for slot 126
*
* Slot Name: SAEds05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 126 has valid bit values from 0 to 4211081,215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot126_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot126_toDisp - convert bit value to display value for slot 126
*
* Slot Name: SAEds05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 126 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot126_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot127_toCAN - convert bit value to display value for slot 127
*
* Slot Name: SAEfr02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3309, 3310
*
* \param bitVal of Slot 127 has valid bit values from -320000 to 322550
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot127_toCAN(INTEGER32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot127_toDisp - convert bit value to display value for slot 127
*
* Slot Name: SAEfr02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3309, 3310
*
* \param bitVal of Slot 127 has valid bit values from 0 to 64255
*
* \return INTEGER32 display value
*
*/
EXTERN_DECL INTEGER32 j1939Slot127_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot128_toCAN - convert bit value to display value for slot 128
*
* Slot Name: SAEpc04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 128 has valid bit values from -100 to 100
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot128_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot128_toDisp - convert bit value to display value for slot 128
*
* Slot Name: SAEpc04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 128 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot128_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot130_toCAN - convert bit value to display value for slot 130
*
* Slot Name: SAEpr12
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4086, 4088, 4089, 7096, 7097, 7098, 7099, 7100,
* 7101
*
* \param bitVal of Slot 130 has valid bit values from 0 to 321275
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot130_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot130_toDisp - convert bit value to display value for slot 130
*
* Slot Name: SAEpr12
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4086, 4088, 4089, 7096, 7097, 7098, 7099, 7100,
* 7101
*
* \param bitVal of Slot 130 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot130_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot132_toCAN - convert bit value to display value for slot 132
*
* Slot Name: SAEtm02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 132 has valid bit values from 0 to 64,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot132_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot132_toDisp - convert bit value to display value for slot 132
*
* Slot Name: SAEtm02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 132 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot132_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot135_toCAN - convert bit value to display value for slot 135
*
* Slot Name: SAEfr03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 135 has valid bit values from -100 to 150
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot135_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot135_toDisp - convert bit value to display value for slot 135
*
* Slot Name: SAEfr03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 135 has valid bit values from 0 to 0
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot135_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot136_toCAN - convert bit value to display value for slot 136
*
* Slot Name: SAEad07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2927
*
* \param bitVal of Slot 136 has valid bit values from -125 to 125
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot136_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot136_toDisp - convert bit value to display value for slot 136
*
* Slot Name: SAEad07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2927
*
* \param bitVal of Slot 136 has valid bit values from 0 to 64000
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot136_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot137_toCAN - convert bit value to display value for slot 137
*
* Slot Name: SAEtq04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 137 has valid bit values from 0 to 7500
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot137_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot137_toDisp - convert bit value to display value for slot 137
*
* Slot Name: SAEtq04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 137 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot137_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot138_toCAN - convert bit value to display value for slot 138
*
* Slot Name: SAEpr04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1127, 1128, 1129, 1130, 5312, 6384
*
* \param bitVal of Slot 138 has valid bit values from 0 to 8031,875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot138_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot138_toDisp - convert bit value to display value for slot 138
*
* Slot Name: SAEpr04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1127, 1128, 1129, 1130, 5312, 6384
*
* \param bitVal of Slot 138 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot138_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot139_toCAN - convert bit value to display value for slot 139
*
* Slot Name: SAEde01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1478
*
* \param bitVal of Slot 139 has valid bit values from 0 to 25
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot139_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot139_toDisp - convert bit value to display value for slot 139
*
* Slot Name: SAEde01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1478
*
* \param bitVal of Slot 139 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot139_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot140_toCAN - convert bit value to display value for slot 140
*
* Slot Name: SAEac02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1810, 2921
*
* \param bitVal of Slot 140 has valid bit values from -12,5 to 12,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot140_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot140_toDisp - convert bit value to display value for slot 140
*
* Slot Name: SAEac02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1810, 2921
*
* \param bitVal of Slot 140 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot140_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot141_toCAN - convert bit value to display value for slot 141
*
* Slot Name: SAEct01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1811
*
* \param bitVal of Slot 141 has valid bit values from -32 to 29
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot141_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot141_toDisp - convert bit value to display value for slot 141
*
* Slot Name: SAEct01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1811
*
* \param bitVal of Slot 141 has valid bit values from 0 to 61
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot141_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot142_toCAN - convert bit value to display value for slot 142
*
* Slot Name: SAEds02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1759
*
* \param bitVal of Slot 142 has valid bit values from -209,7152 to 211,3929215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot142_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot142_toDisp - convert bit value to display value for slot 142
*
* Slot Name: SAEds02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 1759
*
* \param bitVal of Slot 142 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot142_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot143_toCAN - convert bit value to display value for slot 143
*
* Slot Name: SAEec06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 143 has valid bit values from 0 to 64,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot143_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot143_toDisp - convert bit value to display value for slot 143
*
* Slot Name: SAEec06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 143 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot143_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot144_toCAN - convert bit value to display value for slot 144
*
* Slot Name: SAEfq01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2436, 2437, 2438, 2439, 2470, 2471, 2472, 2473,
* 2504, 2505, 2506, 2507
*
* \param bitVal of Slot 144 has valid bit values from 0 to 501,9921875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot144_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot144_toDisp - convert bit value to display value for slot 144
*
* Slot Name: SAEfq01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2436, 2437, 2438, 2439, 2470, 2471, 2472, 2473,
* 2504, 2505, 2506, 2507
*
* \param bitVal of Slot 144 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot144_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot151_toCAN - convert bit value to display value for slot 151
*
* Slot Name: SAEpf01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2464, 2465, 2466, 2467, 2498, 2499, 2500, 2501,
* 3384
*
* \param bitVal of Slot 151 has valid bit values from -1 to 2,921814
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot151_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot151_toDisp - convert bit value to display value for slot 151
*
* Slot Name: SAEpf01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2464, 2465, 2466, 2467, 2498, 2499, 2500, 2501,
* 3384
*
* \param bitVal of Slot 151 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot151_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot161_toCAN - convert bit value to display value for slot 161
*
* Slot Name: SAEpr15
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2580, 2581
*
* \param bitVal of Slot 161 has valid bit values from 0 to 25000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot161_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot161_toDisp - convert bit value to display value for slot 161
*
* Slot Name: SAEpr15
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2580, 2581
*
* \param bitVal of Slot 161 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot161_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot162_toCAN - convert bit value to display value for slot 162
*
* Slot Name: SAEprc01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2586
*
* \param bitVal of Slot 162 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot162_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot162_toDisp - convert bit value to display value for slot 162
*
* Slot Name: SAEprc01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2586
*
* \param bitVal of Slot 162 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot162_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot204_toCAN - convert bit value to display value for slot 204
*
* Slot Name: SAEio01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2611
*
* \param bitVal of Slot 204 has valid bit values from 0 to 100
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot204_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot204_toDisp - convert bit value to display value for slot 204
*
* Slot Name: SAEio01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2611
*
* \param bitVal of Slot 204 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot204_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot205_toCAN - convert bit value to display value for slot 205
*
* Slot Name: SAEpc02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2660, 2661, 2662, 2663, 2664, 2697, 2698, 2699,
* 2700, 2701, 2734, 2735, 2736, 2737, 2738, 4494, 4498, 4516, 4520, 4524,
* 4531, 4535, 4553, 4557, 4561, 4568, 4572, 4590, 4594, 4598, 4605, 4609, 4627,
* 4631, 4635, 4642, 4646, 4664, 4668, 4672, 4679, 4683, 4701, 4705, 4709, 4716,
* 4720, 4738, 4742, 4746
*
* \param bitVal of Slot 205 has valid bit values from 0 to 102
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot205_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot205_toDisp - convert bit value to display value for slot 205
*
* Slot Name: SAEpc02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 2660, 2661, 2662, 2663, 2664, 2697, 2698, 2699,
* 2700, 2701, 2734, 2735, 2736, 2737, 2738, 4494, 4498, 4516, 4520, 4524,
* 4531, 4535, 4553, 4557, 4561, 4568, 4572, 4590, 4594, 4598, 4605, 4609, 4627,
* 4631, 4635, 4642, 4646, 4664, 4668, 4672, 4679, 4683, 4701, 4705, 4709, 4716,
* 4720, 4738, 4742, 4746
*
* \param bitVal of Slot 205 has valid bit values from 0 to 1020
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot205_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot206_toCAN - convert bit value to display value for slot 206
*
* Slot Name: SAEtm13
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2793
*
* \param bitVal of Slot 206 has valid bit values from 0 to 3,289856
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot206_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot206_toDisp - convert bit value to display value for slot 206
*
* Slot Name: SAEtm13
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 2793
*
* \param bitVal of Slot 206 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot206_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot219_toCAN - convert bit value to display value for slot 219
*
* Slot Name: SAEvm01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 219 has valid bit values from 0 to 128510
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot219_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot219_toDisp - convert bit value to display value for slot 219
*
* Slot Name: SAEvm01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 219 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot219_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot221_toCAN - convert bit value to display value for slot 221
*
* Slot Name: SAEev03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 221 has valid bit values from 0 to 642,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot221_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot221_toDisp - convert bit value to display value for slot 221
*
* Slot Name: SAEev03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 221 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot221_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot222_toCAN - convert bit value to display value for slot 222
*
* Slot Name: SAEvm2
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 222 has valid bit values from 0 to 32127,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot222_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot222_toDisp - convert bit value to display value for slot 222
*
* Slot Name: SAEvm2
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 222 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot222_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot224_toCAN - convert bit value to display value for slot 224
*
* Slot Name: SAEtm14
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 224 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot224_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot224_toDisp - convert bit value to display value for slot 224
*
* Slot Name: SAEtm14
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 224 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot224_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot225_toCAN - convert bit value to display value for slot 225
*
* Slot Name: SAEvm3
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3027, 5914
*
* \param bitVal of Slot 225 has valid bit values from -62,5 to 62,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot225_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot225_toDisp - convert bit value to display value for slot 225
*
* Slot Name: SAEvm3
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3027, 5914
*
* \param bitVal of Slot 225 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot225_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot226_toCAN - convert bit value to display value for slot 226
*
* Slot Name: SAEma04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 226 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot226_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot226_toDisp - convert bit value to display value for slot 226
*
* Slot Name: SAEma04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 226 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot226_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot227_toCAN - convert bit value to display value for slot 227
*
* Slot Name: SAEma05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4333, 4350, 4386, 4403
*
* \param bitVal of Slot 227 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot227_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot227_toDisp - convert bit value to display value for slot 227
*
* Slot Name: SAEma05
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4333, 4350, 4386, 4403
*
* \param bitVal of Slot 227 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot227_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot229_toCAN - convert bit value to display value for slot 229
*
* Slot Name: SAEpr16
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 229 has valid bit values from 0 to 12500
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot229_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot229_toDisp - convert bit value to display value for slot 229
*
* Slot Name: SAEpr16
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 229 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot229_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot230_toCAN - convert bit value to display value for slot 230
*
* Slot Name: SAEct09
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 230 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot230_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot230_toDisp - convert bit value to display value for slot 230
*
* Slot Name: SAEct09
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 230 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot230_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot234_toCAN - convert bit value to display value for slot 234
*
* Slot Name: SAEds13
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3311
*
* \param bitVal of Slot 234 has valid bit values from 0 to 2500
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot234_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot234_toDisp - convert bit value to display value for slot 234
*
* Slot Name: SAEds13
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3311
*
* \param bitVal of Slot 234 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot234_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot235_toCAN - convert bit value to display value for slot 235
*
* Slot Name: SAEds14
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5410, 5411, 5412, 5413
*
* \param bitVal of Slot 235 has valid bit values from -32000 to 32255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot235_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot235_toDisp - convert bit value to display value for slot 235
*
* Slot Name: SAEds14
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5410, 5411, 5412, 5413
*
* \param bitVal of Slot 235 has valid bit values from 0 to 64255
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot235_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot236_toCAN - convert bit value to display value for slot 236
*
* Slot Name: SAEpp01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3216, 3226, 3255, 3265, 4377, 4443, 6579, 6580,
* 7351, 7352, 7353, 7354, 7649, 7660, 7671, 7682
*
* \param bitVal of Slot 236 has valid bit values from -200 to 3012,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot236_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot236_toDisp - convert bit value to display value for slot 236
*
* Slot Name: SAEpp01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3216, 3226, 3255, 3265, 4377, 4443, 6579, 6580,
* 7351, 7352, 7353, 7354, 7649, 7660, 7671, 7682
*
* \param bitVal of Slot 236 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot236_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot237_toCAN - convert bit value to display value for slot 237
*
* Slot Name: SAEpc16
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 3217, 3227, 3256, 3266, 7650, 7661, 7672, 7683
*
* \param bitVal of Slot 237 has valid bit values from -12 to 21,02707
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot237_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot237_toDisp - convert bit value to display value for slot 237
*
* Slot Name: SAEpc16
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 3217, 3227, 3256, 3266, 7650, 7661, 7672, 7683
*
* \param bitVal of Slot 237 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot237_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot241_toCAN - convert bit value to display value for slot 241
*
* Slot Name: SAEtm16
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3327, 3366, 4982, 4989
*
* \param bitVal of Slot 241 has valid bit values from 0 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot241_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot241_toDisp - convert bit value to display value for slot 241
*
* Slot Name: SAEtm16
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3327, 3366, 4982, 4989
*
* \param bitVal of Slot 241 has valid bit values from 0 to 250000
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot241_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot242_toCAN - convert bit value to display value for slot 242
*
* Slot Name: SAEad08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3318, 3319, 5821, 7790, 7793, 7796, 7798, 7802,
* 7805, 7808, 7810
*
* \param bitVal of Slot 242 has valid bit values from -64 to 64,51
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot242_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot242_toDisp - convert bit value to display value for slot 242
*
* Slot Name: SAEad08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3318, 3319, 5821, 7790, 7793, 7796, 7798, 7802,
* 7805, 7808, 7810
*
* \param bitVal of Slot 242 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot242_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot243_toCAN - convert bit value to display value for slot 243
*
* Slot Name: SAEva02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3322
*
* \param bitVal of Slot 243 has valid bit values from -64 to 64,51
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot243_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot243_toDisp - convert bit value to display value for slot 243
*
* Slot Name: SAEva02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3322
*
* \param bitVal of Slot 243 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot243_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot244_toCAN - convert bit value to display value for slot 244
*
* Slot Name: SAEad09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7356, 7357, 7358, 7359, 7360, 7361, 7362, 7363,
* 7364, 7365, 7366, 7367, 7368, 7369, 7370, 7371, 7372, 7373, 7374, 7375,
* 7376, 7377, 7378, 7379, 7479, 7480
*
* \param bitVal of Slot 244 has valid bit values from -12,5 to 12,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot244_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot244_toDisp - convert bit value to display value for slot 244
*
* Slot Name: SAEad09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7356, 7357, 7358, 7359, 7360, 7361, 7362, 7363,
* 7364, 7365, 7366, 7367, 7368, 7369, 7370, 7371, 7372, 7373, 7374, 7375,
* 7376, 7377, 7378, 7379, 7479, 7480
*
* \param bitVal of Slot 244 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot244_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot246_toCAN - convert bit value to display value for slot 246
*
* Slot Name: SAEpr17
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3342, 6816
*
* \param bitVal of Slot 246 has valid bit values from -7 to 403
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot246_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot246_toDisp - convert bit value to display value for slot 246
*
* Slot Name: SAEpr17
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3342, 6816
*
* \param bitVal of Slot 246 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot246_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot247_toCAN - convert bit value to display value for slot 247
*
* Slot Name: SAEtm17
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 247 has valid bit values from 0 to 250
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot247_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot247_toDisp - convert bit value to display value for slot 247
*
* Slot Name: SAEtm17
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 247 has valid bit values from 0 to 250000
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot247_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot248_toCAN - convert bit value to display value for slot 248
*
* Slot Name: SAEad10
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 248 has valid bit values from -65 to 60
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot248_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot248_toDisp - convert bit value to display value for slot 248
*
* Slot Name: SAEad10
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 248 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot248_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot249_toCAN - convert bit value to display value for slot 249
*
* Slot Name: SAEev04
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3380
*
* \param bitVal of Slot 249 has valid bit values from -1606 to 1606,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot249_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot249_toDisp - convert bit value to display value for slot 249
*
* Slot Name: SAEev04
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3380
*
* \param bitVal of Slot 249 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot249_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot250_toCAN - convert bit value to display value for slot 250
*
* Slot Name: SAEec05
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3381
*
* \param bitVal of Slot 250 has valid bit values from 0 to 3212,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot250_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot250_toDisp - convert bit value to display value for slot 250
*
* Slot Name: SAEec05
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3381
*
* \param bitVal of Slot 250 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot250_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot251_toCAN - convert bit value to display value for slot 251
*
* Slot Name: SAEpc07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3382, 4236, 4237, 4238, 4239
*
* \param bitVal of Slot 251 has valid bit values from -100 to 100
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot251_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot251_toDisp - convert bit value to display value for slot 251
*
* Slot Name: SAEpc07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3382, 4236, 4237, 4238, 4239
*
* \param bitVal of Slot 251 has valid bit values from 0 to 2000
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot251_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot252_toCAN - convert bit value to display value for slot 252
*
* Slot Name: SAEev05
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3386
*
* \param bitVal of Slot 252 has valid bit values from 0 to 32899071
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot252_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot252_toDisp - convert bit value to display value for slot 252
*
* Slot Name: SAEev05
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3386
*
* \param bitVal of Slot 252 has valid bit values from 0 to 4211081088
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot252_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot254_toCAN - convert bit value to display value for slot 254
*
* Slot Name: SAEpc15
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3516, 4421
*
* \param bitVal of Slot 254 has valid bit values from 0 to 62,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot254_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot254_toDisp - convert bit value to display value for slot 254
*
* Slot Name: SAEpc15
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3516, 4421
*
* \param bitVal of Slot 254 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot254_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot255_toCAN - convert bit value to display value for slot 255
*
* Slot Name: SAEco01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3518, 4422
*
* \param bitVal of Slot 255 has valid bit values from 0 to 1250
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot255_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot255_toDisp - convert bit value to display value for slot 255
*
* Slot Name: SAEco01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3518, 4422
*
* \param bitVal of Slot 255 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot255_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot256_toCAN - convert bit value to display value for slot 256
*
* Slot Name: SAEpc08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3590, 3591, 3592, 6649
*
* \param bitVal of Slot 256 has valid bit values from -251 to 250,99
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot256_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot256_toDisp - convert bit value to display value for slot 256
*
* Slot Name: SAEpc08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3590, 3591, 3592, 6649
*
* \param bitVal of Slot 256 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot256_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot261_toCAN - convert bit value to display value for slot 261
*
* Slot Name: SAErc02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 261 has valid bit values from -90 to 90
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot261_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot261_toDisp - convert bit value to display value for slot 261
*
* Slot Name: SAErc02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 261 has valid bit values from 0 to 23040
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot261_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot262_toCAN - convert bit value to display value for slot 262
*
* Slot Name: SAEfg02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3236, 3832, 3835
*
* \param bitVal of Slot 262 has valid bit values from 0 to 12851
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot262_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot262_toDisp - convert bit value to display value for slot 262
*
* Slot Name: SAEfg02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3236, 3832, 3835
*
* \param bitVal of Slot 262 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot262_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot263_toCAN - convert bit value to display value for slot 263
*
* Slot Name: SAEra01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3684
*
* \param bitVal of Slot 263 has valid bit values from -32 to 29
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot263_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot263_toDisp - convert bit value to display value for slot 263
*
* Slot Name: SAEra01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 3684
*
* \param bitVal of Slot 263 has valid bit values from 0 to 61
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot263_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot264_toCAN - convert bit value to display value for slot 264
*
* Slot Name: SAEpc09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3938, 5829, 5830, 5831, 5832
*
* \param bitVal of Slot 264 has valid bit values from -125 to 132,02
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot264_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot264_toDisp - convert bit value to display value for slot 264
*
* Slot Name: SAEpc09
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 3938, 5829, 5830, 5831, 5832
*
* \param bitVal of Slot 264 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot264_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot267_toCAN - convert bit value to display value for slot 267
*
* Slot Name: SAEma07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 413
*
* \param bitVal of Slot 267 has valid bit values from -16449535 to 16449535
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot267_toCAN(INTEGER32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot267_toDisp - convert bit value to display value for slot 267
*
* Slot Name: SAEma07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 413
*
* \param bitVal of Slot 267 has valid bit values from 0 to 16449535
*
* \return INTEGER32 display value
*
*/
EXTERN_DECL INTEGER32 j1939Slot267_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot268_toCAN - convert bit value to display value for slot 268
*
* Slot Name: SAEpc10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4154, 4191
*
* \param bitVal of Slot 268 has valid bit values from 0 to 0,875
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot268_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot268_toDisp - convert bit value to display value for slot 268
*
* Slot Name: SAEpc10
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4154, 4191
*
* \param bitVal of Slot 268 has valid bit values from 0 to 7
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot268_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot272_toCAN - convert bit value to display value for slot 272
*
* Slot Name: SAEfm01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4331, 4348, 4384, 4401
*
* \param bitVal of Slot 272 has valid bit values from 0 to 19276,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot272_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot272_toDisp - convert bit value to display value for slot 272
*
* Slot Name: SAEfm01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4331, 4348, 4384, 4401
*
* \param bitVal of Slot 272 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot272_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot284_toCAN - convert bit value to display value for slot 284
*
* Slot Name: SAEcy02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 284 has valid bit values from 2000 to 2061
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot284_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot284_toDisp - convert bit value to display value for slot 284
*
* Slot Name: SAEcy02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 284 has valid bit values from 0 to 61
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot284_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot285_toCAN - convert bit value to display value for slot 285
*
* Slot Name: SAEsh01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 4490
*
* \param bitVal of Slot 285 has valid bit values from 0 to 642,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot285_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot285_toDisp - convert bit value to display value for slot 285
*
* Slot Name: SAEsh01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 4490
*
* \param bitVal of Slot 285 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot285_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot286_toCAN - convert bit value to display value for slot 286
*
* Slot Name: SAEma01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4781, 4786
*
* \param bitVal of Slot 286 has valid bit values from 0 to 1000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot286_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot286_toDisp - convert bit value to display value for slot 286
*
* Slot Name: SAEma01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4781, 4786
*
* \param bitVal of Slot 286 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot286_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot287_toCAN - convert bit value to display value for slot 287
*
* Slot Name: SAEdn01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4782, 4787
*
* \param bitVal of Slot 287 has valid bit values from 0 to 20
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot287_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot287_toDisp - convert bit value to display value for slot 287
*
* Slot Name: SAEdn01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4782, 4787
*
* \param bitVal of Slot 287 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot287_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot288_toCAN - convert bit value to display value for slot 288
*
* Slot Name: SAEva03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4983, 4984, 4985
*
* \param bitVal of Slot 288 has valid bit values from -250 to 250,992
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot288_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot288_toDisp - convert bit value to display value for slot 288
*
* Slot Name: SAEva03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4983, 4984, 4985
*
* \param bitVal of Slot 288 has valid bit values from 0 to 64126
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot288_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot290_toCAN - convert bit value to display value for slot 290
*
* Slot Name: SAErs01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4818, 4819, 4820, 4821, 4822, 4823, 4824, 4825,
* 4826, 4827, 4828, 4829, 4830, 4831, 4832, 4833, 4834, 4835, 4836, 4837,
* 4838, 4839, 4840, 4841, 4842, 4843, 4844, 4845, 4846, 4847, 4848, 4849, 4850,
* 4851, 4852, 4853, 4854, 4855, 4856, 4857, 4858, 4859, 4860, 4861, 4862, 4863,
* 4864, 4865, 4866, 4867, 4868, 4869, 4870, 4871, 4872, 4873, 4874, 4875, 4876,
* 4877, 4878, 4879, 4880, 4881, 4882, 4883, 4884, 4885, 4886, 4887, 4888, 4889,
* 4890, 4891, 4892, 4893, 4894, 4895, 4896, 4897, 4898, 4899, 4900, 4901, 4902,
* 4903, 4904, 4905, 4906, 4907, 4908, 4909, 4910, 4911, 4912, 4913, 4914, 4915,
* 4916, 4917, 7070
*
* \param bitVal of Slot 290 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot290_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot290_toDisp - convert bit value to display value for slot 290
*
* Slot Name: SAErs01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4818, 4819, 4820, 4821, 4822, 4823, 4824, 4825,
* 4826, 4827, 4828, 4829, 4830, 4831, 4832, 4833, 4834, 4835, 4836, 4837,
* 4838, 4839, 4840, 4841, 4842, 4843, 4844, 4845, 4846, 4847, 4848, 4849, 4850,
* 4851, 4852, 4853, 4854, 4855, 4856, 4857, 4858, 4859, 4860, 4861, 4862, 4863,
* 4864, 4865, 4866, 4867, 4868, 4869, 4870, 4871, 4872, 4873, 4874, 4875, 4876,
* 4877, 4878, 4879, 4880, 4881, 4882, 4883, 4884, 4885, 4886, 4887, 4888, 4889,
* 4890, 4891, 4892, 4893, 4894, 4895, 4896, 4897, 4898, 4899, 4900, 4901, 4902,
* 4903, 4904, 4905, 4906, 4907, 4908, 4909, 4910, 4911, 4912, 4913, 4914, 4915,
* 4916, 4917, 7070
*
* \param bitVal of Slot 290 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot290_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot294_toCAN - convert bit value to display value for slot 294
*
* Slot Name: SAEad11
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4976, 4977
*
* \param bitVal of Slot 294 has valid bit values from -250 to 252
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot294_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot294_toDisp - convert bit value to display value for slot 294
*
* Slot Name: SAEad11
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 4976, 4977
*
* \param bitVal of Slot 294 has valid bit values from 0 to 16449536
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot294_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot295_toCAN - convert bit value to display value for slot 295
*
* Slot Name: SAEpc17
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5025, 5032, 5039, 5046
*
* \param bitVal of Slot 295 has valid bit values from -100 to 6325,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot295_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot295_toDisp - convert bit value to display value for slot 295
*
* Slot Name: SAEpc17
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5025, 5032, 5039, 5046
*
* \param bitVal of Slot 295 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot295_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot296_toCAN - convert bit value to display value for slot 296
*
* Slot Name: SAEpp02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5026, 5033, 5040, 5047
*
* \param bitVal of Slot 296 has valid bit values from -125 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot296_toCAN(INTEGER8 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot296_toDisp - convert bit value to display value for slot 296
*
* Slot Name: SAEpp02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5026, 5033, 5040, 5047
*
* \param bitVal of Slot 296 has valid bit values from 0 to 250
*
* \return INTEGER8 display value
*
*/
EXTERN_DECL INTEGER8 j1939Slot296_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot297_toCAN - convert bit value to display value for slot 297
*
* Slot Name: SAElg01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 297 has valid bit values from 0 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot297_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot297_toDisp - convert bit value to display value for slot 297
*
* Slot Name: SAElg01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 297 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot297_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot298_toCAN - convert bit value to display value for slot 298
*
* Slot Name: SAEsg02
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 5027, 5028, 5034, 5035, 5041, 5042, 5048, 5049
*
* \param bitVal of Slot 298 has valid bit values from 0 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot298_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot298_toDisp - convert bit value to display value for slot 298
*
* Slot Name: SAEsg02
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 5027, 5028, 5034, 5035, 5041, 5042, 5048, 5049
*
* \param bitVal of Slot 298 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot298_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot299_toCAN - convert bit value to display value for slot 299
*
* Slot Name: SAEpc18
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5029, 5030, 5036, 5037, 5043, 5044, 5050, 5051,
* 5983, 6333, 6386, 6834, 6835, 6836, 6850, 6852, 6975, 6976, 6977, 6981,
* 6982, 6983, 7905, 7913, 7921, 7929, 7946, 7970, 7982, 7994, 8006, 8018, 8030,
* 8042, 8054, 8066
*
* \param bitVal of Slot 299 has valid bit values from 0 to 125
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot299_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot299_toDisp - convert bit value to display value for slot 299
*
* Slot Name: SAEpc18
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5029, 5030, 5036, 5037, 5043, 5044, 5050, 5051,
* 5983, 6333, 6386, 6834, 6835, 6836, 6850, 6852, 6975, 6976, 6977, 6981,
* 6982, 6983, 7905, 7913, 7921, 7929, 7946, 7970, 7982, 7994, 8006, 8018, 8030,
* 8042, 8054, 8066
*
* \param bitVal of Slot 299 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot299_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot300_toCAN - convert bit value to display value for slot 300
*
* Slot Name: SAEful02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5053, 5054
*
* \param bitVal of Slot 300 has valid bit values from 0 to 4211081,215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot300_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot300_toDisp - convert bit value to display value for slot 300
*
* Slot Name: SAEful02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5053, 5054
*
* \param bitVal of Slot 300 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot300_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot301_toCAN - convert bit value to display value for slot 301
*
* Slot Name: SAEdv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5055, 5533, 5537
*
* \param bitVal of Slot 301 has valid bit values from 0 to 1003,984375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot301_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot301_toDisp - convert bit value to display value for slot 301
*
* Slot Name: SAEdv01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5055, 5533, 5537
*
* \param bitVal of Slot 301 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot301_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot302_toCAN - convert bit value to display value for slot 302
*
* Slot Name: SAEdn02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5056, 5534, 5538
*
* \param bitVal of Slot 302 has valid bit values from 0 to 1,961
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot302_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot302_toDisp - convert bit value to display value for slot 302
*
* Slot Name: SAEdn02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5056, 5534, 5538
*
* \param bitVal of Slot 302 has valid bit values from 0 to 64252
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot302_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot303_toCAN - convert bit value to display value for slot 303
*
* Slot Name: SAEac03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5347, 5348, 5349
*
* \param bitVal of Slot 303 has valid bit values from -320 to 322,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot303_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot303_toDisp - convert bit value to display value for slot 303
*
* Slot Name: SAEac03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5347, 5348, 5349
*
* \param bitVal of Slot 303 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot303_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot305_toCAN - convert bit value to display value for slot 305
*
* Slot Name: SAEpw04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5564, 7952, 7976, 7988, 8000, 8012, 8024, 8036,
* 8048, 8060, 8072
*
* \param bitVal of Slot 305 has valid bit values from 0 to 32127,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot305_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot305_toDisp - convert bit value to display value for slot 305
*
* Slot Name: SAEpw04
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5564, 7952, 7976, 7988, 8000, 8012, 8024, 8036,
* 8048, 8060, 8072
*
* \param bitVal of Slot 305 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot305_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot306_toCAN - convert bit value to display value for slot 306
*
* Slot Name: SAEct13
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5567
*
* \param bitVal of Slot 306 has valid bit values from -32128 to 32127
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot306_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot306_toDisp - convert bit value to display value for slot 306
*
* Slot Name: SAEct13
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5567
*
* \param bitVal of Slot 306 has valid bit values from 0 to 64255
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot306_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot307_toCAN - convert bit value to display value for slot 307
*
* Slot Name: SAEde02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5468, 5535, 5539
*
* \param bitVal of Slot 307 has valid bit values from 0 to 7,844
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot307_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot307_toDisp - convert bit value to display value for slot 307
*
* Slot Name: SAEde02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5468, 5535, 5539
*
* \param bitVal of Slot 307 has valid bit values from 0 to 64258
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot307_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot308_toCAN - convert bit value to display value for slot 308
*
* Slot Name: SAEpc19
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5568
*
* \param bitVal of Slot 308 has valid bit values from 0 to 10
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot308_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot308_toDisp - convert bit value to display value for slot 308
*
* Slot Name: SAEpc19
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5568
*
* \param bitVal of Slot 308 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot308_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot317_toCAN - convert bit value to display value for slot 317
*
* Slot Name: SAEfm02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5503, 5505, 5834, 6593, 6594, 6595, 6596
*
* \param bitVal of Slot 317 has valid bit values from 0 to 3212,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot317_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot317_toDisp - convert bit value to display value for slot 317
*
* Slot Name: SAEfm02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5503, 5505, 5834, 6593, 6594, 6595, 6596
*
* \param bitVal of Slot 317 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot317_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot318_toCAN - convert bit value to display value for slot 318
*
* Slot Name: SAEr04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 318 has valid bit values from -3,92 to 3,92
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot318_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot318_toDisp - convert bit value to display value for slot 318
*
* Slot Name: SAEr04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 318 has valid bit values from 0 to 64225
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot318_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot319_toCAN - convert bit value to display value for slot 319
*
* Slot Name: SAEtm18
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 319 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot319_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot319_toDisp - convert bit value to display value for slot 319
*
* Slot Name: SAEtm18
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 319 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot319_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot320_toCAN - convert bit value to display value for slot 320
*
* Slot Name: SAEfq02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5632, 5633, 5634, 5635, 5636, 5638, 5640, 5642,
* 5644, 5645, 5646, 5647, 5648, 5650, 5652, 5654
*
* \param bitVal of Slot 320 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot320_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot320_toDisp - convert bit value to display value for slot 320
*
* Slot Name: SAEfq02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5632, 5633, 5634, 5635, 5636, 5638, 5640, 5642,
* 5644, 5645, 5646, 5647, 5648, 5650, 5652, 5654
*
* \param bitVal of Slot 320 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot320_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot321_toCAN - convert bit value to display value for slot 321
*
* Slot Name: SAEfl02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1600, 2773, 2774, 2778
*
* \param bitVal of Slot 321 has valid bit values from 0 to 4211081,215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot321_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot321_toDisp - convert bit value to display value for slot 321
*
* Slot Name: SAEfl02
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 1600, 2773, 2774, 2778
*
* \param bitVal of Slot 321 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot321_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot322_toCAN - convert bit value to display value for slot 322
*
* Slot Name: SAEtm19
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5680
*
* \param bitVal of Slot 322 has valid bit values from 0 to 12,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot322_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot322_toDisp - convert bit value to display value for slot 322
*
* Slot Name: SAEtm19
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5680
*
* \param bitVal of Slot 322 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot322_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot323_toCAN - convert bit value to display value for slot 323
*
* Slot Name: SAEef01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 4245
*
* \param bitVal of Slot 323 has valid bit values from 0 to 250,996
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot323_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot323_toDisp - convert bit value to display value for slot 323
*
* Slot Name: SAEef01
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 4245
*
* \param bitVal of Slot 323 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot323_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot326_toCAN - convert bit value to display value for slot 326
*
* Slot Name: SAEsg03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5753, 5757, 6972
*
* \param bitVal of Slot 326 has valid bit values from -125 to 0
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot326_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot326_toDisp - convert bit value to display value for slot 326
*
* Slot Name: SAEsg03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5753, 5757, 6972
*
* \param bitVal of Slot 326 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot326_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot333_toCAN - convert bit value to display value for slot 333
*
* Slot Name: SAEtm20
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 333 has valid bit values from 0 to 642,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot333_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot333_toDisp - convert bit value to display value for slot 333
*
* Slot Name: SAEtm20
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 333 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot333_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot334_toCAN - convert bit value to display value for slot 334
*
* Slot Name: SAEpc20
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 334 has valid bit values from -32 to 32,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot334_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot334_toDisp - convert bit value to display value for slot 334
*
* Slot Name: SAEpc20
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 334 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot334_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot336_toCAN - convert bit value to display value for slot 336
*
* Slot Name: SAEfm03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5833
*
* \param bitVal of Slot 336 has valid bit values from 0 to 321,275
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot336_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot336_toDisp - convert bit value to display value for slot 336
*
* Slot Name: SAEfm03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 5833
*
* \param bitVal of Slot 336 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot336_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot337_toCAN - convert bit value to display value for slot 337
*
* Slot Name: SAEms01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5835, 5836
*
* \param bitVal of Slot 337 has valid bit values from 0 to 803,1875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot337_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot337_toDisp - convert bit value to display value for slot 337
*
* Slot Name: SAEms01
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5835, 5836
*
* \param bitVal of Slot 337 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot337_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot345_toCAN - convert bit value to display value for slot 345
*
* Slot Name: SAEpc21
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7837
*
* \param bitVal of Slot 345 has valid bit values from 0 to 100,3984375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot345_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot345_toDisp - convert bit value to display value for slot 345
*
* Slot Name: SAEpc21
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7837
*
* \param bitVal of Slot 345 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot345_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot346_toCAN - convert bit value to display value for slot 346
*
* Slot Name: SAEpw05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 346 has valid bit values from 0 to 3212,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot346_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot346_toDisp - convert bit value to display value for slot 346
*
* Slot Name: SAEpw05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 346 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot346_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot347_toCAN - convert bit value to display value for slot 347
*
* Slot Name: SAEev06
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7589
*
* \param bitVal of Slot 347 has valid bit values from 0 to 64,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot347_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot347_toDisp - convert bit value to display value for slot 347
*
* Slot Name: SAEev06
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7589
*
* \param bitVal of Slot 347 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot347_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot348_toCAN - convert bit value to display value for slot 348
*
* Slot Name: SAEpp03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5848, 5855
*
* \param bitVal of Slot 348 has valid bit values from -200 to 6225,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot348_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot348_toDisp - convert bit value to display value for slot 348
*
* Slot Name: SAEpp03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 5848, 5855
*
* \param bitVal of Slot 348 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot348_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot349_toCAN - convert bit value to display value for slot 349
*
* Slot Name: SAEpp04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 349 has valid bit values from -500 to 2712,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot349_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot349_toDisp - convert bit value to display value for slot 349
*
* Slot Name: SAEpp04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 349 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot349_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot350_toCAN - convert bit value to display value for slot 350
*
* Slot Name: SAEfl03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 350 has valid bit values from -1600 to 1612,75
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot350_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot350_toDisp - convert bit value to display value for slot 350
*
* Slot Name: SAEfl03
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 350 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot350_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot352_toCAN - convert bit value to display value for slot 352
*
* Slot Name: SAEec07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6080, 6081, 6082, 6083, 6084, 6085, 6086, 6087,
* 6088, 6089, 6090, 6091, 6092, 6093, 6094, 6095, 6096, 6097, 6098, 6099,
* 6100, 6101, 6102, 6103, 6104, 6105, 6106, 6107, 6108, 6109, 6110, 6111, 6112,
* 6113, 6114, 6115, 6116, 6117, 6118, 6119, 6120, 6121, 6122, 6123, 6124, 6125,
* 6126, 6127, 6128, 6129, 6130, 6131, 6132, 6133, 6134, 6135, 6136, 6137, 6138,
* 6139, 6140, 6141, 6142, 6143
*
* \param bitVal of Slot 352 has valid bit values from 0 to 321,275
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot352_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot352_toDisp - convert bit value to display value for slot 352
*
* Slot Name: SAEec07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6080, 6081, 6082, 6083, 6084, 6085, 6086, 6087,
* 6088, 6089, 6090, 6091, 6092, 6093, 6094, 6095, 6096, 6097, 6098, 6099,
* 6100, 6101, 6102, 6103, 6104, 6105, 6106, 6107, 6108, 6109, 6110, 6111, 6112,
* 6113, 6114, 6115, 6116, 6117, 6118, 6119, 6120, 6121, 6122, 6123, 6124, 6125,
* 6126, 6127, 6128, 6129, 6130, 6131, 6132, 6133, 6134, 6135, 6136, 6137, 6138,
* 6139, 6140, 6141, 6142, 6143
*
* \param bitVal of Slot 352 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot352_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot353_toCAN - convert bit value to display value for slot 353
*
* Slot Name: SAEtm22
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 353 has valid bit values from -3212,7 to 3212,8
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot353_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot353_toDisp - convert bit value to display value for slot 353
*
* Slot Name: SAEtm22
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 353 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot353_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot354_toCAN - convert bit value to display value for slot 354
*
* Slot Name: SAEen02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 354 has valid bit values from 0 to 642550
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot354_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot354_toDisp - convert bit value to display value for slot 354
*
* Slot Name: SAEen02
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 354 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot354_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot355_toCAN - convert bit value to display value for slot 355
*
* Slot Name: SAEpr18
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6586, 6587, 7835
*
* \param bitVal of Slot 355 has valid bit values from -3212,7 to 3212,8
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot355_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot355_toDisp - convert bit value to display value for slot 355
*
* Slot Name: SAEpr18
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6586, 6587, 7835
*
* \param bitVal of Slot 355 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot355_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot356_toCAN - convert bit value to display value for slot 356
*
* Slot Name: SAEma09
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 356 has valid bit values from 0 to 642550
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot356_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot356_toDisp - convert bit value to display value for slot 356
*
* Slot Name: SAEma09
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 356 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot356_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot357_toCAN - convert bit value to display value for slot 357
*
* Slot Name: SAEpr19
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 357 has valid bit values from 0 to 501,9921875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot357_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot357_toDisp - convert bit value to display value for slot 357
*
* Slot Name: SAEpr19
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 357 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot357_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot358_toCAN - convert bit value to display value for slot 358
*
* Slot Name: SAEtp04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 358 has valid bit values from -273 to 228,9921875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot358_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot358_toDisp - convert bit value to display value for slot 358
*
* Slot Name: SAEtp04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 358 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot358_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot359_toCAN - convert bit value to display value for slot 359
*
* Slot Name: SAEdp01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 359 has valid bit values from 0 to 1606,375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot359_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot359_toDisp - convert bit value to display value for slot 359
*
* Slot Name: SAEdp01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 359 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot359_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot360_toCAN - convert bit value to display value for slot 360
*
* Slot Name: SAEfm04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 360 has valid bit values from -3212,7 to 3212,8
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot360_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot360_toDisp - convert bit value to display value for slot 360
*
* Slot Name: SAEfm04
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 360 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot360_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot361_toCAN - convert bit value to display value for slot 361
*
* Slot Name: SAEfm05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 361 has valid bit values from -32127 to 32128
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot361_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot361_toDisp - convert bit value to display value for slot 361
*
* Slot Name: SAEfm05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 361 has valid bit values from 0 to 64255
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot361_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot362_toCAN - convert bit value to display value for slot 362
*
* Slot Name: SAEr05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 362 has valid bit values from 0 to 642,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot362_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot362_toDisp - convert bit value to display value for slot 362
*
* Slot Name: SAEr05
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 362 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot362_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot363_toCAN - convert bit value to display value for slot 363
*
* Slot Name: SAEma10
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 363 has valid bit values from 0 to 1003,984375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot363_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot363_toDisp - convert bit value to display value for slot 363
*
* Slot Name: SAEma10
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 363 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot363_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot364_toCAN - convert bit value to display value for slot 364
*
* Slot Name: SAEpr20
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6483, 6487, 6491, 6495, 6499, 6503, 6507, 6511,
* 6515, 6519, 6523, 6527, 6531, 6535, 6539, 6543, 6547, 6551, 6555, 6559,
* 6707
*
* \param bitVal of Slot 364 has valid bit values from -1 to 6,84362793
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot364_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot364_toDisp - convert bit value to display value for slot 364
*
* Slot Name: SAEpr20
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6483, 6487, 6491, 6495, 6499, 6503, 6507, 6511,
* 6515, 6519, 6523, 6527, 6531, 6535, 6539, 6543, 6547, 6551, 6555, 6559,
* 6707
*
* \param bitVal of Slot 364 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot364_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot365_toCAN - convert bit value to display value for slot 365
*
* Slot Name: SAEad12
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6484, 6485, 6488, 6489, 6492, 6493, 6496, 6497,
* 6500, 6501, 6504, 6505, 6508, 6509, 6512, 6513, 6516, 6517, 6520, 6521,
* 6524, 6525, 6528, 6529, 6532, 6533, 6536, 6537, 6540, 6541, 6544, 6545, 6548,
* 6549, 6552, 6553, 6556, 6557, 6560, 6561
*
* \param bitVal of Slot 365 has valid bit values from -250 to 250,992
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot365_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot365_toDisp - convert bit value to display value for slot 365
*
* Slot Name: SAEad12
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6484, 6485, 6488, 6489, 6492, 6493, 6496, 6497,
* 6500, 6501, 6504, 6505, 6508, 6509, 6512, 6513, 6516, 6517, 6520, 6521,
* 6524, 6525, 6528, 6529, 6532, 6533, 6536, 6537, 6540, 6541, 6544, 6545, 6548,
* 6549, 6552, 6553, 6556, 6557, 6560, 6561
*
* \param bitVal of Slot 365 has valid bit values from 0 to 64126
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot365_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot366_toCAN - convert bit value to display value for slot 366
*
* Slot Name: SAEen03
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 6396, 6400, 6404, 6408, 6412, 6416, 6420, 6424,
* 6428, 6432, 6436, 6440, 6444, 6448, 6452, 6456, 6460, 6464, 6468, 6472
*
* \param bitVal of Slot 366 has valid bit values from -1 to 6,84362793
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot366_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot366_toDisp - convert bit value to display value for slot 366
*
* Slot Name: SAEen03
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 6396, 6400, 6404, 6408, 6412, 6416, 6420, 6424,
* 6428, 6432, 6436, 6440, 6444, 6448, 6452, 6456, 6460, 6464, 6468, 6472
*
* \param bitVal of Slot 366 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot366_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot367_toCAN - convert bit value to display value for slot 367
*
* Slot Name: SAEpr21
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 6397, 6401, 6405, 6409, 6413, 6417, 6421, 6425,
* 6429, 6433, 6437, 6441, 6445, 6449, 6453, 6457, 6461, 6465, 6469, 6473
*
* \param bitVal of Slot 367 has valid bit values from 0 to 62,74902344
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot367_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot367_toDisp - convert bit value to display value for slot 367
*
* Slot Name: SAEpr21
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 6397, 6401, 6405, 6409, 6413, 6417, 6421, 6425,
* 6429, 6433, 6437, 6441, 6445, 6449, 6453, 6457, 6461, 6465, 6469, 6473
*
* \param bitVal of Slot 367 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot367_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot369_toCAN - convert bit value to display value for slot 369
*
* Slot Name: SAEfg03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6387, 6388
*
* \param bitVal of Slot 369 has valid bit values from 0 to 3,921813965
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot369_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot369_toDisp - convert bit value to display value for slot 369
*
* Slot Name: SAEfg03
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6387, 6388
*
* \param bitVal of Slot 369 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot369_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot370_toCAN - convert bit value to display value for slot 370
*
* Slot Name: SAEpw06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 370 has valid bit values from 0 to 4015,9375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot370_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot370_toDisp - convert bit value to display value for slot 370
*
* Slot Name: SAEpw06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 370 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot370_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot372_toCAN - convert bit value to display value for slot 372
*
* Slot Name: SAEfg04
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6393
*
* \param bitVal of Slot 372 has valid bit values from 0 to 62,74902344
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot372_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot372_toDisp - convert bit value to display value for slot 372
*
* Slot Name: SAEfg04
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6393
*
* \param bitVal of Slot 372 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot372_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot373_toCAN - convert bit value to display value for slot 373
*
* Slot Name: SAEid03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6395
*
* \param bitVal of Slot 373 has valid bit values from 0 to 64255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot373_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot373_toDisp - convert bit value to display value for slot 373
*
* Slot Name: SAEid03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6395
*
* \param bitVal of Slot 373 has valid bit values from 0 to 64255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot373_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot375_toCAN - convert bit value to display value for slot 375
*
* Slot Name: SAEr06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 375 has valid bit values from -1004 to 1003,96875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot375_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot375_toDisp - convert bit value to display value for slot 375
*
* Slot Name: SAEr06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 375 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot375_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot376_toCAN - convert bit value to display value for slot 376
*
* Slot Name: SAEvm4
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6563
*
* \param bitVal of Slot 376 has valid bit values from 0 to 210554060,75
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot376_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot376_toDisp - convert bit value to display value for slot 376
*
* Slot Name: SAEvm4
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6563
*
* \param bitVal of Slot 376 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot376_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot378_toCAN - convert bit value to display value for slot 378
*
* Slot Name: SAEvr07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6585
*
* \param bitVal of Slot 378 has valid bit values from -32127 to 32128
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot378_toCAN(INTEGER16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot378_toDisp - convert bit value to display value for slot 378
*
* Slot Name: SAEvr07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6585
*
* \param bitVal of Slot 378 has valid bit values from 0 to 64255
*
* \return INTEGER16 display value
*
*/
EXTERN_DECL INTEGER16 j1939Slot378_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot379_toCAN - convert bit value to display value for slot 379
*
* Slot Name: SAEad13
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6657, 6678, 6679, 6680, 6681, 6682, 6683, 6684,
* 6685, 6686, 6687, 6688, 6689, 6690, 6691, 6692, 6693, 6694, 6695, 6696,
* 6697
*
* \param bitVal of Slot 379 has valid bit values from -400 to 101,99
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot379_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot379_toDisp - convert bit value to display value for slot 379
*
* Slot Name: SAEad13
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6657, 6678, 6679, 6680, 6681, 6682, 6683, 6684,
* 6685, 6686, 6687, 6688, 6689, 6690, 6691, 6692, 6693, 6694, 6695, 6696,
* 6697
*
* \param bitVal of Slot 379 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot379_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot380_toCAN - convert bit value to display value for slot 380
*
* Slot Name: SAEtm23
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6656, 6658, 6659, 6660, 6661, 6662, 6663, 6664,
* 6665, 6666, 6667, 6668, 6669, 6670, 6671, 6672, 6673, 6674, 6675, 6676,
* 6677
*
* \param bitVal of Slot 380 has valid bit values from 0 to 128510
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot380_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot380_toDisp - convert bit value to display value for slot 380
*
* Slot Name: SAEtm23
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6656, 6658, 6659, 6660, 6661, 6662, 6663, 6664,
* 6665, 6666, 6667, 6668, 6669, 6670, 6671, 6672, 6673, 6674, 6675, 6676,
* 6677
*
* \param bitVal of Slot 380 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot380_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot384_toCAN - convert bit value to display value for slot 384
*
* Slot Name: SAEtm24
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6775, 6776
*
* \param bitVal of Slot 384 has valid bit values from 0 to 385530
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot384_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot384_toDisp - convert bit value to display value for slot 384
*
* Slot Name: SAEtm24
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6775, 6776
*
* \param bitVal of Slot 384 has valid bit values from 0 to 64255
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot384_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot385_toCAN - convert bit value to display value for slot 385
*
* Slot Name: SAErs03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6781
*
* \param bitVal of Slot 385 has valid bit values from 0 to 62500
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot385_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot385_toDisp - convert bit value to display value for slot 385
*
* Slot Name: SAErs03
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6781
*
* \param bitVal of Slot 385 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot385_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot386_toCAN - convert bit value to display value for slot 386
*
* Slot Name: SAEpr23
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 386 has valid bit values from -40000 to 602550
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot386_toCAN(INTEGER32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot386_toDisp - convert bit value to display value for slot 386
*
* Slot Name: SAEpr23
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 386 has valid bit values from 0 to 64255
*
* \return INTEGER32 display value
*
*/
EXTERN_DECL INTEGER32 j1939Slot386_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot387_toCAN - convert bit value to display value for slot 387
*
* Slot Name: SAEpc22
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 387 has valid bit values from -321,27 to 321,28
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot387_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot387_toDisp - convert bit value to display value for slot 387
*
* Slot Name: SAEpc22
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 387 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot387_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot388_toCAN - convert bit value to display value for slot 388
*
* Slot Name: SAEfm06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 388 has valid bit values from -200 to 6225,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot388_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot388_toDisp - convert bit value to display value for slot 388
*
* Slot Name: SAEfm06
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 388 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot388_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot389_toCAN - convert bit value to display value for slot 389
*
* Slot Name: SAEfi01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 389 has valid bit values from -125 to 125,9961
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot389_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot389_toDisp - convert bit value to display value for slot 389
*
* Slot Name: SAEfi01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 389 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot389_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot390_toCAN - convert bit value to display value for slot 390
*
* Slot Name: SAEev07
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 390 has valid bit values from -200 to 6225,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot390_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot390_toDisp - convert bit value to display value for slot 390
*
* Slot Name: SAEev07
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 390 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot390_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot393_toCAN - convert bit value to display value for slot 393
*
* Slot Name: SAEpr24
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 393 has valid bit values from -102,0104 to 124,012988
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot393_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot393_toDisp - convert bit value to display value for slot 393
*
* Slot Name: SAEpr24
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 393 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot393_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot394_toCAN - convert bit value to display value for slot 394
*
* Slot Name: SAEr07
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 394 has valid bit values from -300 to 342,55
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot394_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot394_toDisp - convert bit value to display value for slot 394
*
* Slot Name: SAEr07
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 394 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot394_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot396_toCAN - convert bit value to display value for slot 396
*
* Slot Name: SAEfm07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6893, 6894
*
* \param bitVal of Slot 396 has valid bit values from 0 to 1285,1
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot396_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot396_toDisp - convert bit value to display value for slot 396
*
* Slot Name: SAEfm07
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 6893, 6894
*
* \param bitVal of Slot 396 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot396_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot397_toCAN - convert bit value to display value for slot 397
*
* Slot Name: SAEfm08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6895
*
* \param bitVal of Slot 397 has valid bit values from 0 to 12851
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot397_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot397_toDisp - convert bit value to display value for slot 397
*
* Slot Name: SAEfm08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 6895
*
* \param bitVal of Slot 397 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot397_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot398_toCAN - convert bit value to display value for slot 398
*
* Slot Name: SAEvr08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7039
*
* \param bitVal of Slot 398 has valid bit values from -8031,75 to 8032
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot398_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot398_toDisp - convert bit value to display value for slot 398
*
* Slot Name: SAEvr08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7039
*
* \param bitVal of Slot 398 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot398_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot399_toCAN - convert bit value to display value for slot 399
*
* Slot Name: SAEvl06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7316, 7496
*
* \param bitVal of Slot 399 has valid bit values from -125 to 125,996
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot399_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot399_toDisp - convert bit value to display value for slot 399
*
* Slot Name: SAEvl06
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7316, 7496
*
* \param bitVal of Slot 399 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot399_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot400_toCAN - convert bit value to display value for slot 400
*
* Slot Name: SAEfi02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7333
*
* \param bitVal of Slot 400 has valid bit values from 0 to 2007,96875
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot400_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot400_toDisp - convert bit value to display value for slot 400
*
* Slot Name: SAEfi02
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7333
*
* \param bitVal of Slot 400 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot400_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot401_toCAN - convert bit value to display value for slot 401
*
* Slot Name: SAEvl07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7346
*
* \param bitVal of Slot 401 has valid bit values from 0 to 6425,5
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot401_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot401_toDisp - convert bit value to display value for slot 401
*
* Slot Name: SAEvl07
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7346
*
* \param bitVal of Slot 401 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot401_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot403_toCAN - convert bit value to display value for slot 403
*
* Slot Name: SAEec08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7393
*
* \param bitVal of Slot 403 has valid bit values from 0 to 250,99609375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot403_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot403_toDisp - convert bit value to display value for slot 403
*
* Slot Name: SAEec08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7393
*
* \param bitVal of Slot 403 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot403_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot404_toCAN - convert bit value to display value for slot 404
*
* Slot Name: SAEpc23
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7432, 7433
*
* \param bitVal of Slot 404 has valid bit values from -16 to 15,25
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot404_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot404_toDisp - convert bit value to display value for slot 404
*
* Slot Name: SAEpc23
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7432, 7433
*
* \param bitVal of Slot 404 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot404_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot405_toCAN - convert bit value to display value for slot 405
*
* Slot Name: SAEvl08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7438
*
* \param bitVal of Slot 405 has valid bit values from 0 to 31,25
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot405_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot405_toDisp - convert bit value to display value for slot 405
*
* Slot Name: SAEvl08
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7438
*
* \param bitVal of Slot 405 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot405_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot406_toCAN - convert bit value to display value for slot 406
*
* Slot Name: SAEvl09
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7439
*
* \param bitVal of Slot 406 has valid bit values from -31,25 to 0
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot406_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot406_toDisp - convert bit value to display value for slot 406
*
* Slot Name: SAEvl09
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7439
*
* \param bitVal of Slot 406 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot406_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot407_toCAN - convert bit value to display value for slot 407
*
* Slot Name: SAEds16
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7476, 7477
*
* \param bitVal of Slot 407 has valid bit values from 0 to 5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot407_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot407_toDisp - convert bit value to display value for slot 407
*
* Slot Name: SAEds16
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7476, 7477
*
* \param bitVal of Slot 407 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot407_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot409_toCAN - convert bit value to display value for slot 409
*
* Slot Name: SAEev08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7497, 7906, 7914, 7922, 7930
*
* \param bitVal of Slot 409 has valid bit values from 0 to 50
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot409_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot409_toDisp - convert bit value to display value for slot 409
*
* Slot Name: SAEev08
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7497, 7906, 7914, 7922, 7930
*
* \param bitVal of Slot 409 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot409_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot410_toCAN - convert bit value to display value for slot 410
*
* Slot Name: SAEec09
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7590
*
* \param bitVal of Slot 410 has valid bit values from 0 to 62,5
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot410_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot410_toDisp - convert bit value to display value for slot 410
*
* Slot Name: SAEec09
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7590
*
* \param bitVal of Slot 410 has valid bit values from 0 to 250
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot410_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot411_toCAN - convert bit value to display value for slot 411
*
* Slot Name: SAEprc02
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 7629, 7630, 7631, 7632, 7633, 7634, 7635, 7636,
* 7637, 7638, 7639, 7640, 7641, 7642, 7643, 7644, 7645, 7646, 7647, 7648
*
* \param bitVal of Slot 411 has valid bit values from 0 to 4000
*
* \return UNSIGNED8 display value
*
*/
EXTERN_DECL UNSIGNED8 j1939Slot411_toCAN(UNSIGNED16 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot411_toDisp - convert bit value to display value for slot 411
*
* Slot Name: SAEprc02
* This function converts a given bit value to write it to display

** This Slot apllies to SPNs: 7629, 7630, 7631, 7632, 7633, 7634, 7635, 7636,
* 7637, 7638, 7639, 7640, 7641, 7642, 7643, 7644, 7645, 7646, 7647, 7648
*
* \param bitVal of Slot 411 has valid bit values from 0 to 250
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot411_toDisp(UNSIGNED8);


/***************************************************************************/
/**
* \brief j1939Slot412_toCAN - convert bit value to display value for slot 412
*
* Slot Name: SAEma12
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7699
*
* \param bitVal of Slot 412 has valid bit values from 0 to 421108121500
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot412_toCAN(UNSIGNED32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot412_toDisp - convert bit value to display value for slot 412
*
* Slot Name: SAEma12
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7699
*
* \param bitVal of Slot 412 has valid bit values from 0 to 4211081215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot412_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot413_toCAN - convert bit value to display value for slot 413
*
* Slot Name: SAEvm5
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7455, 7456
*
* \param bitVal of Slot 413 has valid bit values from 0 to 2105540607,5
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot413_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot413_toDisp - convert bit value to display value for slot 413
*
* Slot Name: SAEvm5
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7455, 7456
*
* \param bitVal of Slot 413 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot413_toDisp(UNSIGNED32);


/***************************************************************************/
/**
* \brief j1939Slot415_toCAN - convert bit value to display value for slot 415
*
* Slot Name: SAEma13
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7783, 7784, 7786, 7787
*
* \param bitVal of Slot 415 has valid bit values from 0 to 64,255
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot415_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot415_toDisp - convert bit value to display value for slot 415
*
* Slot Name: SAEma13
* This function converts a given bit value to write it to display
* This Slot apllies to SPNs: 7783, 7784, 7786, 7787
*
* \param bitVal of Slot 415 has valid bit values from 0 to 64254
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot415_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot416_toCAN - convert bit value to display value for slot 416
*
* Slot Name: SAEtma01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 416 has valid bit values from -502 to 501,984375
*
* \return UNSIGNED16 display value
*
*/
EXTERN_DECL UNSIGNED16 j1939Slot416_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot416_toDisp - convert bit value to display value for slot 416
*
* Slot Name: SAEtma01
* This function converts a given bit value to write it to display
*
* \param bitVal of Slot 416 has valid bit values from 0 to 64255
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot416_toDisp(UNSIGNED16);


/***************************************************************************/
/**
* \brief j1939Slot419_toCAN - convert bit value to display value for slot 419
*
* Slot Name: SAEfg05
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7852
*
* \param bitVal of Slot 419 has valid bit values from 0 to 4211081,215
*
* \return UNSIGNED32 display value
*
*/
EXTERN_DECL UNSIGNED32 j1939Slot419_toCAN(REAL32 dispVal);


/***************************************************************************/
/**
* \brief j1939Slot419_toDisp - convert bit value to display value for slot 419
*
* Slot Name: SAEfg05
* This function converts a given bit value to write it to display
* This Slot apllies to SPN: 7852
*
* \param bitVal of Slot 419 has valid bit values from 0 to 4211081215
*
* \return REAL32 display value
*
*/
EXTERN_DECL REAL32 j1939Slot419_toDisp(UNSIGNED32);

#endif /* J1939_SLOTS_H */
